@@ -60,18 +60,17 @@ static const char sccsid[] = "@(#)ant.c	4.11 98/06/18 xlockmore";
 #define DEFAULTS "*delay: 1000 \n" \
  "*count: -3 \n" \
  "*cycles: 40000 \n" \
- "*size: -7 \n" \
+ "*size: -12 \n" \
  "*ncolors: 64 \n" \
  "*neighbors: 0 \n" \
  "*sharpturn: False \n" \
  "*fullrandom: True \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "erase.h"
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "automata.h"
 
 /*-
  * neighbors of 0 randomizes it between 3, 4 and 6.
@@ -113,7 +112,7 @@ ModeSpecOpt ant_opts =
 ModStruct   ant_description =
 {"ant", "init_ant", "draw_ant", "release_ant",
  "refresh_ant", "init_ant", NULL, &ant_opts,
- 1000, -3, 40000, -7, 64, 1.0, "",
+ 1000, -3, 40000, -12, 64, 1.0, "",
  "Shows Langton's and Turk's generalized ants", 0, NULL};
 
 #endif
@@ -177,7 +176,7 @@ static char plots[] =
 #endif
  6};				/* Neighborhoods, 8 just makes a mess */
 
-#define NEIGHBORKINDS (sizeof plots / sizeof *plots)
+#define NEIGHBORKINDS (long) (sizeof plots / sizeof *plots)
 
 /* Relative ant moves */
 #define FS 0			/* Step */
@@ -479,7 +478,8 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 			    ap->shape.hexagon, 6, Convex, CoordModePrevious);
 	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-		ap->xb + ap->xs * col, ap->yb + ap->ys * row, ap->xs, ap->ys);
+		ap->xb + ap->xs * col, ap->yb + ap->ys * row,
+	 	ap->xs - (ap->xs > 3), ap->ys - (ap->ys > 3));
 	} else {		/* TRI */
 		int         orient = (col + row) % 2;	/* O left 1 right */
 
@@ -509,7 +509,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 
 		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
 		int         side;
-		int         fudge = 7; /* fudge because the hexagons are not exact */
+		int         fudge = 7;	/* fudge because the hexagons are not exact */
 		XPoint      hex, hex2;
 
 		if (ap->sharpturn) {
@@ -547,31 +547,31 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 	} else if (ap->neighbors == 4) {
 		if (truchetstate) {
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-				 ap->xb + ap->xs * col - ap->xs / 2,
-				 ap->yb + ap->ys * row + ap->ys / 2,
-				 ap->xs, ap->ys,
+				 ap->xb + ap->xs * col - ap->xs / 2 + 1,
+				 ap->yb + ap->ys * row + ap->ys / 2 - 1,
+				 ap->xs - 2, ap->ys - 2,
 				 0 * 64, 90 * 64);
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-				 ap->xb + ap->xs * col + ap->xs / 2,
-				 ap->yb + ap->ys * row - ap->ys / 2,
-				 ap->xs, ap->ys,
+				 ap->xb + ap->xs * col + ap->xs / 2 - 1,
+				 ap->yb + ap->ys * row - ap->ys / 2 + 1,
+				 ap->xs - 2, ap->ys - 2,
 				 -90 * 64, -90 * 64);
 		} else {
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-				 ap->xb + ap->xs * col - ap->xs / 2,
-				 ap->yb + ap->ys * row - ap->ys / 2,
-				 ap->xs, ap->ys,
+				 ap->xb + ap->xs * col - ap->xs / 2 + 1,
+				 ap->yb + ap->ys * row - ap->ys / 2 + 1,
+				 ap->xs - 2, ap->ys - 2,
 				 0 * 64, -90 * 64);
 			XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-				 ap->xb + ap->xs * col + ap->xs / 2,
-				 ap->yb + ap->ys * row + ap->ys / 2,
-				 ap->xs, ap->ys,
+				 ap->xb + ap->xs * col + ap->xs / 2 - 1,
+				 ap->yb + ap->ys * row + ap->ys / 2 - 1,
+				 ap->xs - 2, ap->ys - 2,
 				 90 * 64, 90 * 64);
 		}
 	} else if (ap->neighbors == 3) {
 		int         orient = (col + row) % 2;	/* O left 1 right */
 		int         side, ang;
-		int         fudge = 7; /* fudge because the triangles are not exact */
+		int         fudge = 7;	/* fudge because the triangles are not exact */
 		XPoint      tri;
 
 		tri.x = ap->xb + col * ap->xs;
@@ -594,7 +594,7 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 				XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 				  tri.x - ap->xs / 2, tri.y - 3 * ap->ys / 4,
 					 ap->xs, 3 * ap->ys / 2,
-					 (ang + fudge) * 64, (60 - 2 * fudge) * 64);
+				  (ang + fudge) * 64, (60 - 2 * fudge) * 64);
 			}
 		}
 	}
@@ -840,7 +840,8 @@ init_ant(ModeInfo * mi)
 	Window      window = MI_WINDOW(mi);
 	int         size = MI_SIZE(mi);
 	antfarmstruct *ap;
-	int         col, row, i, dir;
+	int         col, row, dir;
+	long        i;
 
 	if (antfarms == NULL) {
 		if ((antfarms = (antfarmstruct *) calloc(MI_NUM_SCREENS(mi),
@@ -897,17 +898,17 @@ init_ant(ModeInfo * mi)
 			ap->width = 2;
 		if (ap->height < 4)
 			ap->height = 4;
-    if (size < -MINSIZE) {
-      ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
-              MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-			if (ap->ys < MINRANDOMSIZE) 
-         ap->ys = MIN(MINRANDOMSIZE,
-              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
-    } else if (size < MINSIZE) {
-      if (!size)
-        ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
-      else
-		  	ap->ys = MINSIZE;
+		if (size < -MINSIZE) {
+			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
+				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
+			if (ap->ys < MINRANDOMSIZE)
+				ap->ys = MIN(MINRANDOMSIZE,
+					     MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+		} else if (size < MINSIZE) {
+			if (!size)
+				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
+			else
+				ap->ys = MINSIZE;
 		} else
 			ap->ys = MIN(size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 					       MINGRIDSIZE));
@@ -925,13 +926,13 @@ init_ant(ModeInfo * mi)
 		/* Avoid array bounds read of hexagonUnit */
 		ap->shape.hexagon[6].x = 0;
 		ap->shape.hexagon[6].y = 0;
-	} else if (ap->neighbors == 4 && ap->neighbors == 8) {
+	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
 		if (size < -MINSIZE) {
 			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-			if (ap->ys < MINRANDOMSIZE) 
-         ap->ys = MIN(MINRANDOMSIZE,
-              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+			if (ap->ys < MINRANDOMSIZE)
+				ap->ys = MIN(MINRANDOMSIZE,
+					     MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
 		} else if (size < MINSIZE) {
 			if (!size)
 				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
@@ -955,9 +956,9 @@ init_ant(ModeInfo * mi)
 		if (size < -MINSIZE) {
 			ap->ys = NRAND(MIN(-size, MAX(MINSIZE, MIN(ap->width, ap->height) /
 				      MINGRIDSIZE)) - MINSIZE + 1) + MINSIZE;
-			if (ap->ys < MINRANDOMSIZE) 
-         ap->ys = MIN(MINRANDOMSIZE,
-              MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
+			if (ap->ys < MINRANDOMSIZE)
+				ap->ys = MIN(MINRANDOMSIZE,
+					     MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE));
 		} else if (size < MINSIZE) {
 			if (!size)
 				ap->ys = MAX(MINSIZE, MIN(ap->width, ap->height) / MINGRIDSIZE);
@@ -1002,7 +1003,7 @@ init_ant(ModeInfo * mi)
 		getTurk(mi, (int) (NRAND(NUMSTIPPLES - 1)));
 	if (MI_NPIXELS(mi) > 2)
 		for (i = 0; i < (int) ap->ncolors - 1; i++)
-			ap->colors[i] = (NRAND(MI_NPIXELS(mi)) +
+			ap->colors[i] = (unsigned char) (NRAND(MI_NPIXELS(mi)) +
 			     i * MI_NPIXELS(mi)) / ((int) (ap->ncolors - 1));
 	if (ap->ants == NULL)
 		ap->ants = (antstruct *) malloc(ap->n * sizeof (antstruct));
@@ -1039,6 +1040,8 @@ draw_ant(ModeInfo * mi)
 	unsigned char color;
 	short       chg_dir, old_dir;
 
+	MI_IS_DRAWN(mi) = True;
+
 	ap->painted = True;
 	for (i = 0; i < ap->n; i++) {
 		anant = &ap->ants[i];
@@ -1089,9 +1092,6 @@ draw_ant(ModeInfo * mi)
 		draw_anant(mi, anant->col, anant->row);
 	}
 	if (++ap->generation > MI_CYCLES(mi)) {
-#ifdef STANDALONE
-		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
-#endif
 		init_ant(mi);
 	}
 	if (ap->redrawing) {
