@@ -68,10 +68,12 @@ static const char sccsid[] = "@(#)bat.c	4.07 97/11/24 xlockmore";
  "*ncolors: 200 \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#include "vis.h"
+#include "color.h"
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt bat_opts =
 {0, NULL, 0, NULL, NULL};
@@ -530,6 +532,8 @@ draw_bat(ModeInfo * mi)
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < bp->nbats; i++) {
 		drawabat(mi, &bp->bats[i]);
 		movebat(bp, &bp->bats[i]);
