@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)bouboule.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 15-May-97: jwz@netscape.com: turned into a standalone program.
+ * 15-May-97: jwz@jwz.org: turned into a standalone program.
  * 04-Sep-96: Added 3d support Henrik Theiling <theiling@coli-uni-sb.de>
  * 20-Feb-96: Added tests so that already malloced objects are not
  *            malloced twice, thanks to the report from <mccomb@interport.net>
@@ -573,6 +573,8 @@ draw_bouboule(ModeInfo * mi)
 	/* star in 3d mode, otherwise 0 */
 #endif
 
+	MI_IS_DRAWN(mi) = True;
+
 #if ((USEOLDXARCS == 0) || (ADAPT_ERASE == 1))
 	if (MI_IS_USE3D(mi)) {
 		maxdiff = (int) MAXDIFF;
