@@ -157,14 +157,6 @@ typedef struct {
 
 static bouncestruct *bounces = NULL;
 
-static void checkCollision(bouncestruct * bp, int aball);
-static void drawball(ModeInfo * mi, ballstruct * ball);
-static void moveball(ModeInfo * mi, ballstruct * ball);
-static void spinball(ballstruct * ball, int dir, int *vel, int avgsize);
-static int  collide(bouncestruct * bp, int aball);
-static void bounce_windows(ModeInfo * mi, bouncestruct * bs);
-
-
 static void
 checkCollision(bouncestruct * bp, int aball)
 {
@@ -259,6 +251,19 @@ drawball(ModeInfo * mi, ballstruct * ball)
 	}
 }
 
+static void
+spinball(ballstruct * ball, int dir, int *vel, int avgsize)
+{
+	*vel -= (int) ((*vel + SIGN(*vel * dir) *
+		ball->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
+	if (*vel) {
+		ball->spindir = DIR(*vel * dir);
+		ball->vang = *vel * ORIENTCYCLE;
+		ball->spindelay = (int) ((double) M_PI * avgsize / (ABS(ball->vang))) + 1;
+	} else
+		ball->spindir = 0;
+}
+
 #define BETWEEN(x, xmin, xmax) (((x) >= (xmin)) && ((x) <= (xmax)))
 static void
 hit_left_wall(ModeInfo * mi, ballstruct * ball,
@@ -366,19 +371,6 @@ moveball(ModeInfo * mi, ballstruct * ball)
 	}
 }
 
-static void
-spinball(ballstruct * ball, int dir, int *vel, int avgsize)
-{
-	*vel -= (int) ((*vel + SIGN(*vel * dir) *
-		ball->spindelay * ORIENTCYCLE / (M_PI * avgsize)) / SLIPAGE);
-	if (*vel) {
-		ball->spindir = DIR(*vel * dir);
-		ball->vang = *vel * ORIENTCYCLE;
-		ball->spindelay = (int) ((double) M_PI * avgsize / (ABS(ball->vang))) + 1;
-	} else
-		ball->spindir = 0;
-}
-
 static int
 collide(bouncestruct * bp, int aball)
 {
@@ -394,6 +386,61 @@ collide(bouncestruct * bp, int aball)
 	return i;
 }
 
+static void
+bounce_windows(ModeInfo * mi, bouncestruct * bs)
+{
+	Window      root, parent, *children;
+	unsigned int nchildren;
+	int         i;
+	int         n;
+
+	if (!MI_IS_INROOT(mi)) {
+		bs->nwindow = 0;
+		return;
+	}
+	if (XQueryTree(MI_DISPLAY(mi), MI_WINDOW(mi),
+		       &root, &parent, &children, &nchildren) == 0) {	/* failure */
+		bs->nwindow = 0;
+		return;
+	}
+	bs->nwindow = nchildren;
+	if (bs->windows != NULL) {
+		(void) free((void *) bs->windows);
+	}
+	bs->windows = (ballwindow *) malloc(bs->nwindow * sizeof (ballwindow));
+	for (n = 0, i = 0; i < bs->nwindow; i++) {
+		XWindowAttributes att;
+
+/*-
+   May give
+   X Error of failed request: BadWindow (invalid Window parameter)
+   Major opcode of failed request:  3 (X_GetWindowAttributes)
+ */
+		if (XGetWindowAttributes(MI_DISPLAY(mi), children[i], &att) == 0) {	/* failure */
+			bs->nwindow = 0;
+			return;
+		}
+		if ((att.x < 0) || (att.x > bs->width) ||
+		    (att.y < 0) || (att.y > bs->height) ||
+#if defined(__cplusplus) || defined(c_plusplus)
+		    (att.c_class != InputOutput) ||
+#else
+		    (att.class != InputOutput) ||
+#endif
+		    (att.map_state != IsViewable)) {
+			continue;
+		}
+		bs->windows[n].x = att.x;
+		bs->windows[n].y = att.y;
+		bs->windows[n].width = att.width;
+		bs->windows[n].height = att.height;
+		n++;
+	}
+	bs->nwindow = n;
+	XFree((caddr_t) children);
+	return;
+}
+
 void
 init_bounce(ModeInfo * mi)
 {
@@ -503,6 +550,8 @@ draw_bounce(ModeInfo * mi)
 	bouncestruct *bp = &bounces[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < bp->nballs; i++) {
 		drawball(mi, &bp->balls[i]);
 		moveball(mi, &bp->balls[i]);
@@ -545,58 +594,3 @@ refresh_bounce(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 	bounce_windows(mi, bp);
 }
-
-static void
-bounce_windows(ModeInfo * mi, bouncestruct * bs)
-{
-	Window      root, parent, *children;
-	unsigned int nchildren;
-	int         i;
-	int         n;
-
-	if (!MI_IS_INROOT(mi)) {
-		bs->nwindow = 0;
-		return;
-	}
-	if (XQueryTree(MI_DISPLAY(mi), MI_WINDOW(mi),
-		       &root, &parent, &children, &nchildren) == 0) {	/* failure */
-		bs->nwindow = 0;
-		return;
-	}
-	bs->nwindow = nchildren;
-	if (bs->windows != NULL) {
-		(void) free((void *) bs->windows);
-	}
-	bs->windows = (ballwindow *) malloc(bs->nwindow * sizeof (ballwindow));
-	for (n = 0, i = 0; i < bs->nwindow; i++) {
-		XWindowAttributes att;
-
-/*-
-   May give
-   X Error of failed request: BadWindow (invalid Window parameter)
-   Major opcode of failed request:  3 (X_GetWindowAttributes)
- */
-		if (XGetWindowAttributes(MI_DISPLAY(mi), children[i], &att) == 0) {	/* failure */
-			bs->nwindow = 0;
-			return;
-		}
-		if ((att.x < 0) || (att.x > bs->width) ||
-		    (att.y < 0) || (att.y > bs->height) ||
-#if defined(__cplusplus) || defined(c_plusplus)
-		    (att.c_class != InputOutput) ||
-#else
-		    (att.class != InputOutput) ||
-#endif
-		    (att.map_state != IsViewable)) {
-			continue;
-		}
-		bs->windows[n].x = att.x;
-		bs->windows[n].y = att.y;
-		bs->windows[n].width = att.width;
-		bs->windows[n].height = att.height;
-		n++;
-	}
-	bs->nwindow = n;
-	XFree((caddr_t) children);
-	return;
-}
