@@ -25,7 +25,7 @@ static const char sccsid[] = "@(#)braid.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 10-May-97: Jamie Zawinski <jwz@netscape.com> compatible with xscreensaver
+ * 10-May-97: Jamie Zawinski <jwz@jwz.org> compatible with xscreensaver
  * 01-Sep-95: color knotted components differently, J. Neil.
  * 29-Aug-95: Written.  John Neil <neil@math.idbsu.edu>
  */
@@ -42,7 +42,6 @@ static const char sccsid[] = "@(#)braid.c	4.07 97/11/24 xlockmore";
  "*ncolors: 64 \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"
-#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"
 
@@ -85,7 +84,7 @@ ModStruct   braid_description =
 #define FLOATRAND(min,max) ((min)+((double) LRAND()/((double) MAXRAND))*((max)-(min)))
 
 typedef struct {
-  int         linewidth;
+	int         linewidth;
 	int         braidword[MAXLENGTH];
 	int         components[MAXSTRANDS];
 	int         startcomp[MAXLENGTH][MAXSTRANDS];
@@ -275,10 +274,12 @@ draw_braid(ModeInfo * mi)
 	float       x_1, y_1, x_2, y_2, r1, r2;
 	float       color, color_use = 0.0, color_inc;
 
+	MI_IS_DRAWN(mi) = True;
+
 	XSetLineAttributes(display, MI_GC(mi), braid->linewidth,
-		LineSolid,
-	  (braid->linewidth <= 3 ? CapButt : CapRound),
-	  JoinMiter);
+			   LineSolid,
+			   (braid->linewidth <= 3 ? CapButt : CapRound),
+			   JoinMiter);
 
 	theta = (2.0 * M_PI) / (float) (braid->braidlength);
 	t_inc = (2.0 * M_PI) / (float) num_points;
@@ -420,10 +421,6 @@ draw_braid(ModeInfo * mi)
 	XSetLineAttributes(display, MI_GC(mi), 1, LineSolid, CapNotLast, JoinRound);
 
 	if (++braid->age > MI_CYCLES(mi)) {
-#ifdef STANDALONE
-		erase_full_window(display, window);
-#endif
-
 		init_braid(mi);
 	}
 }
