@@ -45,11 +45,11 @@ static const char sccsid[] = "@(#)bug.c	4.07 97/11/24 xlockmore";
  "*size: -4 \n" \
  "*ncolors: 64 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
+#include "automata.h"
 
 ModeSpecOpt bug_opts =
 {0, NULL, 0, NULL, NULL};
@@ -631,7 +631,7 @@ makebacteria(ModeInfo * mi,
 		if (!bp->arr[colrow] && !bp->bacteria[colrow]) {
 			i++;
 			bp->bacteria[colrow] = True;
-	    drawabacterium(mi, hcol, hrow, True);
+			drawabacterium(mi, hcol, hrow, draw);
 		}
 	}
 }
@@ -803,11 +803,11 @@ init_bug(ModeInfo * mi)
 		}
 	}
 	makebacteria(mi, bp->nhcols * bp->nhrows / 2, 0, 0, bp->nhcols, bp->nhrows,
-     False);
+		     False);
 	if (bp->eden)
 		makebacteria(mi, bp->edenwidth * bp->edenheight / 2,
-			     bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight,
-           False);
+		bp->edenstartx, bp->edenstarty, bp->edenwidth, bp->edenheight,
+			     False);
 	bp->redrawing = 1;
 	bp->redrawpos = 0;
 }
@@ -819,6 +819,8 @@ draw_bug(ModeInfo * mi)
 	bugfarmstruct *bp = &bugfarms[MI_SCREEN(mi)];
 	int         hcol, hrow, nhcol, nhrow, colrow, ncolrow, absdir, tryit;
 
+	MI_IS_DRAWN(mi) = True;
+
 	bp->painted = True;
 	bp->currbug = bp->firstbug->next;
 	while (bp->currbug != bp->lastbug) {
