@@ -81,11 +81,12 @@ puzzle.c has the same disease.
 #define DEFAULTS "*delay: 10000 \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
-
+#include "vis.h"
+#include "color.h"
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 #if defined( USE_XPM ) || defined( USE_XPMINC )
 
@@ -377,6 +378,8 @@ draw_cartoon(ModeInfo * mi)
 {
 	cartoonstruct *cp = &cartoons[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (cp->success) {
 		put_cartoon(mi);
 		move_cartoon(mi);
