@@ -134,7 +134,8 @@ drawpetals(ModeInfo * mi, XPoint center,
 	if (MI_NPIXELS(mi) > GREEN + NOTGREEN) {
 		do {
 			colour = NRAND(MI_NPIXELS(mi));
-		} while (colour >= GREEN - NOTGREEN && colour <= GREEN + NOTGREEN);
+		} while ((long) colour >= GREEN - NOTGREEN &&
+			 (long) colour <= GREEN + NOTGREEN);
 	}
 	start_angle = NRAND(360) * M_PI / 180;
 	inc_angle = 2 * M_PI / petals;
@@ -189,7 +190,8 @@ drawcenter(ModeInfo * mi, XPoint center, int size, unsigned long petalcolour)
 			/* Insure good contrast */
 			colour = (NRAND(2 * MI_NPIXELS(mi) / 3) + petalcolour +
 				  MI_NPIXELS(mi) / 6) % MI_NPIXELS(mi);
-		} while (colour >= GREEN - NOTGREEN && colour <= GREEN + NOTGREEN);
+		} while ((long) colour >= GREEN - NOTGREEN &&
+			 (long) colour <= GREEN + NOTGREEN);
 		XSetForeground(display, gc, MI_PIXEL(mi, colour));
 	} else
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
@@ -277,6 +279,8 @@ draw_daisy(ModeInfo * mi)
 {
 	daisystruct *dp = &daisies[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (dp->time < dp->ndaisies)
 		drawdaisy(mi);
 	if (++dp->time > MI_CYCLES(mi))
