@@ -6,7 +6,7 @@ static const char sccsid[] = "@(#)deco.c 4.07 97/11/24 xlockmore";
 
 #endif
 /* 
- * Copyright (c) 1997 by Jamie Zawinski <jwz@netscape.com>
+ * Copyright (c) 1997 by Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -22,12 +22,12 @@ static const char sccsid[] = "@(#)deco.c 4.07 97/11/24 xlockmore";
  *
  * Revision History:
  * 29-Oct-97: xlock version (David Bagley <bagleyd@bigfoot.com>)
- * 1997: xscreensaver version Jamie Zawinski <jwz@netscape.com>
+ * 1997: xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
  * original copyright
- * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -167,6 +167,9 @@ draw_deco(ModeInfo * mi)
 	}
 	if (++dp->time > MI_CYCLES(mi))
 		init_deco(mi);
+
+	MI_IS_DRAWN(mi) = True;
+
 }
 
 void
