@@ -28,7 +28,9 @@ static const char sccsid[] = "@(#)demon.c	4.07 97/11/24 xlockmore";
  *            Fixed memory management that caused leaks
  * 14-Apr-96: -neighbors 6 runtime-time option added
  * 21-Aug-95: Coded from A.K. Dewdney's "Computer Recreations", Scientific
- *            American Magazine" Aug 1989 pp 102-105.
+ *            American Magazine" Aug 1989 pp 102-105.  Also very similar to
+ *            hodgepodge machine described in A.K. Dewdney's "Computer
+ *            Recreations", Scientific American Magazine" Aug 1988 pp 104-107.
  *            also used life.c as a guide.
  */
 
@@ -57,11 +59,11 @@ static const char sccsid[] = "@(#)demon.c	4.07 97/11/24 xlockmore";
  "*neighbors: 0 \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
+#include "automata.h"
 
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
@@ -163,7 +165,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned char state)
 			    dp->shape.hexagon, 6, Convex, CoordModePrevious);
 	} else if (dp->neighbors == 4 || dp->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-		dp->xb + dp->xs * col, dp->yb + dp->ys * row, dp->xs, dp->ys);
+		dp->xb + dp->xs * col, dp->yb + dp->ys * row,
+		dp->xs - (dp->xs > 3), dp->ys - (dp->ys > 3));
 	} else {		/* TRI */
 		int         orient = (col + row) % 2;	/* O left 1 right */
 
@@ -320,8 +323,8 @@ draw_state(ModeInfo * mi, int state)
 		while (current) {
 			rects[ncells].x = dp->xb + current->pt.x * dp->xs;
 			rects[ncells].y = dp->yb + current->pt.y * dp->ys;
-			rects[ncells].width = dp->xs;
-			rects[ncells].height = dp->ys;
+			rects[ncells].width = dp->xs - (dp->xs > 3);
+			rects[ncells].height = dp->ys - (dp->ys > 3);
 			current = current->next;
 			ncells++;
 		}
@@ -527,6 +530,8 @@ draw_demon(ModeInfo * mi)
 	demonstruct *dp = &demons[MI_SCREEN(mi)];
 	int         i, j, k, l, mj = 0, ml;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (dp->state >= dp->states) {
 		(void) memcpy((char *) dp->newcell, (char *) dp->oldcell,
 			      dp->ncols * dp->nrows * sizeof (unsigned char));
