@@ -54,6 +54,7 @@ static const char sccsid[] = "@(#)eyes.c	4.07 97/11/24 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt eyes_opts =
 {0, NULL, 0, NULL, NULL};
@@ -168,7 +169,7 @@ typedef struct {		/* per-screen info */
 	Eyes       *eyes;
 	Fly         fly;
 	Cursor      cursor;
-	int         time;
+	unsigned long time;
 } EyeScrInfo;
 
 /* ---------------------------------------------------------------------- */
@@ -938,7 +939,9 @@ init_eyes(ModeInfo * mi)
 		Pixmap      bit;
 		XColor      black;
 
-		black.red = black.green = black.blue = 0;
+		black.red = 0;
+		black.green = 0;
+		black.blue = 0;
 		black.flags = DoRed | DoGreen | DoBlue;
 		bit = XCreatePixmapFromBitmapData(display, window, "\000", 1, 1,
 						  MI_BLACK_PIXEL(mi),
@@ -964,6 +967,8 @@ draw_eyes(ModeInfo * mi)
 	EyeScrInfo *ep = &eye_info[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (!stuff_alloced) {
 		/* if startup init didn't finish, do nothing */
 		return;
