@@ -26,7 +26,7 @@ static const char sccsid[] = "@(#)flag.c	4.07 97/11/24 xlockmore";
  *
  * Revision History: 
  * 24-Oct-97: xpm and ras capability added.
- * 13-May-97: jwz@netscape.com: turned into a standalone program.
+ * 13-May-97: jwz@jwz.org: turned into a standalone program.
  *            Made it able to animate arbitrary (runtime) text or bitmaps
  * 15-May-96: written.
  */
@@ -50,6 +50,11 @@ static const char sccsid[] = "@(#)flag.c	4.07 97/11/24 xlockmore";
 #define DEF_TEXT ""
 #include "xlockmore.h"		/* in xscreensaver distribution */
 
+#else /* STANDALONE */
+#include "xlock.h"		/* in xlockmore distribution */
+#include "color.h"
+#endif /* STANDALONE */
+
 /* This makes me laugh :) */
 #ifdef JWZ
 /*-
@@ -80,10 +85,6 @@ static const char sccsid[] = "@(#)flag.c	4.07 97/11/24 xlockmore";
 #include "iostuff.h"
 #endif
 
-#else /* STANDALONE */
-#include "xlock.h"		/* in xlockmore distribution */
-#endif /* STANDALONE */
-
 #define DEF_INVERT  "False"
 
 static Bool invert;
@@ -438,7 +439,7 @@ init_flag(ModeInfo * mi)
 	if (MI_IS_FULLRANDOM(mi) ||
 	    (MI_BITMAP(mi) && *(MI_BITMAP(mi)) && message && *message) ||
 	((!(MI_BITMAP(mi)) || !*(MI_BITMAP(mi))) && (!message || !*message)))
-		fp->choice = LRAND() & 1;
+		fp->choice = (int) (LRAND() & 1);
 	else if (MI_BITMAP(mi) && *(MI_BITMAP(mi)))
 		fp->choice = IMAGE_FLAG;
 	else
@@ -512,6 +513,8 @@ draw_flag(ModeInfo * mi)
 	Window      window = MI_WINDOW(mi);
 	flagstruct *fp = &flags[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (fp->width <= MAXW(fp) || fp->height <= MAXH(fp)) {
 		fp->size = MININITSIZE;
 		/* fp->pointsize = MINPOINTSIZE; */
