@@ -79,22 +79,22 @@ typedef struct {
 	int         cycles;
 	int         alt;
 	XPoint      pts[MAXBATCH];
+	short       lasthalf;
 } flamestruct;
 
 static flamestruct *flames = NULL;
 
 static short
-halfrandom(int mv)
+halfrandom(flamestruct * fp, int mv)
 {
-	static short lasthalf = 0;
 	unsigned long r;
 
-	if (lasthalf) {
-		r = lasthalf;
-		lasthalf = 0;
+	if (fp->lasthalf) {
+		r = fp->lasthalf;
+		fp->lasthalf = 0;
 	} else {
 		r = LRAND();
-		lasthalf = r >> 16;
+		fp->lasthalf = (short) (r >> 16);
 	}
 	return r % mv;
 }
@@ -276,7 +276,7 @@ init_flame(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 
 	if (MI_NPIXELS(mi) > 2) {
-		fp->pixcol = halfrandom(MI_NPIXELS(mi));
+		fp->pixcol = halfrandom(fp, MI_NPIXELS(mi));
 		XSetForeground(display, gc, MI_PIXEL(mi, fp->pixcol));
 	} else {
 		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
@@ -304,6 +304,8 @@ draw_flame(ModeInfo * mi)
 		}
 	}
 
+	MI_IS_DRAWN(mi) = True;
+
 	/* number of functions */
 	fp->snum = 2 + (fp->cur_level % (MAXLEV - 1));
 
@@ -311,7 +313,7 @@ draw_flame(ModeInfo * mi)
 	if (fp->alt)
 		fp->anum = 0;
 	else
-		fp->anum = halfrandom(fp->snum) + 2;
+		fp->anum = halfrandom(fp, fp->snum) + 2;
 
 	/* 6 coefs per function */
 	for (k = 0; k < fp->snum; k++) {
