@@ -43,7 +43,6 @@ static const char sccsid[] = "@(#)flow.c 4.10 98/04/24 xlockmore";
  "*ncolors: 200 \n"
 #define SMOOTH_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "erase.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
@@ -98,7 +97,7 @@ typedef struct {
 	double      phi;
 	double      dphi;
 	void        (*ODE) (Par par, double *dx, double *dy, double *dz,
-        double x, double y, double z, double t);
+			    double x, double y, double z, double t);
 	Par         par;
 } flowstruct;
 
@@ -106,7 +105,7 @@ static flowstruct *flows = NULL;
 
 static void
 Lorentz(Par par, double *dx, double *dy, double *dz,
-        double x, double y, double z, double t)
+	double x, double y, double z, double t)
 {
 	*dx = par.a * (y - x);
 	*dy = x * (par.b - z) - y;
@@ -115,7 +114,7 @@ Lorentz(Par par, double *dx, double *dy, double *dz,
 
 static void
 Rossler(Par par, double *dx, double *dy, double *dz,
-        double x, double y, double z, double t)
+	double x, double y, double z, double t)
 {
 	*dx = -(y + par.a * z);
 	*dy = x + y * par.b;
@@ -124,7 +123,7 @@ Rossler(Par par, double *dx, double *dy, double *dz,
 
 static void
 RosslerCone(Par par, double *dx, double *dy, double *dz,
-            double x, double y, double z, double t)
+	    double x, double y, double z, double t)
 {
 	*dx = -(y + par.a * z);
 	*dy = x + y * par.b - z * z * par.c;
@@ -301,6 +300,8 @@ draw_flow(ModeInfo * mi)
 	for (col = 0; col < MI_NPIXELS(mi); col++)
 		sp->cnsegs[col] = 0;
 
+	MI_IS_DRAWN(mi) = True;
+
 	/* <=- Bees -=> */
 	for (b = 0; b < sp->beecount; b++) {
 		/* Age the arrays. */
@@ -346,10 +347,10 @@ draw_flow(ModeInfo * mi)
 		col = b % (MI_NPIXELS(mi) - 1);
 
 		ix = col * sp->beecount + sp->cnsegs[col];
-		sp->csegs[ix].x1 = DISPLAYX(0);
-		sp->csegs[ix].y1 = DISPLAYY(0);
-		sp->csegs[ix].x2 = DISPLAYX(1);
-		sp->csegs[ix].y2 = DISPLAYY(1);
+		sp->csegs[ix].x1 = (short) DISPLAYX(0);
+		sp->csegs[ix].y1 = (short) DISPLAYY(0);
+		sp->csegs[ix].x2 = (short) DISPLAYX(1);
+		sp->csegs[ix].y2 = (short) DISPLAYY(1);
 		sp->cnsegs[col]++;
 	}
 	if (sp->count) {
@@ -370,8 +371,8 @@ draw_flow(ModeInfo * mi)
 		/* mono */
 		XSetForeground(display, gc, MI_PIXEL(mi, 1));
 		XDrawSegments(display, window, gc,
-			sp->csegs + col * sp->beecount, sp->cnsegs[col]);
-  }
+			    sp->csegs + col * sp->beecount, sp->cnsegs[col]);
+	}
 
 	for (col = 0, c = 0; col < MI_NPIXELS(mi); col++)
 		for (b = 0; b < sp->cnsegs[col]; b++) {
@@ -384,9 +385,6 @@ draw_flow(ModeInfo * mi)
 			c++;
 		}
 	if (++sp->count > MI_CYCLES(mi)) {
-#ifdef STANDALONE
-		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
-#endif /* STANDALONE */
 		init_flow(mi);
 	}
 }
