@@ -186,7 +186,7 @@ static void
 startover(ModeInfo * mi)
 {
 	unistruct  *gp = &universes[MI_SCREEN(mi)];
-	int         size = MI_SIZE(mi);
+	int         size = (int) MI_SIZE(mi);
 	int         i, j;	/* more tmp */
 	double      w1, w2;	/* more tmp */
 	double      d, v, w, h;	/* yet more tmp */
@@ -343,6 +343,8 @@ draw_galaxy(ModeInfo * mi)
 	double      d;		/* tmp */
 	int         i, j, k;	/* more tmp */
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < gp->ngalaxies; ++i) {
 		Galaxy     *gt = &gp->galaxies[i];
 
