@@ -35,12 +35,12 @@ struct glb_config glb_config =
 	-4,			/* screen_bottom */
 	4,			/* screen_top */
 #if 0
-	{0.1, 0.0, 0.4, 0},	/* bg_colour */
+	{0.1, 0.0, 0.4, 0.0},	/* bg_colour */
 #else
-	{0.0, 0.0, 0.0, 0},	/* bg_colour */
+	{0.0, 0.0, 0.0, 0.0},	/* bg_colour */
 #endif
 #if 0
-	{0.7, 0.7, 0, 0.3}	/* bubble_colour */
+	{0.7, 0.7, 0.0, 0.3}	/* bubble_colour */
 #else
 	{0.0, 0.0, 0.7, 0.3}	/* bubble_colour */
 #endif
@@ -54,6 +54,7 @@ struct glb_config glb_config =
 #include "xlockmore.h"
 #else
 #include "xlock.h"
+#include "vis.h"
 #endif
 
 #ifdef USE_GL
@@ -120,7 +121,7 @@ init_bubble3d(ModeInfo * mi)
 	struct context *c;
 
 	if (contexts == 0) {
-		contexts = malloc(sizeof (struct context) * MI_NUM_SCREENS(mi));
+		contexts = (struct context *) malloc(sizeof (struct context) * MI_NUM_SCREENS(mi));
 
 		if (contexts == 0)
 			return;
@@ -144,6 +145,8 @@ draw_bubble3d(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (!c->glx_context)
 		return;
 
@@ -166,8 +169,8 @@ release_bubble3d(ModeInfo * mi)
 {
 	struct context *c = &contexts[MI_SCREEN(mi)];
 
-	glb_draw_end(c->draw_context);
 	if (contexts != 0) {
+		glb_draw_end(c->draw_context);
 		(void) free((void *) contexts);
 		contexts = 0;
 	}
