@@ -69,7 +69,7 @@ static const char sccsid[] = "@(#)pipes.c	4.07 97/11/24 xlockmore";
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-
+#include "vis.h"
 #endif /* !STANDALONE */
 
 #ifdef USE_GL
@@ -694,6 +694,8 @@ draw_pipes(ModeInfo * mi)
 	int         newdir;
 	int         OPX, OPY, OPZ;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (!pp->glx_context)
 		return;
 
