@@ -71,7 +71,7 @@ static const char sccsid[] = "@(#)stairs.c	4.07 97/11/24 xlockmore";
 #include "xlockmore.h"		/* from the xscreensaver distribution */
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
-
+#include "vis.h"
 #endif /* !STANDALONE */
 
 #ifdef USE_GL
@@ -322,7 +322,7 @@ draw_stairs_internal(ModeInfo * mi)
 		mySphere(0.5);
 	glPopMatrix();
 	sp->sphere_position += 3;
-	if (sp->sphere_position >= NPOSITIONS)
+	if (sp->sphere_position >= (int) NPOSITIONS)
 		sp->sphere_position = 0;
 }
 
@@ -424,6 +424,8 @@ draw_stairs(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (!sp->glx_context)
 		return;
 
