@@ -23,12 +23,12 @@ static const char sccsid[] = "@(#)goop.c  4.10 98/03/24 xlockmore";
  *
  * Revision History:
  * 24-Mar-98: xlock version David Bagley <bagleyd@bigfoot.com>
- * 1997:      xscreensaver version Jamie Zawinski <jwz@netscape.com>
+ * 1997:      xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
  * original copyright
- * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -74,7 +74,8 @@ static const char sccsid[] = "@(#)goop.c  4.10 98/03/24 xlockmore";
 #define HACK_INIT init_goop
 #define HACK_DRAW draw_goop
 #define goop_opts xlockmore_opts
-#define DEFAULTS "*delay: 40000 \n"
+#define DEFAULTS "*delay: 40000 \n" \
+ "*count: 100 \n"
 /*-  Come back to this.
   "*delay:		12000",
 "*transparent:	true",
@@ -86,7 +87,6 @@ static const char sccsid[] = "@(#)goop.c  4.10 98/03/24 xlockmore";
 "*torque:		0.0075",
 "*elasticity:		1.8",
 "*maxVelocity:	1.2",
-"*count: 100 \n"
  */
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
@@ -102,7 +102,7 @@ ModeSpecOpt goop_opts =
 ModStruct   goop_description =
 {"goop", "init_goop", "draw_goop", "release_goop",
  "refresh_goop", "init_goop", NULL, &goop_opts,
- 10000, -12, 1, 1, 64, 1.0, "",
+ 10000, -5, 1, 1, 64, 1.0, "",
  "Shows goop from a lava lamp", 0, NULL};
 
 #endif
@@ -124,11 +124,11 @@ typedef struct {
 	long        min_r, max_r;	/* radius range */
 	int         npoints;	/* control points */
 	long       *r;		/* radii */
-	spline     *spline;
+	spline     *splines;
 } blob;
 
 typedef struct {
-	int         nblobs;
+	int         nblobs;	/* number of blops per plane */
 	blob       *blobs;
 	Pixmap      pixmap;
 	unsigned long pixel;
@@ -158,7 +158,7 @@ static void
 make_blob(blob * b, int maxx, int maxy, int size)
 {
 	int         i;
-	int         mid;
+	long        mid;
 
 	maxx *= SCALE;
 	maxy *= SCALE;
@@ -172,8 +172,8 @@ make_blob(blob * b, int maxx, int maxy, int size)
 	mid = ((b->min_r + b->max_r) / 2);
 
 	b->torque = 0.0075;	/* torque init */
-	b->elasticity = SCALE * 1.8;	/* elasticity init */
-	b->max_velocity = SCALE * 1.2;	/* max_velocity init */
+	b->elasticity = (long) (SCALE * 1.8);	/* elasticity init */
+	b->max_velocity = (long) (SCALE * 1.2);		/* max_velocity init */
 
 	b->x = NRAND(maxx);
 	b->y = NRAND(maxy);
@@ -181,9 +181,9 @@ make_blob(blob * b, int maxx, int maxy, int size)
 	b->dx = NRAND(b->max_velocity) * RANDSIGN();
 	b->dy = NRAND(b->max_velocity) * RANDSIGN();
 	b->th = (2.0 * M_PI) * LRAND() / MAXRAND * RANDSIGN();
-	b->npoints = (LRAND() % 5) + 5;
+	b->npoints = (int) (LRAND() % 5) + 5;
 
-	b->spline = make_spline(b->npoints);
+	b->splines = make_spline(b->npoints);
 	b->r = (long *) malloc(sizeof (*b->r) * b->npoints);
 	for (i = 0; i < b->npoints; i++)
 		b->r[i] = ((LRAND() % mid) + (mid / 2)) * RANDSIGN();
@@ -202,11 +202,11 @@ throb_blob(blob * b)
 		long        x, y;
 
 		/* place control points evenly around perimiter, shifted by theta */
-		x = b->x + ra * cos(i * frac + th);
-		y = b->y + ra * sin(i * frac + th);
+		x = b->x + (long) (ra * cos(i * frac + th));
+		y = b->y + (long) (ra * sin(i * frac + th));
 
-		b->spline->control_x[i] = x / SCALE;
-		b->spline->control_y[i] = y / SCALE;
+		b->splines->control_x[i] = x / SCALE;
+		b->splines->control_y[i] = y / SCALE;
 
 		/* alter the radius by a random amount, in the direction in which
 		   it had been going (the sign of the radius indicates direction.) */
@@ -280,22 +280,22 @@ static void
 draw_blob(Display * display, Drawable drawable, GC gc, blob * b,
 	  Bool fill_p)
 {
-	compute_closed_spline(b->spline);
+	compute_closed_spline(b->splines);
 #ifdef DEBUG
 	{
 		int         i;
 
 		for (i = 0; i < b->npoints; i++)
 			XDrawLine(display, drawable, gc, b->x / SCALE, b->y / SCALE,
-			   b->spline->control_x[i], b->spline->control_y[i]);
+			 b->splines->control_x[i], b->splines->control_y[i]);
 	}
 #else
 	if (fill_p)
-		XFillPolygon(display, drawable, gc, b->spline->points, b->spline->n_points,
+		XFillPolygon(display, drawable, gc, b->splines->points, b->splines->n_points,
 			     Nonconvex, CoordModeOrigin);
 	else
 #endif
-		XDrawLines(display, drawable, gc, b->spline->points, b->spline->n_points,
+		XDrawLines(display, drawable, gc, b->splines->points, b->splines->n_points,
 			   CoordModeOrigin);
 }
 
@@ -315,7 +315,7 @@ make_layer(ModeInfo * mi, layer * l, int nblobs)
 	blob_min = (blob_max * 2) / 3;
 	for (i = 0; i < l->nblobs; i++)
 		make_blob(&(l->blobs[i]), width, height,
-			  (LRAND() % (blob_max - blob_min)) + blob_min);
+			  (int) (LRAND() % (blob_max - blob_min)) + blob_min);
 
 	l->pixmap = XCreatePixmap(MI_DISPLAY(mi), MI_WINDOW(mi), width, height, 1);
 	l->gc = XCreateGC(MI_DISPLAY(mi), l->pixmap, 0, &gcv);
@@ -364,7 +364,7 @@ free_goop(Display * display, goopstruct * gp)
 				for (b = 0; b < gp->layers[l].nblobs; b++) {
 					if (gp->layers[l].blobs[b].r)
 						(void) free((void *) gp->layers[l].blobs[b].r);
-					free_spline(gp->layers[l].blobs[b].spline);
+					free_spline(gp->layers[l].blobs[b].splines);
 				}
 				(void) free((void *) gp->layers[l].blobs);
 			}
@@ -394,7 +394,7 @@ init_goop(ModeInfo * mi)
 	goopstruct *gp;
 	int         i;
 	XGCValues   gcv;
-	int         nblobs = 3;	/* batchount init */
+	int         nblobs;
 
 	unsigned long *plane_masks = 0;
 	unsigned long base_pixel = 0;
@@ -417,7 +417,7 @@ init_goop(ModeInfo * mi)
 
 	gp->nlayers = 0;	/* planes init */
 	if (gp->nlayers <= 0)
-		gp->nlayers = (LRAND() % (MI_DEPTH(mi) - 2)) + 2;
+		gp->nlayers = (int) (LRAND() % (MI_DEPTH(mi) - 2)) + 2;
 	gp->layers = (layer *) calloc(gp->nlayers, sizeof (layer));
 
 
@@ -437,7 +437,7 @@ init_goop(ModeInfo * mi)
 			gp->nlayers = nplanes;
 		else {
 			(void) fprintf(stderr,
-				"could not allocate any color planes; turning transparency off.\n");
+				       "could not allocate any color planes; turning transparency off.\n");
 			gp->mode = opaque;
 		}
 	}
@@ -446,10 +446,14 @@ init_goop(ModeInfo * mi)
 		gp->mode = opaque;
 #endif
 
-	{
+	nblobs = MI_COUNT(mi);
+	if (nblobs < 0) {
+		nblobs = NRAND(-nblobs) + 1;	/* Add 1 so its not too boring */
+	} {
 		int         lblobs[32];
 		int         total = DEF_COUNT;
 
+		/* What does this do? DAB */
 		if (nblobs <= 0)
 			while (total)
 				for (i = 0; total && i < gp->nlayers; i++)
@@ -482,13 +486,13 @@ init_goop(ModeInfo * mi)
 		}
 	}
 	gp->pixmap = XCreatePixmap(display, window, MI_WIDTH(mi), MI_HEIGHT(mi),
-				   (gp->mode == xor ? 1L : MI_DEPTH(mi)));
+				   (gp->mode == xor ? 1 : MI_DEPTH(mi)));
 
 	gcv.background = gp->background;
 	gcv.foreground = 255;	/* init */
 	gcv.line_width = 5;	/* thickness init */
 	gp->pixmap_gc = XCreateGC(display, gp->pixmap, GCLineWidth, &gcv);
-  MI_CLEARWINDOW(mi);
+	MI_CLEARWINDOW(mi);
 }
 
 void
@@ -499,6 +503,8 @@ draw_goop(ModeInfo * mi)
 	goopstruct *gp = &goops[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	switch (gp->mode) {
 		case transparent:
 
