@@ -1,8 +1,8 @@
 /* -*- Mode: C; tab-width: 4 -*- */
-/* hyper --- spinning hypercubes, not just tesseracts any more */
+/* hyper --- spinning hypercubes, not just for tesseracts any more */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)hyper.c 4.11 98/05/27 xlockmore";
+static const char sccsid[] = "@(#)hyper.c 4.12 98/08/04 xlockmore";
 
 #endif
 
@@ -48,23 +48,36 @@ static const char sccsid[] = "@(#)hyper.c 4.11 98/05/27 xlockmore";
  * trade secrets or any patents by this file or any part thereof.  In no
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
+ * 
+ * Check out A.K. Dewdney's "Computer Recreations", Scientific American
+ * Magazine" Apr 1986 pp 14-25 for more info.
+ * Idea on 3d taken from there but does not work yet.  Also a small number of
+ * random chosen planes drawn may be nice.
  *
+ * Revision History:
+ * 04-Aug-98: Added "3d" support from Scientific American
  */
 
 #ifdef STANDALONE
-#define PROGCLASS "Hyperer"
+#define PROGCLASS "Hyper"
 #define HACK_INIT init_hyper
 #define HACK_DRAW draw_hyper
 #define HACK_CHANGE change_hyper
 #define hyper_opts xlockmore_opts
 #define DEFAULTS "*delay: 100000 \n" \
-	"*count: -6 \n" \
-	"*cycles: 300 \n" \
-	"*ncolors: 200 \n" \
-	"*spinDelay:	2 \n" \
-	"*showAxes:	false \n" \
-	"*randomStart:	false \n" \
-	"*debug:	false \n"
+ "*count: -6 \n" \
+ "*cycles: 300 \n" \
+ "*ncolors: 200 \n" \
+ "*use3d: False \n" \
+ "*delta3d: 1.5 \n" \
+ "*right3d: red \n" \
+ "*left3d: blue \n" \
+ "*both3d: magenta \n" \
+ "*none3d: black \n" \
+ "*spinDelay:	2 \n" \
+ "*showAxes:	false \n" \
+ "*randomStart:	false \n" \
+ "*debug:	false \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -74,7 +87,7 @@ static Bool random_start;
 static Bool show_axes;
 static int  spin_delay;
 
-extern XFontStruct *getFont();
+extern XFontStruct *getFont(Display * display);
 
 static XrmOptionDescRec opts[] =
 {
@@ -119,6 +132,9 @@ typedef double matrix;		/* Was a double array of size (MAX_D + 1) ^ 2 */
 #define MIN_D 2
 #define MAX_D 10		/* Memory use goes up exponentially */
 
+/* Normally DELTA3D is not in degrees, but it works here, so why fight it? */
+#define DELDEG (MI_DELTA3D(mi)*M_PI/180.0)
+
 typedef struct {
 	int         from, to;
 	long        color;
@@ -126,7 +142,7 @@ typedef struct {
 
 
 typedef struct hyper {
-	GC          xorGC;
+	GC          gc;
 	Bool        redrawing;
 	Bool        painted;
 	XFontStruct *font;
@@ -136,6 +152,7 @@ typedef struct hyper {
 	int         maxx, maxy;
 	int         delay;
 	int         spinDelay;
+	Bool        normxor;
 
 	/*
 	 * Data storage.
@@ -154,16 +171,20 @@ typedef struct hyper {
 	double     *dd_rotations;	/* change in change in rotation */
 	int        *cdd_rotations;	/* how many turns to apply dd_rotations */
 	matrix     *Trotations;
+	matrix     *Trotationsleft;
 
 	matrix     *Tall;
+	matrix     *Tallleft;
 
 	int         num_points;
 	vector     *points;
+	vector     *pointsleft;
 	int         num_lines;
 	line_segment *lines;
 
 	int         point_set;	/* which bank of points are we using */
 	XPoint     *xpoints[2];
+	XPoint     *xpointsleft[2];
 
 	int         num_axis_points;
 
@@ -201,7 +222,7 @@ MatMult(matrix * a, matrix * b, matrix * c, int n)
 			for (k = 0; k < n; k++)
 				temp += a[i * n + k] * b[k * n + j];
 			c[i * n + j] = temp;
-		};
+		}
 }
 
 static void
@@ -216,7 +237,7 @@ MatVecMult(matrix * a, vector * b, vector * c, int n)
 		for (k = 0; k < n; k++)
 			temp += a[i * n + k] * b[k];
 		c[i] = temp;
-	};
+	}
 }
 
 static void
@@ -302,8 +323,9 @@ figure_num_planes(int d)
 }
 
 static void
-figure_points(ModeInfo * mi, hyperstruct * hp)
+figure_points(ModeInfo * mi)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	int         i, j, k, n, d, pix = 0;
 	int        *c;
 
@@ -315,13 +337,21 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 	hp->points = allocarray(vector, hp->num_points * hp->num_mat);
 	hp->xpoints[0] = allocarray(XPoint, hp->num_points);
 	hp->xpoints[1] = allocarray(XPoint, hp->num_points);
+	if (MI_IS_USE3D(mi)) {
+		hp->pointsleft = allocarray(vector, hp->num_points * hp->num_mat);
+		hp->xpointsleft[0] = allocarray(XPoint, hp->num_points);
+		hp->xpointsleft[1] = allocarray(XPoint, hp->num_points);
+	}
 	c = allocarray(int, hp->num_points);	/* will be lost, sigh */
 
 	ZeroMultiCounter(c, hp->num_d);
 	n = 0;
 	do {
-		for (i = 0; i < hp->num_d; i++)
+		for (i = 0; i < hp->num_d; i++) {
 			hp->points[n * hp->num_mat + i] = c[i];
+			if (MI_IS_USE3D(mi))
+				hp->pointsleft[n * hp->num_mat + i] = c[i];
+		}
 		n++;
 	} while (IncMultiCounter(c, hp->num_d));
 	(void) free((void *) c);
@@ -340,15 +370,16 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 	hp->num_lines = figure_num_lines(hp->num_d);
 	/* assert(hp->num_lines <= hp->max_lines); */
 	hp->lines = (line_segment *) malloc(hp->num_lines * sizeof (line_segment));
-	for (n = i = 0; i < hp->num_points; i++)
+	for (n = i = 0; i < hp->num_points; i++) {
 		for (j = i + 1; j < hp->num_points; j++) {
-			for (d = k = 0; k < hp->num_d; k++)
+			for (d = k = 0; k < hp->num_d; k++) {
 				if (hp->points[i * hp->num_mat + k] != hp->points[j * hp->num_mat + k])
 					d++;
+			}
 			if (d == 1) {
 				hp->lines[n].from = i;
 				hp->lines[n].to = j;
-				/* printf ("from %x to %x ", i, j); */
+				/* (void) printf ("from %x to %x ", i, j); */
 				if (MI_NPIXELS(mi) > 2) {
 					hp->lines[n].color = MI_PIXEL(mi, pix);
 					if (++pix >= MI_NPIXELS(mi))
@@ -356,8 +387,9 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 				} else
 					hp->lines[n].color = MI_WHITE_PIXEL(mi);
 				n++;
-			};
-		};
+			}
+		}
+	}
 #if 0
 	assert(hp->num_lines == n);
 #endif
@@ -380,6 +412,10 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 	hp->Trotations = allocarray(matrix, hp->num_planes * hp->num_matmat);
 	hp->Tall = allocarray(matrix, hp->num_matmat);
 
+	if (MI_IS_USE3D(mi)) {
+		hp->Trotationsleft = allocarray(matrix, hp->num_planes * hp->num_matmat);
+		hp->Tallleft = allocarray(matrix, hp->num_matmat);
+	}
 	hp->rotation_planes = allocarray(XPoint, hp->num_planes);
 
 	for (n = i = 0; i < hp->num_d; i++)
@@ -387,7 +423,7 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 			hp->rotation_planes[n].x = i;
 			hp->rotation_planes[n].y = j;
 			n++;
-		};
+		}
 #if 0
 	assert(hp->num_planes == n);
 #endif
@@ -398,10 +434,9 @@ figure_points(ModeInfo * mi, hyperstruct * hp)
 	if (random_start) {
 		for (i = 0; i < hp->num_planes; i++)
 			hp->rotations[i] = 2.0 * NRAND(FRAC) * M_PI / FRAC;
-	};
+	}
 }
 
-
 static void
 figure_axis_points(hyperstruct * hp)
 {
@@ -428,6 +463,10 @@ free_hyper(hyperstruct * hp)
 		(void) free((void *) hp->points);
 		hp->points = NULL;
 	}
+	if (hp->pointsleft) {
+		(void) free((void *) hp->pointsleft);
+		hp->pointsleft = NULL;
+	}
 	if (hp->lines) {
 		XFree(hp->lines);
 		hp->lines = NULL;
@@ -456,10 +495,18 @@ free_hyper(hyperstruct * hp)
 		(void) free((void *) hp->Trotations);
 		hp->Trotations = NULL;
 	}
+	if (hp->Trotationsleft) {
+		(void) free((void *) hp->Trotationsleft);
+		hp->Trotationsleft = NULL;
+	}
 	if (hp->Tall) {
 		(void) free((void *) hp->Tall);
 		hp->Tall = NULL;
 	}
+	if (hp->Tallleft) {
+		(void) free((void *) hp->Tallleft);
+		hp->Tallleft = NULL;
+	}
 	if (hp->xpoints[0]) {
 		XFree(hp->xpoints[0]);
 		hp->xpoints[0] = NULL;
@@ -468,13 +515,21 @@ free_hyper(hyperstruct * hp)
 		XFree(hp->xpoints[1]);
 		hp->xpoints[1] = NULL;
 	}
+	if (hp->xpointsleft[0]) {
+		XFree(hp->xpointsleft[0]);
+		hp->xpointsleft[0] = NULL;
+	}
+	if (hp->xpointsleft[1]) {
+		XFree(hp->xpointsleft[1]);
+		hp->xpointsleft[1] = NULL;
+	}
 }
 
 static void
-init_x_stuff(ModeInfo * mi, hyperstruct * hp)
+init_x_stuff(ModeInfo * mi)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	XGCValues   gcv;
-	int         options;
 
 	hp->maxx = MI_WIDTH(mi);
 	hp->maxy = MI_HEIGHT(mi);
@@ -501,101 +556,166 @@ init_x_stuff(ModeInfo * mi, hyperstruct * hp)
 	if (!hp->font)
 		hp->font = getFont(MI_DISPLAY(mi));
 
-	if (!hp->xorGC) {
-		options = GCForeground | GCFont | GCFunction;
-		gcv.foreground = MI_WHITE_PIXEL(mi) ^ MI_BLACK_PIXEL(mi);
+	if (MI_NPIXELS(mi) <= 2 || MI_IS_USE3D(mi))
+		hp->normxor = False;
+	if (!hp->gc && (MI_NPIXELS(mi) <= 2 || !MI_IS_USE3D(mi))) {
+		long        options;
+
+		if (hp->normxor) {
+			options = GCForeground | GCFont | GCFunction;
+			gcv.foreground = MI_WHITE_PIXEL(mi) ^ MI_BLACK_PIXEL(mi);
+			gcv.function = GXxor;
+		} else {
+			options = GCForeground | GCBackground | GCFont;
+			gcv.foreground = MI_WHITE_PIXEL(mi);
+			gcv.background = MI_BLACK_PIXEL(mi);
+		}
 		gcv.font = hp->font->fid;
-		gcv.function = GXxor;
-		hp->xorGC = XCreateGC(MI_DISPLAY(mi), MI_WINDOW(mi), options, &gcv);
+		hp->gc = XCreateGC(MI_DISPLAY(mi), MI_WINDOW(mi), options, &gcv);
 	}
 }
 
 static void
-move_line(ModeInfo * mi, int from, int to, int set, int color)
+move_line(ModeInfo * mi, int from, int to, int set, long color)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	GC          gc = MI_GC(mi);
 	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 
-	if (MI_NPIXELS(mi) <= 2) {
+	if (MI_NPIXELS(mi) <= 2 || !MI_IS_USE3D(mi))
+		gc = hp->gc;
+	if (hp->normxor) {
+		XSetForeground(display, gc, color);
+		if (!hp->redrawing)
+			XDrawLine(display, window, gc,
+			hp->xpoints[!set][from].x, hp->xpoints[!set][from].y,
+			   hp->xpoints[!set][to].x, hp->xpoints[!set][to].y);
+		XDrawLine(display, window, gc,
+			  hp->xpoints[set][from].x, hp->xpoints[set][from].y,
+			  hp->xpoints[set][to].x, hp->xpoints[set][to].y);
+	} else {
 		if (!hp->redrawing) {
-			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			if (MI_IS_INSTALL(mi) && MI_IS_USE3D(mi))
+				XSetForeground(display, gc, MI_NONE_COLOR(mi));
+			else
+				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 			XDrawLine(display, window, gc,
 			  hp->xpoints[set][from].x, hp->xpoints[set][from].y,
-			  hp->xpoints[set][to].x, hp->xpoints[set][to].y);
+			     hp->xpoints[set][to].x, hp->xpoints[set][to].y);
+			if (MI_IS_USE3D(mi))
+				XDrawLine(display, window, gc,
+					  hp->xpointsleft[set][from].x, hp->xpointsleft[set][from].y,
+					  hp->xpointsleft[set][to].x, hp->xpointsleft[set][to].y);
 		}
-		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+		if (MI_IS_USE3D(mi)) {
+			if (MI_IS_INSTALL(mi)) {
+				XSetFunction(display, gc, GXor);
+			}
+			XSetForeground(display, gc, MI_LEFT_COLOR(mi));
+		} else if (MI_NPIXELS(mi) <= 2)
+			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+		else
+			XSetForeground(display, gc, color);
 		XDrawLine(display, window, gc,
 			hp->xpoints[!set][from].x, hp->xpoints[!set][from].y,
-			   hp->xpoints[!set][to].x, hp->xpoints[!set][to].y);
-	} else {
-		XSetForeground(display, hp->xorGC, color);
-		if (!hp->redrawing)
-			XDrawLine(display, window, hp->xorGC,
-			hp->xpoints[!set][from].x, hp->xpoints[!set][from].y,
-			   hp->xpoints[!set][to].x, hp->xpoints[!set][to].y);
-		XDrawLine(display, window, hp->xorGC,
-			  hp->xpoints[set][from].x, hp->xpoints[set][from].y,
-			  hp->xpoints[set][to].x, hp->xpoints[set][to].y);
+			  hp->xpoints[!set][to].x, hp->xpoints[!set][to].y);
+		if (MI_IS_USE3D(mi)) {
+			XSetForeground(display, gc, MI_RIGHT_COLOR(mi));
+			XDrawLine(display, window, gc,
+				  hp->xpointsleft[!set][from].x, hp->xpointsleft[!set][from].y,
+				  hp->xpointsleft[!set][to].x, hp->xpointsleft[!set][to].y);
+			if (MI_IS_INSTALL(mi)) {
+				XSetFunction(display, gc, GXcopy);
+			}
+		}
 	}
 }
 
-
 static void
-move_number(ModeInfo * mi, int axis, char *string, int set, int color)
+move_number(ModeInfo * mi, int axis, char *string, int set, long color)
 {
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	GC          gc = MI_GC(mi);
 	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 
-	if (MI_NPIXELS(mi) <= 2) {
+	if (MI_NPIXELS(mi) <= 2 || !MI_IS_USE3D(mi))
+		gc = hp->gc;
+	if (hp->normxor) {
+		XSetForeground(display, gc, color);
+		if (!hp->redrawing)
+			XDrawString(display, window, gc,
+			hp->xpoints[!set][axis].x, hp->xpoints[!set][axis].y,
+				    string, strlen(string));
+		XDrawString(display, window, gc,
+			  hp->xpoints[set][axis].x, hp->xpoints[set][axis].y,
+			    string, strlen(string));
+	} else {
 		if (!hp->redrawing) {
-			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			if (MI_IS_INSTALL(mi) && MI_IS_USE3D(mi))
+				XSetForeground(display, gc, MI_NONE_COLOR(mi));
+			else
+				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 			XDrawString(display, window, gc,
 			  hp->xpoints[set][axis].x, hp->xpoints[set][axis].y,
 				    string, strlen(string));
+			if (MI_IS_USE3D(mi))
+				XDrawString(display, window, gc,
+					    hp->xpointsleft[set][axis].x, hp->xpointsleft[set][axis].y,
+					    string, strlen(string));
 		}
-		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+		if (MI_IS_USE3D(mi)) {
+			if (MI_IS_INSTALL(mi)) {
+				XSetFunction(display, gc, GXor);
+			}
+			XSetForeground(display, gc, MI_LEFT_COLOR(mi));
+		} else if (MI_NPIXELS(mi) <= 2)
+			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+		else
+			XSetForeground(display, gc, color);
 		XDrawString(display, window, gc,
 			hp->xpoints[!set][axis].x, hp->xpoints[!set][axis].y,
 			    string, strlen(string));
-	} else {
-		XSetForeground(display, hp->xorGC, color);
-		if (!hp->redrawing)
-			XDrawString(display, window, hp->xorGC,
-			hp->xpoints[!set][axis].x, hp->xpoints[!set][axis].y,
+		if (MI_IS_USE3D(mi)) {
+			XSetForeground(display, gc, MI_RIGHT_COLOR(mi));
+			XDrawString(display, window, gc,
+				    hp->xpointsleft[!set][axis].x, hp->xpointsleft[!set][axis].y,
 				    string, strlen(string));
-		XDrawString(display, window, hp->xorGC,
-			  hp->xpoints[set][axis].x, hp->xpoints[set][axis].y,
-			    string, strlen(string));
+			if (MI_IS_INSTALL(mi)) {
+				XSetFunction(display, gc, GXcopy);
+			}
+		}
 	}
 }
 
 static void
-draw_hyper_step(ModeInfo * mi, hyperstruct * hp, int set)
+draw_hyper_step(ModeInfo * mi, int set)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	int         i;
 	char        tmps[3];
 
-	if (!hp->stationary || hp->redrawing) {
-	for (i = 0; i < hp->num_lines; i++) {
-		move_line(mi, hp->lines[i].from, hp->lines[i].to, set, hp->lines[i].color);
-	}
+	MI_IS_DRAWN(mi) = True;
 
-	if (hp->show_axes_p) {
-		for (i = 0; i < hp->num_axis_points; i++) {
-			sprintf(tmps, "%d", i);
-			move_number(mi, hp->axis_points[i], tmps, set, MI_WHITE_PIXEL(mi));
+	if (!hp->stationary || hp->redrawing) {
+		for (i = 0; i < hp->num_lines; i++) {
+			move_line(mi, hp->lines[i].from, hp->lines[i].to, set, hp->lines[i].color);
+		}
+
+		if (hp->show_axes_p) {
+			for (i = 0; i < hp->num_axis_points; i++) {
+				(void) sprintf(tmps, "%d", i);
+				move_number(mi, hp->axis_points[i], tmps, set, MI_WHITE_PIXEL(mi));
+			}
 		}
-	}
 	}
 }
 
 static void
-move_hyper(ModeInfo * mi, hyperstruct * hp)
+move_hyper(ModeInfo * mi)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	int         i;
 
 /* NEEDSWORK: These should be resources */
@@ -618,7 +738,7 @@ move_hyper(ModeInfo * mi, hyperstruct * hp)
 			if (hp->d_rotations[i] != 0.0 || hp->cdd_rotations[i]) {
 				hp->stationary = False;
 				break;
-			};
+			}
 		if (NRAND(3) < 1 + hp->stationary) {
 			/* Change!  But what? */
 			max_axis = hp->num_planes;
@@ -640,11 +760,10 @@ move_hyper(ModeInfo * mi, hyperstruct * hp)
 					(hp->dd_rotations[axis] >= 0.0 ? 1 : -1) *
 					(faster ? 1 : -1);
 			if (MI_IS_DEBUG(mi))
-				fprintf(stderr,
-					"axis %d made %s\n", axis, faster ? "faster" : "slower");
-		};
-	};
-
+				(void) fprintf(stderr,
+					       "axis %d made %s\n", axis, faster ? "faster" : "slower");
+		}
+	}
 	/*
 	 * Rotate.
 	 */
@@ -652,29 +771,21 @@ move_hyper(ModeInfo * mi, hyperstruct * hp)
 		if (hp->cdd_rotations[i]) {
 			hp->cdd_rotations[i]--;
 			hp->d_rotations[i] += hp->dd_rotations[i];
-		};
+		}
 		hp->rotations[i] += hp->d_rotations[i];
-	};
+	}
 }
 
-#define NEED_SINCOS
-#ifdef NEED_SINCOS
 static void
-sincos(double a, double *s, double *c)
-{
-	*s = sin(a);
-	*c = cos(a);
-}
-
-#endif /* NEED_SINCOS */
-
-static void
-calc_transformation(hyperstruct * hp)
+calc_transformation(ModeInfo * mi)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	double      cosa, sina;
+	double      cosb = 0.0, sinb = 0.0;
 	int         p1, p2;
 	matrix     *Ttmp;
-	matrix     *Tpre, *Tuser, *Tpretranspose, *Tscale, *Tposttranspose;
+	matrix     *Tpre, *Tuser, *Tuserleft = NULL;
+	matrix     *Tpretranspose, *Tscale, *Tposttranspose;
 	int         i;
 	dpoint      scale, range, offset;
 	double      scale_used;
@@ -682,6 +793,9 @@ calc_transformation(hyperstruct * hp)
 	Ttmp = allocarray(matrix, hp->num_matmat);
 	Tpre = allocarray(matrix, hp->num_matmat);
 	Tuser = allocarray(matrix, hp->num_matmat);
+	if (MI_IS_USE3D(mi)) {
+		Tuserleft = allocarray(matrix, hp->num_matmat);
+	}
 	Tpretranspose = allocarray(matrix, hp->num_matmat);
 	Tscale = allocarray(matrix, hp->num_matmat);
 	Tposttranspose = allocarray(matrix, hp->num_matmat);
@@ -694,17 +808,29 @@ calc_transformation(hyperstruct * hp)
 	MatIdent(Tpre, hp->num_mat);
 	for (i = 0; i < hp->num_d; i++) {
 		Tpre[i * hp->num_mat + hp->num_d] = -0.5;
-	};
+	}
 
 
 	/*
 	 * Figure the rotation.
 	 */
 	MatIdent(Tuser, hp->num_mat);
+	if (MI_IS_USE3D(mi)) {
+		MatIdent(Tuserleft, hp->num_mat);
+	}
 	for (i = 0; i < hp->num_planes; i++) {
 		p1 = hp->rotation_planes[i].x;
 		p2 = hp->rotation_planes[i].y;
-		sincos(hp->rotations[i], &sina, &cosa);
+		if (MI_IS_USE3D(mi)) {
+			sinb = sin(hp->rotations[i] - DELDEG);
+			cosb = cos(hp->rotations[i] - DELDEG);
+			sina = sin(hp->rotations[i] + DELDEG);
+			cosa = cos(hp->rotations[i] + DELDEG);
+		} else {
+			sina = sin(hp->rotations[i]);
+			cosa = cos(hp->rotations[i]);
+		}
+
 		MatIdent(&hp->Trotations[i * hp->num_matmat], hp->num_mat);
 		hp->Trotations[i * hp->num_matmat + p1 * hp->num_mat + p1] =
 			hp->Trotations[i * hp->num_matmat + p2 * hp->num_mat + p2] = cosa;
@@ -712,7 +838,17 @@ calc_transformation(hyperstruct * hp)
 		hp->Trotations[i * hp->num_matmat + p2 * hp->num_mat + p1] = -sina;
 		MatMult(&hp->Trotations[i * hp->num_matmat], Tuser, Ttmp, hp->num_mat);
 		MatCopy(Ttmp, Tuser, hp->num_mat);
-	};
+
+		if (MI_IS_USE3D(mi)) {
+			MatIdent(&hp->Trotationsleft[i * hp->num_matmat], hp->num_mat);
+			hp->Trotationsleft[i * hp->num_matmat + p1 * hp->num_mat + p1] =
+				hp->Trotationsleft[i * hp->num_matmat + p2 * hp->num_mat + p2] = cosb;
+			hp->Trotationsleft[i * hp->num_matmat + p1 * hp->num_mat + p2] = sinb;
+			hp->Trotationsleft[i * hp->num_matmat + p2 * hp->num_mat + p1] = -sinb;
+			MatMult(&hp->Trotationsleft[i * hp->num_matmat], Tuserleft, Ttmp, hp->num_mat);
+			MatCopy(Ttmp, Tuserleft, hp->num_mat);
+		}
+	}
 
 /* Now calculate the scaling matrix */
 #if 1
@@ -725,7 +861,8 @@ calc_transformation(hyperstruct * hp)
 	 * This principle generalizes to sqrt(hp->num_d).
 	 */
 #define border_width (0.05)
-	range.x = range.y = sqrt((double) hp->num_d);
+	range.x = sqrt((double) hp->num_d);
+	range.y = range.x;
 	scale.x = (1.0 - 2 * border_width) * hp->maxx / range.x;
 	scale.y = (1.0 - 2 * border_width) * hp->maxy / range.y;
 	scale_used = ((scale.x < scale.y) ? scale.x : scale.y);
@@ -752,30 +889,34 @@ calc_transformation(hyperstruct * hp)
 #else
 	MatIdent(Tscale, hp->num_mat);
 #endif
+	(void) free((void *) Tpretranspose);
+	(void) free((void *) Tposttranspose);
 
 	/*
 	 * Put it all together.
 	 */
 	MatMult(Tuser, Tpre, Ttmp, hp->num_mat);
 	MatMult(Tscale, Ttmp, hp->Tall, hp->num_mat);
-
-	(void) free((void *) Ttmp);
-	(void) free((void *) Tpre);
 	(void) free((void *) Tuser);
-	(void) free((void *) Tpretranspose);
+	if (MI_IS_USE3D(mi)) {
+		MatMult(Tuserleft, Tpre, Ttmp, hp->num_mat);
+		MatMult(Tscale, Ttmp, hp->Tallleft, hp->num_mat);
+		(void) free((void *) Tuserleft);
+	}
+	(void) free((void *) Tpre);
+	(void) free((void *) Ttmp);
 	(void) free((void *) Tscale);
-	(void) free((void *) Tposttranspose);
 }
 
 
 static void
-translate_point(hyperstruct * hp, vector * real, XPoint * screen_image)
+translate_point(hyperstruct * hp, matrix * Tall, vector * real, XPoint * screen_image)
 {
 	vector     *image;
 
 	image = allocarray(vector, hp->num_mat);
 
-	MatVecMult(hp->Tall, real, image, hp->num_mat);
+	MatVecMult(Tall, real, image, hp->num_mat);
 	screen_image->x = (short) image[0];
 	screen_image->y = (short) image[1];
 
@@ -783,14 +924,17 @@ translate_point(hyperstruct * hp, vector * real, XPoint * screen_image)
 }
 
 static void
-translate_points(hyperstruct * hp, int set)
+translate_points(ModeInfo * mi, int set)
 {
+	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 	int         i;
 
-	calc_transformation(hp);
+	calc_transformation(mi);
 	for (i = 0; i < hp->num_points; i++) {
-		translate_point(hp, &hp->points[i * hp->num_mat], &hp->xpoints[set][i]);
-	};
+		translate_point(hp, hp->Tall, &hp->points[i * hp->num_mat], &hp->xpoints[set][i]);
+		if (MI_IS_USE3D(mi))
+			translate_point(hp, hp->Tallleft, &hp->pointsleft[i * hp->num_mat], &hp->xpointsleft[set][i]);
+	}
 }
 
 void
@@ -799,11 +943,11 @@ refresh_hyper(ModeInfo * mi)
 	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
 
 	if (!hp->painted) {
-	MI_CLEARWINDOW(mi);
-	hp->redrawing = True;
-	draw_hyper_step(mi, hp, hp->this_set);
-	hp->redrawing = False;
-	hp->painted = True;
+		MI_CLEARWINDOW(mi);
+		hp->redrawing = True;
+		draw_hyper_step(mi, hp->this_set);
+		hp->redrawing = False;
+		hp->painted = True;
 	}
 }
 
@@ -820,23 +964,26 @@ init_hyper(ModeInfo * mi)
 	}
 	hp = &hypers[MI_SCREEN(mi)];
 
-	init_x_stuff(mi, hp);
+	init_x_stuff(mi);
 
-	figure_points(mi, hp);
+	figure_points(mi);
 
 	/*
 	 * Fix the d+1 coord of all points.
 	 */
-	for (i = 0; i < hp->num_points; i++)
+	for (i = 0; i < hp->num_points; i++) {
 		hp->points[i * hp->num_mat + hp->num_d] = 1;
+		if (MI_IS_USE3D(mi))
+			hp->pointsleft[i * hp->num_mat + hp->num_d] = 1;
+	}
 
 	figure_axis_points(hp);
 
 	hp->this_set = 0;
-	translate_points(hp, !hp->this_set);
-	translate_points(hp, hp->this_set);
+	translate_points(mi, !hp->this_set);
+	translate_points(mi, hp->this_set);
 	refresh_hyper(mi);
-        hp->painted = True;
+	hp->painted = True;
 	hp->stationary = True;
 }
 
@@ -845,14 +992,15 @@ void
 draw_hyper(ModeInfo * mi)
 {
 	hyperstruct *hp = &hypers[MI_SCREEN(mi)];
-        hp->painted = False;
-	draw_hyper_step(mi, hp, hp->this_set);
+
+	hp->painted = False;
+	draw_hyper_step(mi, hp->this_set);
 
 	/* Set up next place */
-	move_hyper(mi, hp);
-	translate_points(hp, hp->this_set);
-        if (!hp->stationary)
-	hp->this_set = !hp->this_set;
+	move_hyper(mi);
+	translate_points(mi, hp->this_set);
+	if (!hp->stationary)
+		hp->this_set = !hp->this_set;
 }
 
 void
@@ -873,8 +1021,8 @@ release_hyper(ModeInfo * mi)
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++) {
 			hyperstruct *hp = &hypers[screen];
 
-			if (hp->xorGC != NULL)
-				XFreeGC(MI_DISPLAY(mi), hp->xorGC);
+			if (hp->gc != NULL)
+				XFreeGC(MI_DISPLAY(mi), hp->gc);
 			if (hp->font)
 				XFreeFont(MI_DISPLAY(mi), hp->font);
 			free_hyper(hp);
