@@ -40,10 +40,11 @@ static const char sccsid[] = "@(#)image.c	4.07 97/11/24 xlockmore";
  "*ncolors: 200 \n" \
  "*bitmap: \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#include "color.h"
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt image_opts =
 {0, NULL, 0, NULL, NULL};
@@ -211,6 +212,8 @@ draw_image(ModeInfo * mi)
 	imagestruct *ip = &ims[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	XSetForeground(display, ip->backGC, ip->black);
 	for (i = 0; i < ip->iconcount; i++) {
 		if ((ip->ncols * ip->nrows > ip->iconcount) && ip->icons[i].x >= 0)
