@@ -21,9 +21,12 @@ static const char sccsid[] = "@(#)julia.c	4.07 97/11/24 xlockmore";
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
  *
+ * Check out  A.K. Dewdney's "Computer Recreations", Scientific
+ * American Magazine" Nov 1987.
+ *
  * Revision History:
- * 28-May-97: jwz@netscape.com: added interactive frobbing with the mouse.
- * 10-May-97: jwz@netscape.com: turned into a standalone program.
+ * 28-May-97: jwz@jwz.org: added interactive frobbing with the mouse.
+ * 10-May-97: jwz@jwz.org: turned into a standalone program.
  * 02-Dec-95: snagged boilerplate from hop.c
  *           used ifs {w0 = sqrt(x-c), w1 = -sqrt(x-c)} with random iteration 
  *           to plot the julia set, and sinusoidially varied parameter for set 
@@ -164,7 +167,7 @@ init_julia(ModeInfo * mi)
 	Window      window = MI_WINDOW(mi);
 	juliastruct *jp;
 	XGCValues   gcv;
-	int         i;
+	int         i, j;
 
 	if (julias == NULL) {
 		if ((julias = (juliastruct *) calloc(MI_NUM_SCREENS(mi),
@@ -184,7 +187,9 @@ init_julia(ModeInfo * mi)
 		Pixmap      bit;
 		XColor      black;
 
-		black.red = black.green = black.blue = 0;
+		black.red = 0;
+		black.green = 0;
+		black.blue = 0;
 		black.flags = DoRed | DoGreen | DoBlue;
 		bit = XCreatePixmapFromBitmapData(display, window, "\000", 1, 1,
 						  MI_BLACK_PIXEL(mi),
@@ -230,15 +235,15 @@ init_julia(ModeInfo * mi)
 	if (MI_NPIXELS(mi) > 2)
 		jp->pix = NRAND(MI_NPIXELS(mi));
 	jp->inc = NRAND(400) - 200;
-	jp->nbuffers = (MI_CYCLES(mi) + 1);
+	jp->nbuffers = MI_CYCLES(mi) + 1;
 	if (!jp->pointBuffer)
 		jp->pointBuffer = (XPoint **) calloc(jp->nbuffers, sizeof (XPoint *));
-	for (i = 0; i < jp->nbuffers; ++i)
-		if (jp->pointBuffer[i])
-			(void) memset((char *) jp->pointBuffer[i], 0,
-				      numpoints * sizeof (XPoint));
-		else
-			jp->pointBuffer[i] = (XPoint *) calloc(numpoints, sizeof (XPoint));
+	for (i = 0; i < jp->nbuffers; ++i) {
+		if (!jp->pointBuffer[i])
+			jp->pointBuffer[i] = (XPoint *) malloc(numpoints * sizeof (XPoint));
+		for (j = 0; j < numpoints; j++)
+			jp->pointBuffer[i][j].x = jp->pointBuffer[i][j].y = -1;		/* move initial point off screen */
+	}
 	jp->buffer = 0;
 	jp->redrawing = 0;
 	jp->erase = 0;
@@ -258,6 +263,8 @@ draw_julia(ModeInfo * mi)
 	int         k = 64, rnd = 0, i, j;
 	XPoint     *xp = jp->pointBuffer[jp->buffer], old_circle, new_circle;
 
+	MI_IS_DRAWN(mi) = True;
+
 	old_circle.x = (int) (jp->centerx * jp->cr / 2) + jp->centerx - 2;
 	old_circle.y = (int) (jp->centery * jp->ci / 2) + jp->centery - 2;
 	incr(mi, jp);
@@ -291,7 +298,7 @@ draw_julia(ModeInfo * mi)
 		/* save calls to LRAND by using bit shifts over and over on the same
 		   int for 32 iterations, then get a new random int */
 		if (!(k % 32))
-			rnd = LRAND();
+			rnd = (int) LRAND();
 
 		/* complex sqrt: x^0.5 = radius^0.5*(cos(theta/2) + i*sin(theta/2)) */
 
