@@ -72,7 +72,7 @@ static const char sccsid[] = "@(#)kaleid.c  4.11 98/06/01 xlockmore";
  "*linear: False \n" \
  "*quad: False \n" \
  "*oct: False \n"
- "*fullrandom: False \n"
+"*fullrandom: False \n"
 #define UNIFORM_COLORS
 #define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
@@ -96,8 +96,8 @@ static Bool Linear;
 
 static XrmOptionDescRec opts[] =
 {
-    {"-disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "on"},
-    {"+disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "off"},
+   {"-disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "on"},
+  {"+disconnected", ".kaleid.disconnected", XrmoptionNoArg, (caddr_t) "off"},
 	{"-serial", ".kaleid.serial", XrmoptionNoArg, (caddr_t) "on"},
 	{"+serial", ".kaleid.serial", XrmoptionNoArg, (caddr_t) "off"},
 	{"-alternate", ".kaleid.alternate", XrmoptionNoArg, (caddr_t) "on"},
@@ -114,7 +114,7 @@ static argtype vars[] =
 {
 	{(caddr_t *) & Disconnected, "disconnected", "Disconnected", DEF_DISCONNECTED, t_Bool},
 	{(caddr_t *) & Serial, "serial", "Serial", DEF_SERIAL, t_Bool},
-   {(caddr_t *) & Alternate, "alternate", "Alternate", DEF_ALTERNATE, t_Bool},
+  {(caddr_t *) & Alternate, "alternate", "Alternate", DEF_ALTERNATE, t_Bool},
 	{(caddr_t *) & Quad, "quad", "Quad", DEF_QUAD, t_Bool},
 	{(caddr_t *) & Oct, "oct", "Oct", DEF_OCT, t_Bool},
 	{(caddr_t *) & Linear, "linear", "Linear", DEF_LINEAR, t_Bool}
@@ -179,10 +179,10 @@ typedef struct {
 	double      yv;
 	int         curlwidth;
 	int         pix;
-    int         White;
-    Bool        RadiusOut;
-    Bool        AngleOut;
-    Bool        DeferredChange;
+	int         White;
+	Bool        RadiusOut;
+	Bool        AngleOut;
+	Bool        DeferredChange;
 } penstruct;
 
 typedef struct {
@@ -198,7 +198,7 @@ typedef struct {
 	double      slice;
 	int         bouncetype;
 	int         modetype;
-    Bool        alternate, disconnected, serial, linear;
+	Bool        alternate, disconnected, serial, linear;
 } kaleidstruct;
 
 static kaleidstruct *kaleids = NULL;
@@ -318,8 +318,8 @@ QuadRotated(
  */
 static void
 GeneralPolarMoveAndBounce(
-						  kaleidstruct * kp,
-						  int pn
+				 kaleidstruct * kp,
+				 int pn
 )
 {
 	kp->pen[pn].cx = kp->pen[pn].cx + kp->pen[pn].xv;
@@ -358,19 +358,19 @@ GeneralPolarMoveAndBounce(
 	}
 
 	if (kp->pen[pn].cy < 0) {
-        kp->pen[pn].RadiusOut = True;
+		kp->pen[pn].RadiusOut = True;
 		if (kp->pen[pn].oy >= 0) {
 			kp->pen[pn].yv = -kp->pen[pn].yv;
 		}
 	} else if (kp->pen[pn].cy >= kp->slice) {
-        kp->pen[pn].RadiusOut = True;
+		kp->pen[pn].RadiusOut = True;
 		if (kp->pen[pn].oy < kp->slice) {
 			kp->pen[pn].yv = -kp->pen[pn].yv;
 		}
 	} else {
-        kp->pen[pn].RadiusOut = False;
+		kp->pen[pn].RadiusOut = False;
 	}
-	  
+
 }
 
 
@@ -388,7 +388,7 @@ GeneralRotated(
 	int         segnum;
 
 
-    GeneralPolarMoveAndBounce(kp,pn);
+	GeneralPolarMoveAndBounce(kp, pn);
 
 	Angle = 0.0;
 	for (segnum = 0; segnum < kp->modetype; segnum += 1) {
@@ -426,7 +426,7 @@ GeneralMirrored(
 	double      Angle;
 	int         segnum;
 
-    GeneralPolarMoveAndBounce(kp,pn);
+	GeneralPolarMoveAndBounce(kp, pn);
 
 	Angle = 0.0;
 	for (segnum = 0; segnum < kp->modetype; segnum += 2) {
@@ -582,16 +582,16 @@ OctMirrored(
 #if 0
 static void
 OldOctRotated(
-			  kaleidstruct * kp,
-			  int pn,
-			  XSegment * segs
+		     kaleidstruct * kp,
+		     int pn,
+		     XSegment * segs
 )
 {
-    double      angle,radius;
-    double      oangle,oradius;
-    double      rv,av;
-	double      perp,para;
-    int         i;
+	double      angle, radius;
+	double      oangle, oradius;
+	double      rv, av;
+	double      perp, para;
+	int         i;
 
 	/*
 	 *  I know that the "bounce" is not really accurate, but I like the way
@@ -600,53 +600,51 @@ OldOctRotated(
 
 	kp->pen[pn].cx = kp->pen[pn].cx + kp->pen[pn].xv;
 	kp->pen[pn].cy = kp->pen[pn].cy + kp->pen[pn].yv;
-    angle          = CartToAngle(kp->pen[pn].cx, kp->pen[pn].cy);
-    radius         = CartToRadius(kp->pen[pn].cx, kp->pen[pn].cy);
-    
-    oangle         = CartToAngle(kp->pen[pn].ox, kp->pen[pn].oy);
-    oradius        = CartToRadius(kp->pen[pn].ox, kp->pen[pn].oy);
+	angle = CartToAngle(kp->pen[pn].cx, kp->pen[pn].cy);
+	radius = CartToRadius(kp->pen[pn].cx, kp->pen[pn].cy);
 
-    if (radius < 0.0) {
+	oangle = CartToAngle(kp->pen[pn].ox, kp->pen[pn].oy);
+	oradius = CartToRadius(kp->pen[pn].ox, kp->pen[pn].oy);
+
+	if (radius < 0.0) {
 		if (kp->pen[pn].xv < 0.0) {
 			kp->pen[pn].xv = -kp->pen[pn].xv;
-        }
+		}
 	} else if (radius > kp->radius) {
-        if (kp->pen[pn].xv > 0.0) {
-		    kp->pen[pn].xv = -kp->pen[pn].xv;
-	    }
+		if (kp->pen[pn].xv > 0.0) {
+			kp->pen[pn].xv = -kp->pen[pn].xv;
+		}
 	}
-
-    if (angle < 0.0) {
-        if (oangle > 0.0) {
-		  kp->pen[pn].yv = -kp->pen[pn].yv;
+	if (angle < 0.0) {
+		if (oangle > 0.0) {
+			kp->pen[pn].yv = -kp->pen[pn].yv;
 		}
+	} else if (angle > 45.0) {
+		if (oangle < 45.0) {
+			rv = CartToRadius(kp->pen[pn].xv, kp->pen[pn].yv);
+			av = CartToAngle(kp->pen[pn].xv, kp->pen[pn].yv);
 
-    } else if (angle > 45.0) {
-        if (oangle < 45.0) {
-            rv = CartToRadius(kp->pen[pn].xv,kp->pen[pn].yv);
-            av = CartToAngle(kp->pen[pn].xv,kp->pen[pn].yv);
+			para = PolarToCartX(rv, av - 45.0);
+			perp = PolarToCartY(rv, av - 45.0);
 
-            para = PolarToCartX(rv,av - 45.0);
-            perp = PolarToCartY(rv,av - 45.0);
+			rv = CartToRadius(para, -perp);
+			av = CartToAngle(para, -perp);
 
-			rv = CartToRadius(para,-perp);
-            av = CartToAngle(para,-perp);
-
-            kp->pen[pn].xv = PolarToCartX(rv,av + 45.0);
-            kp->pen[pn].yv = PolarToCartY(rv,av + 45.0);
+			kp->pen[pn].xv = PolarToCartX(rv, av + 45.0);
+			kp->pen[pn].yv = PolarToCartY(rv, av + 45.0);
 		}
-    }
+	}
+	for (i = 0; i < 8; i += 1) {
+		segs[i].x1 = (int) (kp->widthby2 + PolarToCartX(oradius, oangle));
+		segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius, oangle));
+		segs[i].x2 = (int) (kp->widthby2 + PolarToCartX(radius, angle));
+		segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius, angle));
 
-    for (i=0; i<8; i+=1) {
-        segs[i].x1 = (int) (kp->widthby2  + PolarToCartX(oradius,oangle));
-	    segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius,oangle)); 
-	    segs[i].x2 = (int) (kp->widthby2  + PolarToCartX(radius,angle));
-	    segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius,angle));
-
-        oangle    += 45.0;
-        angle     += 45.0;
+		oangle += 45.0;
+		angle += 45.0;
 	}
 }
+
 #endif
 
 /*-
@@ -654,18 +652,18 @@ OldOctRotated(
  */
 static void
 OctRotated(
-		   kaleidstruct * kp,
-		   int pn,
-		   XSegment * segs
+		  kaleidstruct * kp,
+		  int pn,
+		  XSegment * segs
 )
 {
 	double      xdiag;
 	double      ydiag;
-    double      radius,angle;
-    double      oradius,oangle;
-    double      ox,oy,cx,cy;
+	double      radius, angle;
+	double      oradius, oangle;
+	double      ox, oy, cx, cy;
 	double      offset;
-    int         i;
+	int         i;
 
 	/*
 	 *  I know that the "bounce" is not really accurate, but I like the way
@@ -693,37 +691,35 @@ OctRotated(
 		kp->pen[pn].cy = ydiag - (kp->pen[pn].cy - ydiag);
 		kp->pen[pn].yv = -kp->pen[pn].yv;
 	}
+	offset = CartToRadius(kp->heightby2, kp->widthby2);
+	ox = (kp->pen[pn].ox * offset) / kp->widthby2;
+	oy = (kp->pen[pn].oy * offset) / kp->heightby2;
+	cx = (kp->pen[pn].cx * offset) / kp->widthby2;
+	cy = (kp->pen[pn].cy * offset) / kp->heightby2;
 
-    
-    offset = CartToRadius(kp->heightby2,kp->widthby2);
-    ox     = (kp->pen[pn].ox * offset) / kp->widthby2;
-    oy     = (kp->pen[pn].oy * offset) / kp->heightby2;
-    cx     = (kp->pen[pn].cx * offset) / kp->widthby2;
-    cy     = (kp->pen[pn].cy * offset) / kp->heightby2;
+	angle = CartToAngle(cx - offset,
+			    offset - cy
+		) - 90.0;
+	radius = CartToRadius(cx - offset,
+			      offset - cy
+		);
 
-    angle          = CartToAngle(cx - offset,
-								 offset  - cy
-								) - 90.0;
-    radius         = CartToRadius(cx - offset,
-								  offset  - cy
-								 );
-    
-    oangle         = CartToAngle(ox - offset,
-								 offset  - oy
-								) - 90.0;
-    oradius        = CartToRadius(ox - offset,
-								  offset  - oy
-								 );
+	oangle = CartToAngle(ox - offset,
+			     offset - oy
+		) - 90.0;
+	oradius = CartToRadius(ox - offset,
+			       offset - oy
+		);
 
 
-    for (i=0; i<8; i+=1) {
-        segs[i].x1 = (int) (kp->widthby2  + PolarToCartX(oradius,oangle));
-	    segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius,oangle)); 
-	    segs[i].x2 = (int) (kp->widthby2  + PolarToCartX(radius,angle));
-	    segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius,angle));
+	for (i = 0; i < 8; i += 1) {
+		segs[i].x1 = (int) (kp->widthby2 + PolarToCartX(oradius, oangle));
+		segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius, oangle));
+		segs[i].x2 = (int) (kp->widthby2 + PolarToCartX(radius, angle));
+		segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius, angle));
 
-        oangle    += 45.0;
-        angle     += 45.0;
+		oangle += 45.0;
+		angle += 45.0;
 	}
 
 }
@@ -733,121 +729,120 @@ OctRotated(
  */
 static void
 GeneralLinearMoveAndBounce(
-					       kaleidstruct * kp,
-					       int pn,
-					       double *angle,
-					       double *radius,
-					       double *oangle,
-					       double *oradius
+				  kaleidstruct * kp,
+				  int pn,
+				  double *angle,
+				  double *radius,
+				  double *oangle,
+				  double *oradius
 )
 {
-    double      rv,av;
-    double      perp,para;
+	double      rv, av;
+	double      perp, para;
 
 	kp->pen[pn].cx = kp->pen[pn].cx + kp->pen[pn].xv;
 	kp->pen[pn].cy = kp->pen[pn].cy + kp->pen[pn].yv;
 
-    *angle   = CartToAngle(kp->pen[pn].cx, kp->pen[pn].cy);
-    *radius  = CartToRadius(kp->pen[pn].cx, kp->pen[pn].cy);
+	*angle = CartToAngle(kp->pen[pn].cx, kp->pen[pn].cy);
+	*radius = CartToRadius(kp->pen[pn].cx, kp->pen[pn].cy);
 
-    *oangle  = CartToAngle(kp->pen[pn].ox, kp->pen[pn].oy);
-    *oradius = CartToRadius(kp->pen[pn].ox, kp->pen[pn].oy);
+	*oangle = CartToAngle(kp->pen[pn].ox, kp->pen[pn].oy);
+	*oradius = CartToRadius(kp->pen[pn].ox, kp->pen[pn].oy);
 
-    if (*radius < 0.0) {
-	    kp->pen[pn].RadiusOut = True;
+	if (*radius < 0.0) {
+		kp->pen[pn].RadiusOut = True;
 		if (*oradius > 0.0) {
-            rv = CartToRadius(kp->pen[pn].xv,kp->pen[pn].yv);
-            av = CartToAngle(kp->pen[pn].xv,kp->pen[pn].yv);
+			rv = CartToRadius(kp->pen[pn].xv, kp->pen[pn].yv);
+			av = CartToAngle(kp->pen[pn].xv, kp->pen[pn].yv);
 
-            para = PolarToCartX(rv,av - (*angle+90.0));
-            perp = PolarToCartY(rv,av - (*angle+90.0));
+			para = PolarToCartX(rv, av - (*angle + 90.0));
+			perp = PolarToCartY(rv, av - (*angle + 90.0));
 
-			rv = CartToRadius(para,-perp);
-            av = CartToAngle(para,-perp);
+			rv = CartToRadius(para, -perp);
+			av = CartToAngle(para, -perp);
 
-            kp->pen[pn].xv = PolarToCartX(rv,av + (*angle+90.0));
-            kp->pen[pn].yv = PolarToCartY(rv,av + (*angle+90.0));
-        }
+			kp->pen[pn].xv = PolarToCartX(rv, av + (*angle + 90.0));
+			kp->pen[pn].yv = PolarToCartY(rv, av + (*angle + 90.0));
+		}
 	} else if (*radius > kp->radius) {
-	    kp->pen[pn].RadiusOut = True;
-        if (*oradius < kp->radius) {
-            rv = CartToRadius(kp->pen[pn].xv,kp->pen[pn].yv);
-            av = CartToAngle(kp->pen[pn].xv,kp->pen[pn].yv);
+		kp->pen[pn].RadiusOut = True;
+		if (*oradius < kp->radius) {
+			rv = CartToRadius(kp->pen[pn].xv, kp->pen[pn].yv);
+			av = CartToAngle(kp->pen[pn].xv, kp->pen[pn].yv);
 
-            para = PolarToCartX(rv,av - (*angle+90.0));
-            perp = PolarToCartY(rv,av - (*angle+90.0));
+			para = PolarToCartX(rv, av - (*angle + 90.0));
+			perp = PolarToCartY(rv, av - (*angle + 90.0));
 
-			rv = CartToRadius(para,-perp);
-            av = CartToAngle(para,-perp);
+			rv = CartToRadius(para, -perp);
+			av = CartToAngle(para, -perp);
 
-            kp->pen[pn].xv = PolarToCartX(rv,av + (*angle+90.0));
-            kp->pen[pn].yv = PolarToCartY(rv,av + (*angle+90.0));
-	    }
+			kp->pen[pn].xv = PolarToCartX(rv, av + (*angle + 90.0));
+			kp->pen[pn].yv = PolarToCartY(rv, av + (*angle + 90.0));
+		}
 	} else {
-	    kp->pen[pn].RadiusOut = False;
+		kp->pen[pn].RadiusOut = False;
 	}
-	  
 
-    if (*angle < 0.0) {
-	    kp->pen[pn].AngleOut = True;
-        if (*oangle > 0.0) {
-            rv = CartToRadius(kp->pen[pn].xv,kp->pen[pn].yv);
-            av = CartToAngle(kp->pen[pn].xv,kp->pen[pn].yv);
 
-            para = PolarToCartX(rv,av);
-            perp = PolarToCartY(rv,av);
+	if (*angle < 0.0) {
+		kp->pen[pn].AngleOut = True;
+		if (*oangle > 0.0) {
+			rv = CartToRadius(kp->pen[pn].xv, kp->pen[pn].yv);
+			av = CartToAngle(kp->pen[pn].xv, kp->pen[pn].yv);
 
-			rv = CartToRadius(para,-perp);
-            av = CartToAngle(para,-perp);
+			para = PolarToCartX(rv, av);
+			perp = PolarToCartY(rv, av);
 
-            kp->pen[pn].xv = PolarToCartX(rv,av);
-            kp->pen[pn].yv = PolarToCartY(rv,av);
+			rv = CartToRadius(para, -perp);
+			av = CartToAngle(para, -perp);
+
+			kp->pen[pn].xv = PolarToCartX(rv, av);
+			kp->pen[pn].yv = PolarToCartY(rv, av);
 		}
+	} else if (*angle > kp->slice) {
+		kp->pen[pn].AngleOut = True;
+		if (*oangle < kp->slice) {
+			rv = CartToRadius(kp->pen[pn].xv, kp->pen[pn].yv);
+			av = CartToAngle(kp->pen[pn].xv, kp->pen[pn].yv);
 
-    } else if (*angle > kp->slice) {
-	    kp->pen[pn].AngleOut = True;
-        if (*oangle < kp->slice) {
-            rv = CartToRadius(kp->pen[pn].xv,kp->pen[pn].yv);
-            av = CartToAngle(kp->pen[pn].xv,kp->pen[pn].yv);
+			para = PolarToCartX(rv, av - kp->slice);
+			perp = PolarToCartY(rv, av - kp->slice);
 
-            para = PolarToCartX(rv,av - kp->slice);
-            perp = PolarToCartY(rv,av - kp->slice);
+			rv = CartToRadius(para, -perp);
+			av = CartToAngle(para, -perp);
 
-			rv = CartToRadius(para,-perp);
-            av = CartToAngle(para,-perp);
-
-            kp->pen[pn].xv = PolarToCartX(rv,av + kp->slice);
-            kp->pen[pn].yv = PolarToCartY(rv,av + kp->slice);
+			kp->pen[pn].xv = PolarToCartX(rv, av + kp->slice);
+			kp->pen[pn].yv = PolarToCartY(rv, av + kp->slice);
 		}
 	} else {
-	    kp->pen[pn].AngleOut = False;
+		kp->pen[pn].AngleOut = False;
 	}
 }
-					
+
 /*-
  *
  */
 static void
 GeneralLinearRotated(
-                     kaleidstruct * kp,
-		             int pn,
-		             XSegment * segs
+			    kaleidstruct * kp,
+			    int pn,
+			    XSegment * segs
 )
 {
-    double      angle,radius;
-    double      oangle,oradius;
-    int         i;
+	double      angle, radius;
+	double      oangle, oradius;
+	int         i;
 
-    GeneralLinearMoveAndBounce(kp,pn,&angle,&radius,&oangle,&oradius);
+	GeneralLinearMoveAndBounce(kp, pn, &angle, &radius, &oangle, &oradius);
 
-    for (i=0; i < kp->modetype; i+=1) {
-        segs[i].x1 = (int) (kp->widthby2  + PolarToCartX(oradius,oangle));
-	    segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius,oangle)); 
-	    segs[i].x2 = (int) (kp->widthby2  + PolarToCartX(radius,angle));
-	    segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius,angle));
+	for (i = 0; i < kp->modetype; i += 1) {
+		segs[i].x1 = (int) (kp->widthby2 + PolarToCartX(oradius, oangle));
+		segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius, oangle));
+		segs[i].x2 = (int) (kp->widthby2 + PolarToCartX(radius, angle));
+		segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius, angle));
 
-        oangle    += kp->slice;
-        angle     += kp->slice;
+		oangle += kp->slice;
+		angle += kp->slice;
 	}
 }
 
@@ -858,41 +853,41 @@ GeneralLinearRotated(
  */
 static void
 GeneralLinearMirrored(
-                      kaleidstruct * kp,
-		              int pn,
-		              XSegment * segs
+			     kaleidstruct * kp,
+			     int pn,
+			     XSegment * segs
 )
 {
-    double      hangle,angle,radius;
-    double      hoangle,oangle,oradius;
-    int         i;
+	double      hangle, angle, radius;
+	double      hoangle, oangle, oradius;
+	int         i;
 
 
-    GeneralLinearMoveAndBounce(kp,pn,&angle,&radius,&oangle,&oradius);
+	GeneralLinearMoveAndBounce(kp, pn, &angle, &radius, &oangle, &oradius);
 
-    hoangle = oangle;
-    hangle  = angle;
+	hoangle = oangle;
+	hangle = angle;
 
-    for (i=0; i < kp->modetype; i+=2) {
-        segs[i].x1 = (int) (kp->widthby2  + PolarToCartX(oradius,oangle));
-	    segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius,oangle)); 
-	    segs[i].x2 = (int) (kp->widthby2  + PolarToCartX(radius,angle));
-	    segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius,angle));
+	for (i = 0; i < kp->modetype; i += 2) {
+		segs[i].x1 = (int) (kp->widthby2 + PolarToCartX(oradius, oangle));
+		segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius, oangle));
+		segs[i].x2 = (int) (kp->widthby2 + PolarToCartX(radius, angle));
+		segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius, angle));
 
-        oangle    += 2.0 * kp->slice;
-        angle     += 2.0 * kp->slice;
+		oangle += 2.0 * kp->slice;
+		angle += 2.0 * kp->slice;
 	}
 
-    oangle = kp->slice * 2.0;
-    angle  = kp->slice * 2.0;
-    for (i=1; i < kp->modetype; i+=2) {
-        segs[i].x1 = (int) (kp->widthby2  + PolarToCartX(oradius,oangle-hoangle));
-	    segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius,oangle-hoangle)); 
-	    segs[i].x2 = (int) (kp->widthby2  + PolarToCartX(radius,angle-hangle));
-	    segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius,angle-hangle));
+	oangle = kp->slice * 2.0;
+	angle = kp->slice * 2.0;
+	for (i = 1; i < kp->modetype; i += 2) {
+		segs[i].x1 = (int) (kp->widthby2 + PolarToCartX(oradius, oangle - hoangle));
+		segs[i].y1 = (int) (kp->heightby2 - PolarToCartY(oradius, oangle - hoangle));
+		segs[i].x2 = (int) (kp->widthby2 + PolarToCartX(radius, angle - hangle));
+		segs[i].y2 = (int) (kp->heightby2 - PolarToCartY(radius, angle - hangle));
 
-        oangle    += 2.0 * kp->slice;
-        angle     += 2.0 * kp->slice;
+		oangle += 2.0 * kp->slice;
+		angle += 2.0 * kp->slice;
 	}
 }
 
@@ -937,28 +932,30 @@ random_position(kaleidstruct * kp, int i)
 {
 
 	if (kp->modetype >= 0) {
-	    if (kp->linear) {
-            double radius, angle;
-	        radius = (double) INTRAND(0, (int) (kp->radius - 1.0));
-		    angle  = (double) INTRAND(0, (int) (kp->slice - 1.0));
-        
-            kp->pen[i].cx = PolarToCartX(radius,angle);
-            kp->pen[i].cy = PolarToCartY(radius,angle);
+		if (kp->linear) {
+			double      radius, angle;
+
+			radius = (double) INTRAND(0, (int) (kp->radius - 1.0));
+			angle = (double) INTRAND(0, (int) (kp->slice - 1.0));
+
+			kp->pen[i].cx = PolarToCartX(radius, angle);
+			kp->pen[i].cy = PolarToCartY(radius, angle);
 		} else {
-           kp->pen[i].cx = (double) INTRAND(0, (int) (kp->radius - 1.0));
-	       kp->pen[i].cy = (double) INTRAND(0, (int) (kp->slice - 1.0));
+			kp->pen[i].cx = (double) INTRAND(0, (int) (kp->radius - 1.0));
+			kp->pen[i].cy = (double) INTRAND(0, (int) (kp->slice - 1.0));
 		}
 	} else if (kp->modetype == OCT) {
-        double radius, angle;
+		double      radius, angle;
+
 		radius = (double) INTRAND(0, (int) (kp->radius - 1.0));
-		angle  = (double) INTRAND(0, 44);
-        
-        kp->pen[i].cx = PolarToCartX(radius,angle);
-        kp->pen[i].cy = PolarToCartY(radius,angle);
+		angle = (double) INTRAND(0, 44);
+
+		kp->pen[i].cx = PolarToCartX(radius, angle);
+		kp->pen[i].cy = PolarToCartY(radius, angle);
 	} else {
 		kp->pen[i].cx = (double) INTRAND(0, (int) (kp->widthby2 - 1.0));
 		kp->pen[i].cy = (double) INTRAND(0,
-		       (int) ((kp->heightby2 * kp->pen[i].cx) / kp->widthby2));
+		     (int) ((kp->heightby2 * kp->pen[i].cx) / kp->widthby2));
 	}
 }
 
@@ -985,22 +982,19 @@ init_kaleid(ModeInfo * mi)
 
 	kp->PenCount = MI_COUNT(mi);
 
-    if (MI_IS_FULLRANDOM(mi))
-     {
-	kp->alternate = (Bool) (LRAND() & 1 );
-	kp->disconnected = (Bool) (LRAND() & 1 );
-	kp->serial = (Bool) (LRAND() & 1 );
-    kp->linear = (Bool) (LRAND() & 1 );
-     }
-   else
-     {
-	kp->alternate = Alternate;
-	kp->disconnected = Disconnected;
-	kp->serial = Serial;
-    kp->linear = Linear;
-     }
+	if (MI_IS_FULLRANDOM(mi)) {
+		kp->alternate = (Bool) (LRAND() & 1);
+		kp->disconnected = (Bool) (LRAND() & 1);
+		kp->serial = (Bool) (LRAND() & 1);
+		kp->linear = (Bool) (LRAND() & 1);
+	} else {
+		kp->alternate = Alternate;
+		kp->disconnected = Disconnected;
+		kp->serial = Serial;
+		kp->linear = Linear;
+	}
 
-   if (kp->PenCount < -MINPENS) {
+	if (kp->PenCount < -MINPENS) {
 		/* if kp->PenCount is random ... the size can change */
 		if (kp->pen != NULL) {
 			(void) free((void *) kp->pen);
@@ -1020,24 +1014,22 @@ init_kaleid(ModeInfo * mi)
 	} else {
 		kp->modetype = (!kp->alternate + 1) * MINSIZE;
 	}
-   if (MI_IS_FULLRANDOM(mi))
-     {
-	int tmp;
-	tmp = NRAND( ABS( MI_SIZE( mi ) ) + 2 );
-	if ( tmp == 0 )
-	  kp->modetype = OCT;
-	else if ( tmp == 1 )
-	  kp->modetype = QUAD;
-     }
-   else
-     {
-	if (Oct)
-	  kp->modetype = OCT;
-	else if (Quad)
-	  kp->modetype = QUAD;
-     }
+	if (MI_IS_FULLRANDOM(mi)) {
+		int         tmp;
 
-	kp->PercentBlack = MAX(0, MIN(MI_CYCLES(mi), 95));
+		tmp = NRAND(ABS(MI_SIZE(mi)) + 2);
+		if (tmp == 0)
+			kp->modetype = OCT;
+		else if (tmp == 1)
+			kp->modetype = QUAD;
+	} else {
+		if (Oct)
+			kp->modetype = OCT;
+		else if (Quad)
+			kp->modetype = QUAD;
+	}
+
+	kp->PercentBlack = (int) MAX(0, MIN(MI_CYCLES(mi), 95));
 
 
 	/* set various size parameters */
@@ -1051,15 +1043,15 @@ init_kaleid(ModeInfo * mi)
 		kp->height = 2.0;
 
 	kp->radius = sqrt(((kp->width * kp->width) +
-				   (kp->height * kp->height)
-				  ) / 4.0
-			);
+			   (kp->height * kp->height)
+			  ) / 4.0
+		);
 
 
 	if (kp->modetype >= 0) {
 		kp->bouncetype = INTRAND(0, 2);
 
-    	kp->slice = 360.0 / (double) kp->modetype;
+		kp->slice = 360.0 / (double) kp->modetype;
 
 		kp->widthby2 = kp->width / 2.0;
 		kp->heightby2 = kp->height / 2.0;
@@ -1071,15 +1063,12 @@ init_kaleid(ModeInfo * mi)
 	/* set the maximum pen width */
 	if (kp->modetype >= 0) {
 		if ((kp->slice == 360.0) || (kp->slice == 180.0)) {
-			kp->maxlwidth = (int) (((double) MIN(kp->widthby2, kp->heightby2)
-					       ) * (double) WidthPercent
-				) / 100.0;
+			kp->maxlwidth = (int) ((((double) MIN(kp->widthby2, kp->heightby2)) *
+					     (double) WidthPercent) / 100.0);
 		} else {
 			kp->maxlwidth = (int) (((sin(kp->slice * ToRadians) *
-					     MIN(kp->widthby2, kp->heightby2)
-						) * (double) WidthPercent
-					       ) / 100.0
-				);
+					  MIN(kp->widthby2, kp->heightby2)) *
+					     (double) WidthPercent) / 100.0);
 		}
 	} else {
 		kp->maxlwidth = (int) ((MIN(kp->widthby2,
@@ -1102,8 +1091,8 @@ init_kaleid(ModeInfo * mi)
 
 		kp->pen[i].curlwidth = INTRAND(1, kp->maxlwidth);
 
-        kp->pen[i].RadiusOut = False;
-        kp->pen[i].AngleOut  = False;
+		kp->pen[i].RadiusOut = False;
+		kp->pen[i].AngleOut = False;
 
 		random_position(kp, i);
 
@@ -1135,7 +1124,7 @@ set_pen_attributes(ModeInfo * mi, kaleidstruct * kp, int i)
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 	}
 	XSetLineAttributes(display, gc,
-		kp->pen[i].curlwidth, LineSolid, CapRound, JoinRound);
+		       kp->pen[i].curlwidth, LineSolid, CapRound, JoinRound);
 }
 
 /*-
@@ -1187,13 +1176,15 @@ draw_kaleid(ModeInfo * mi)
 	int         NumberOfSegments = 0;
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (kp->modetype == QUAD) {
 		NumberOfSegments = 4;
 		segs = (XSegment *) malloc(NumberOfSegments * sizeof (XSegment));
 	} else if (kp->modetype == OCT) {
 		NumberOfSegments = 8;
 		segs = (XSegment *) malloc(NumberOfSegments * sizeof (XSegment));
-	} else /* if (kp->modetype > 0) */ {
+	} else {		/* if (kp->modetype > 0) */
 		NumberOfSegments = kp->modetype;
 		segs = (XSegment *) malloc(NumberOfSegments * sizeof (XSegment));
 	}
@@ -1207,24 +1198,24 @@ draw_kaleid(ModeInfo * mi)
 				QuadMirrored(kp, i, segs);
 			}
 		} else if (kp->modetype == OCT) {
-		    if (kp->alternate) {
-                OctRotated(kp, i, segs);
+			if (kp->alternate) {
+				OctRotated(kp, i, segs);
 			} else {
-                OctMirrored(kp, i, segs);
+				OctMirrored(kp, i, segs);
 			}
 		} else {
 			if (kp->alternate) {
-			    if (kp->linear) {
-				   GeneralLinearRotated(kp, i, segs);
-                } else {
-				   GeneralRotated(kp, i, segs);
+				if (kp->linear) {
+					GeneralLinearRotated(kp, i, segs);
+				} else {
+					GeneralRotated(kp, i, segs);
 				}
 			} else {
-			    if (kp->linear) {
-				   GeneralLinearMirrored(kp, i, segs);
-                } else {
-				   GeneralMirrored(kp, i, segs);
-                }
+				if (kp->linear) {
+					GeneralLinearMirrored(kp, i, segs);
+				} else {
+					GeneralMirrored(kp, i, segs);
+				}
 			}
 		}
 		XDrawSegments(
@@ -1239,12 +1230,12 @@ draw_kaleid(ModeInfo * mi)
 		kp->pen[i].oy = kp->pen[i].cy;
 
 
-		if ((INTRAND(0, 100) < ChangeChance) || kp->pen[i].DeferredChange){
-            if (!kp->pen[i].AngleOut && !kp->pen[i].RadiusOut) {
-			    kp->pen[i].DeferredChange = False;
-			    change_pen(mi, kp, i);
+		if ((INTRAND(0, 100) < ChangeChance) || kp->pen[i].DeferredChange) {
+			if (!kp->pen[i].AngleOut && !kp->pen[i].RadiusOut) {
+				kp->pen[i].DeferredChange = False;
+				change_pen(mi, kp, i);
 			} else {
-			    kp->pen[i].DeferredChange = True;
+				kp->pen[i].DeferredChange = True;
 			}
 		}
 	}
