@@ -57,12 +57,12 @@ static const char sccsid[] = "@(#)life1d.c	4.07 97/11/24 xlockmore";
  "*bitmap: \n" \
  "*verbose: \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
-
+#include "color.h"
 #endif /* STANDALONE */
+#include "automata.h"
+#include "iostuff.h"
 
 #define DEF_TOTALISTIC  "True"	/* FALSE is LCAU */
 
@@ -416,7 +416,7 @@ drawcell(ModeInfo * mi, int col, int row, unsigned int state)
 	}
 	if (MI_NPIXELS(mi) > 2)
 		XSetForeground(display, gc, MI_PIXEL(mi, lp->colors[state - 1]));
-	if (lp->pixelmode | (MI_NPIXELS(mi) <= 2)) {
+	if (lp->pixelmode || (MI_NPIXELS(mi) <= 2)) {
 		if (MI_NPIXELS(mi) <= 2) {
 			XGCValues   gcv;
 
@@ -475,7 +475,7 @@ GetRule(life1dstruct * lp, int i)
 		sum_size = (lp->k - 1) * (lp->r * 2 + 1) + 1;
 		code = lp->code = totalistic_rules[i][2];
 
-		pow = power(lp->k, sum_size - 1);	/* Should be less than max long */
+		pow = power(lp->k, (int) (sum_size - 1));	/* Should be less than max long */
 		for (j = 0; j < sum_size; j++) {
 			lp->nextstate[sum_size - 1 - j] = (char) (code / pow);
 			code -= ((long) lp->nextstate[sum_size - 1 - j]) * pow;
@@ -614,7 +614,7 @@ init_life1d(ModeInfo * mi)
 	} else {
 		maxstates = MAXSTATES - 1;
 		maxradius = 1;
-		maxsum_size = power(maxstates, (2 * maxradius + 1));
+		maxsum_size = (int) power(maxstates, (2 * maxradius + 1));
 	}
 	if (lp->nextstate == NULL)
 		lp->nextstate = (char *) malloc(maxsum_size * sizeof (char));
@@ -690,7 +690,7 @@ init_life1d(ModeInfo * mi)
 				(void) fprintf(stdout, "%d", (int) lp->nextstate[i]);
 		} else {
 			(void) fprintf(stdout, "LCAU rule ");
-			for (i = power(lp->k, (lp->r * 2 + 1)); i >= 0; i--)
+			for (i = (int) power(lp->k, (lp->r * 2 + 1)); i >= 0; i--)
 				(void) fprintf(stdout, "%d", (int) lp->nextstate[i]);
 		}
 		(void) fprintf(stdout, "\n");
@@ -714,6 +714,8 @@ draw_life1d(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	int         col;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (lp->busyLoop) {
 		if (lp->busyLoop >= 250)
 			lp->busyLoop = 0;
