@@ -54,11 +54,11 @@ static const char sccsid[] = "@(#)life3d.c	4.07 98/01/18 xlockmore";
  "*fullrandom: False \n" \
  "*verbose: False \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 #if 1
 #define DEF_RULE3D  "G"		/* All rules with gliders */
@@ -1210,7 +1210,7 @@ static paramstruct param_rules[] =
 static int
 codeToPatternedRule(paramstruct param)
 {
-	int         i;
+	unsigned int i;
 
 	for (i = 0; i < LIFE_RULES; i++)
 		if (param_rules[i].survival == param.survival &&
@@ -2201,7 +2201,7 @@ init_life3d(ModeInfo * mi)
 	NewViewpoint(lp, lp->vx, lp->vy, lp->vz);
 
 	lp->patterned_rule = codeToPatternedRule(lp->param);
-	if (lp->patterned_rule < LIFE_RULES)
+	if ((unsigned) lp->patterned_rule < LIFE_RULES)
 		npats = patterns_rules[lp->patterned_rule];
 	else
 		npats = 0;
@@ -2222,6 +2222,8 @@ draw_life3d(ModeInfo * mi)
 	RunLife3D(lp);
 	DrawScreen(mi);
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (++lp->generation > MI_CYCLES(mi) || !lp->visible) {
 		/*CountCells3D(lp) == 0) */
 		init_life3d(mi);
@@ -2281,7 +2283,7 @@ change_life3d(ModeInfo * mi)
 
 	lp->pattern++;
 	lp->patterned_rule = codeToPatternedRule(lp->param);
-	if (lp->patterned_rule < LIFE_RULES)
+	if ((unsigned) lp->patterned_rule < LIFE_RULES)
 		npats = patterns_rules[lp->patterned_rule];
 	else
 		npats = 0;
@@ -2289,7 +2291,7 @@ change_life3d(ModeInfo * mi)
 		lp->pattern = 0;
 		if (allPatterns) {
 			lp->patterned_rule++;
-			if (lp->patterned_rule >= LIFE_RULES)
+			if ((unsigned) lp->patterned_rule >= LIFE_RULES)
 				lp->patterned_rule = 0;
 			copyFromPatternedRule(&lp->param, lp->patterned_rule);
 			if (MI_IS_VERBOSE(mi))
