@@ -92,11 +92,11 @@ ModStruct   lisa_description =
 #define  LISAMAXFUNCS 2
 #define  NUMSTDFUNCS  10
 #define  MAXCYCLES    3
-#define  MINLISAS 1
+#define  MINLISAS     1
 #define  lisasetcolor() \
 if (MI_NPIXELS(mi) > 2) { \
   XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_PIXEL(mi, loop->color)); \
-  if (++(loop->color) >= MI_NPIXELS(mi)) { loop->color=0; } \
+  if (++(loop->color) >= (unsigned) MI_NPIXELS(mi)) { loop->color=0; } \
   } else { XSetForeground(MI_DISPLAY(mi), MI_GC(mi), MI_WHITE_PIXEL(mi)); }
 #define getRadius(context) \
   ((context->width > context->height)?context->height:context->width) * 3 / 8
@@ -115,7 +115,8 @@ typedef struct lisafunc_struct {
 } lisafuncs;
 
 typedef struct lisa_struct {
-	int         radius, color, dx, dy, nsteps, nfuncs, melting;
+	unsigned long color;
+	int         radius, dx, dy, nsteps, nfuncs, melting;
 	double      pistep, phi, theta;
 	XPoint      center, *lastpoint;
 	lisafuncs  *function[LISAMAXFUNCS];
@@ -331,7 +332,7 @@ initlisa(ModeInfo * mi, lisas * loop)
 	loop->pistep = 2.0 * M_PI / (double) loop->nsteps;
 	loop->center.x = lc->width / 2;
 	loop->center.y = lc->height / 2;
-	loop->radius = MI_SIZE(mi);
+	loop->radius = (int) MI_SIZE(mi);
 	checkRadius(loop, lc);
 	loop->dx = NRAND(XVMAX);
 	loop->dy = NRAND(YVMAX);
@@ -480,6 +481,8 @@ draw_lisa(ModeInfo * mi)
 {
 	lisacons   *lc = &Lisa[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	lc->painted = True;
 	if (++lc->loopcount > lc->maxcycles) {
 		change_lisa(mi);
