@@ -21,6 +21,16 @@ static const char sccsid[] = "@(#)mandelbrot.c 4.07 97/11/24 xlockmore";
  * event will the author be liable for any lost revenue or profits or
  * other special, indirect and consequential damages.
  *
+ * See  A.K. Dewdney's "Computer Recreations", Scientific American 
+ * Magazine" Aug 1985 for more info.  Also A.K. Dewdney's "Computer
+ * Recreations", Scientific American Magazine" Jul 1989, has some neat
+ * extensions besides z^n + c (n small but >= 2) some of these are:
+ *   z^z + z^n + c
+ *   sin(z) + e^z + c 
+ *   sin(z) + z^n + c
+ * These were first explored by a colleague of Mandelbrot, Clifford A.
+ * Pickover.  These would make nice additions to add.
+ *
  * Revision History:
  * 20-Oct-97: Written by Dan Stromberg <strombrg@nis.acs.uci.edu>
  */
@@ -41,6 +51,8 @@ static const char sccsid[] = "@(#)mandelbrot.c 4.07 97/11/24 xlockmore";
 #include <X11/Xutil.h>
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
+#include "vis.h"
+#include "color.h"
 #endif /* !STANDALONE */
 
 #define MINPOWER 1
@@ -103,12 +115,19 @@ mult(complex * a, complex b)
 	a->imag = ti;
 }
 
+/* Plans for future additions?  a, z complex; x, y real
+   sin(z) = (e^(i * z) - e^(-i * z)) / (2 * i)
+   cos(z) = (e^(i * z) - e^(-i * z)) / 2
+   a^z = e^(z * ln(a))
+   e^z = e^x * (cos(y) + i * sin(y))
+   ln(z) = ln ((x^2 + y^2)^(1/2)) + i * invtan(y/x)
+ */
+
 /* this IS a true power function. */
 static void
 ipow(complex * a, int n)
 {
-	int         t2;
-	complex     a2;
+
 
 	switch (n) {
 		case 1:
@@ -117,14 +136,18 @@ ipow(complex * a, int n)
 			mult(a, *a);
 			return;
 		default:
-			t2 = n / 2;
-			a2 = *a;
-			ipow(&a2, t2);
-			mult(&a2, a2);
-			if (t2 * 2 != n)	/* if n is odd */
-				mult(&a2, *a);
-			*a = a2;
-			;;
+			{
+				complex     a2;
+				int         t2;
+
+				a2 = *a;	/* Not very efficient to use:  mult(a, ipow(&a2, n-1)); */
+				t2 = n / 2;
+				ipow(&a2, t2);
+				mult(&a2, a2);
+				if (t2 * 2 != n)	/* if n is odd */
+					mult(&a2, *a);
+				*a = a2;
+			}
 	}
 }
 
@@ -256,7 +279,7 @@ reps(complex c, double p, int r)
 	for (rep = 0; rep < r; rep++) {
 		rpow(&t, p);
 		add(&t, c);
-		if (t.real * t.real + t.imag * t.imag >= 4.0) {
+		if (t.real * t.real + t.imag * t.imag >= 13.0) {
 			escaped = 1;
 			break;
 		}
@@ -291,6 +314,8 @@ draw_mandelbrot(ModeInfo * mi)
 	screen_width = MI_WIDTH(mi);
 	screen_height = ((MI_HEIGHT(mi) + 1) >> 1) << 1;	/* screen_height even */
 
+	MI_IS_DRAWN(mi) = True;
+
 #ifndef STANDALONE
 	if (mp->counter % 5 == 0) {
 		/* advance "drawing" color */
