@@ -36,7 +36,7 @@ static const char sccsid[] = "@(#)maze.c	4.07 97/11/24 xlockmore";
  * 17-Jun-94: HP ANSI C compiler needs a type cast for gray_bits
  *            Richard Lloyd <R.K.Lloyd@csc.liv.ac.uk> 
  * 2-Sep-93: xlock version David Bagley <bagleyd@bigfoot.com>
- * 7-Mar-93: Good ideas from xscreensaver Jamie Zawinski <jwz@netscape.com>
+ * 7-Mar-93: Good ideas from xscreensaver Jamie Zawinski <jwz@jwz.org>
  * 6-Jun-85: Martin Weiss Sun Microsystems 
  */
 
@@ -78,10 +78,11 @@ static const char sccsid[] = "@(#)maze.c	4.07 97/11/24 xlockmore";
  "*ncolors: 64 \n" \
  "*bitmap: \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#include "color.h"
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt maze_opts =
 {0, NULL, 0, NULL, NULL};
@@ -527,6 +528,8 @@ draw_maze_walls(ModeInfo * mi)
 	mazestruct *mp = &mazes[MI_SCREEN(mi)];
 	int         i, j, isize;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < mp->ncols; i++) {
 		isize = i * mp->nrows;
 		for (j = 0; j < mp->nrows; j++) {
