@@ -69,7 +69,7 @@ typedef struct {
 	int         offset;
 	int         stage;
 	int         h[WORLDWIDTH][WORLDWIDTH];
-	int         time;	/* up time */
+	long        time;	/* up time */
 	int         first;
 	Bool        wireframe;
 	Bool        joke;
@@ -199,8 +199,8 @@ init_mountain(ModeInfo * mi)
 	}
 	MI_CLEARWINDOW(mi);
 
-	for (y = 0; y < WORLDWIDTH; y++)
-		for (x = 0; x < WORLDWIDTH; x++)
+	for (y = 0; y < (int) WORLDWIDTH; y++)
+		for (x = 0; x < (int) WORLDWIDTH; x++)
 			mp->h[x][y] = 0;
 
 	j = MI_COUNT(mi);
@@ -232,6 +232,8 @@ draw_mountain(ModeInfo * mi)
 {
 	mountainstruct *mp = &mountains[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	switch (mp->stage) {
 		case 0:
 			drawamountain(mi);
