@@ -32,7 +32,7 @@ static const char sccsid[] = "@(#)nose.c	4.07 97/11/24 xlockmore";
  *            Jouk Jansen <joukj@crys.chem.uva.nl>.
  * 21-Sep-95: font option added, debugged for multiscreens
  * 12-Aug-95: xlock version
- * 1992: xscreensaver version, noseguy (Jamie Zawinski <jwz@netscape.com>)
+ * 1992: xscreensaver version, noseguy (Jamie Zawinski <jwz@jwz.org>)
  * 1990: X11 version, xnlock (Dan Heller <argv@sun.com>)
  */
 
@@ -62,10 +62,10 @@ static const char sccsid[] = "@(#)nose.c	4.07 97/11/24 xlockmore";
  "*program: \n"
 #define UNIFORM_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt nose_opts =
 {0, NULL, 0, NULL, NULL};
@@ -724,6 +724,8 @@ draw_nose(ModeInfo * mi)
 {
 	nosestruct *np = &noses[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (np->busyLoop > 0) {
 		np->busyLoop--;
 		return;
