@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)penrose.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 10-May-97: Jamie Zawinski <jwz@netscape.com> compatible with xscreensaver
+ * 10-May-97: Jamie Zawinski <jwz@jwz.org> compatible with xscreensaver
  * 09-Sep-96: Written.
  */
 
@@ -240,7 +240,7 @@ typedef struct {
 	fringe_c    fringe;
 	forced_pool_c forced;
 	int         done, failures;
-	int         thick_color, thin_color;
+	unsigned long thick_color, thin_color;
 	int         busyLoop;
 	Bool        ammann;
 } tiling_c;
@@ -358,10 +358,11 @@ fived_to_loc(int fived[], tiling_c * tp)
 	float       fifth = 8 * atan(1.) / 5;
 	register int i;
 	register float r;
-	register fcoord_c offset =
-	{.0, .0};
+	register fcoord_c offset;
 	XPoint      pt = tp->origin;
 
+	offset.x = 0.0;
+	offset.y = 0.0;
 	if (fived_table[0].x == .0)
 		for (i = 0; i < 5; i++) {
 			fived_table[i].x = cos(fifth * i);
@@ -1221,6 +1222,8 @@ draw_penrose(ModeInfo * mi)
 	int         i = 0, n;
 	forced_node_c *p = tp->forced.first;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (tp->busyLoop > 0) {
 		tp->busyLoop--;
 		return;
@@ -1231,7 +1234,7 @@ draw_penrose(ModeInfo * mi)
 	}
 	/* Check for the initial "2-gon". */
 	if (tp->fringe.nodes->prev == tp->fringe.nodes->next) {
-		vertex_type_c vtype = VT_TOTAL_MASK & LRAND();
+		vertex_type_c vtype = (unsigned char) (VT_TOTAL_MASK & LRAND());
 
 		MI_CLEARWINDOW(mi);
 
