@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)petal.c	4.07 97/11/24 xlockmore";
  * Revision History:
  * 10-May-97: Compatible with xscreensaver
  * 12-Aug-95: xlock version
- * Jan-95: xscreensaver version (Jamie Zawinski <jwz@netscape.com>)
+ * Jan-95: xscreensaver version (Jamie Zawinski <jwz@jwz.org>)
  * 24-Jun-94: X11 version (Dale Moore  <Dale.Moore@cs.cmu.edu>)  
  *            Based on a program for some old PDP-11 Graphics
  *            Display Processors at CMU.
@@ -91,7 +91,7 @@ typedef struct {
 	int         npoints;
 	long        color;
 	XPoint     *points;
-        Bool        wireframe;
+	Bool        wireframe;
 } petalstruct;
 
 static petalstruct *petals = NULL;
@@ -236,7 +236,7 @@ compute_petal(XPoint * points, int lines, int sizex, int sizey)
 		theta += b;
 		theta %= d;
 	}
-	*p = points[0]; /* Tack on another for XDrawLines */
+	*p = points[0];		/* Tack on another for XDrawLines */
 
 	return (npoints);
 }
@@ -247,12 +247,12 @@ petal(ModeInfo * mi)
 	petalstruct *pp = &petals[MI_SCREEN(mi)];
 
 	XSetForeground(MI_DISPLAY(mi), MI_GC(mi), pp->color);
-        if (pp->wireframe) {
+	if (pp->wireframe) {
 		XDrawLines(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-			     pp->points, pp->npoints + 1, CoordModeOrigin);
+			   pp->points, pp->npoints + 1, CoordModeOrigin);
 	} else {
 		XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-			     pp->points, pp->npoints, Complex, CoordModeOrigin);
+			  pp->points, pp->npoints, Complex, CoordModeOrigin);
 	}
 }
 
@@ -300,10 +300,10 @@ init_petal(ModeInfo * mi)
 	pp->height = MI_HEIGHT(mi);
 
 	pp->time = 0;
-        if (MI_IS_FULLRANDOM(mi))
-          pp->wireframe = (Bool) (LRAND() & 1 );
-        else
-            pp->wireframe = MI_IS_WIREFRAME(mi);
+	if (MI_IS_FULLRANDOM(mi))
+		pp->wireframe = (Bool) (LRAND() & 1);
+	else
+		pp->wireframe = MI_IS_WIREFRAME(mi);
 
 	MI_CLEARWINDOW(mi);
 	pp->painted = False;
@@ -316,6 +316,8 @@ draw_petal(ModeInfo * mi)
 {
 	petalstruct *pp = &petals[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (++pp->time > MI_CYCLES(mi))
 		init_petal(mi);
 	else
