@@ -48,10 +48,11 @@ static const char sccsid[] = "@(#)puzzle.c	4.09 98/03/20 xlockmore";
  "*ncolors: 64 \n" \
  "*bitmap: \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "iostuff.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#include "color.h"
 #endif /* STANDALONE */
+#include "iostuff.h"
 
 ModeSpecOpt puzzle_opts =
 {0, NULL, 0, NULL, NULL};
@@ -120,7 +121,7 @@ typedef struct {
 static puzzlestruct *puzzs = NULL;
 
 #ifdef NUMBERED
-extern XFontStruct *getFont();
+extern XFontStruct *getFont(Display * display);
 
 #define font_height(f) (f->ascent + f->descent)
 static XFontStruct *mode_font = None;
@@ -573,6 +574,8 @@ draw_puzzle(ModeInfo * mi)
 {
 	puzzlestruct *pp = &puzzs[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	pp->painted = False;
 	if (pp->movingBox) {
 		if (moveboxdelta(mi)) {
