@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)pyro.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 15-May-97: jwz@netscape.com: turned into a standalone program.
+ * 15-May-97: jwz@jwz.org: turned into a standalone program.
  * 05-Sep-96: Added 3d support Henrik Theiling <theiling@coli.uni-sb.de>
  * 16-Mar-91: Written, received from David Brooks <brooks@osf.org>
  */
@@ -550,6 +550,8 @@ draw_pyro(ModeInfo * mi)
 	rocket     *rp;
 	int         rockn;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (just_started || (NRAND(pp->p_ignite) == 0)) {
 		just_started = False;
 		if (NRAND(P_FUSILLADE) == 0) {
