@@ -52,20 +52,27 @@ static const char sccsid[] = "@(#)qix.c	4.07 97/11/24 xlockmore";
 #endif /* STANDALONE */
 
 #define DEF_COMPLETE  "False"
+#define DEF_KALEID  "False"
+
 static Bool complete;
+static Bool kaleid;
 
 static XrmOptionDescRec opts[] =
 {
 	{"-complete", ".qix.complete", XrmoptionNoArg, (caddr_t) "on"},
-	{"+complete", ".qix.complete", XrmoptionNoArg, (caddr_t) "off"}
+	{"+complete", ".qix.complete", XrmoptionNoArg, (caddr_t) "off"},
+	{"-kaleid", ".qix.kaleid", XrmoptionNoArg, (caddr_t) "on"},
+	{"+kaleid", ".qix.kaleid", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & complete, "complete", "Complete", DEF_COMPLETE, t_Bool}
+      {(caddr_t *) & complete, "complete", "Complete", DEF_COMPLETE, t_Bool},
+	{(caddr_t *) & kaleid, "kaleid", "Kaleid", DEF_KALEID, t_Bool}
 };
 static OptionStruct desc[] =
 {
-	{"-/+complete", "turn on/off complete morphing graph"}
+	{"-/+complete", "turn on/off complete morphing graph"},
+	{"-/+kaleid", "turn on/off complete kaleidoscope"}
 };
 
 ModeSpecOpt qix_opts =
@@ -98,11 +105,12 @@ typedef struct {
 	int         npoints;
 	int         offset;
 	int         max_delta;
-	int         width, height;
-	int         nlines;
+	int         width, height, mid, midx, midy;
+	int         nlines, linecount;
 	int         redrawing, redrawpos;
 	XPoint     *lineq;
 	Bool        complete;
+	Bool        kaleid;
 } qixstruct;
 
 static qixstruct *qixs = NULL;
@@ -131,13 +139,12 @@ init_qix(ModeInfo * mi)
 
 	qp->width = MI_WIDTH(mi);
 	qp->height = MI_HEIGHT(mi);
+	qp->mid = MAX(qp->width, qp->height) / 2;
+	qp->midx = qp->width / 2;
+	qp->midy = qp->height / 2;
 	qp->max_delta = 16;
 	qp->redrawing = 0;
-
-	if (MI_IS_FULLRANDOM(mi))
-		qp->complete = (Bool) (LRAND() & 1);
-	else
-		qp->complete = complete;
+	qp->linecount = 0;
 
 	if (qp->width < 100) {	/* icon window */
 		qp->max_delta /= 4;
@@ -154,6 +161,19 @@ init_qix(ModeInfo * mi)
 	if (qp->npoints < MINPOINTS)
 		qp->npoints = MINPOINTS;
 
+	if (MI_IS_FULLRANDOM(mi))
+		qp->complete = (Bool) (LRAND() & 1);
+	else
+		qp->complete = complete;
+
+	if (qp->complete) {
+		qp->kaleid = False;
+	} else {
+		if (MI_IS_FULLRANDOM(mi))
+			qp->kaleid = (Bool) (LRAND() & 1);
+		else
+			qp->kaleid = kaleid;
+	}
 	if (qp->delta)
 		(void) free((void *) qp->delta);
 	if (qp->position)
@@ -174,11 +194,18 @@ init_qix(ModeInfo * mi)
 		qp->max_delta /= 4;
 		qp->nlines = qp->npoints;
 	}
-	if (qp->lineq)
+	if (qp->kaleid) {
+		qp->nlines = MI_CYCLES(mi) * 16;	/* Fudge it so its compatible */
+	}
+	if (qp->lineq) {
 		(void) free((void *) qp->lineq);
-	qp->lineq = (XPoint *) malloc(qp->nlines * sizeof (XPoint));
-	for (i = 0; i < qp->nlines; i++)
-		qp->lineq[i].x = qp->lineq[i].y = -1;	/* move initial point off screen */
+		qp->lineq = NULL;
+	}
+	if (!qp->kaleid) {
+		qp->lineq = (XPoint *) malloc(qp->nlines * sizeof (XPoint));
+		for (i = 0; i < qp->nlines; i++)
+			qp->lineq[i].x = qp->lineq[i].y = -1;	/* move initial point off screen */
+	}
 	MI_CLEARWINDOW(mi);
 }
 
@@ -192,6 +219,8 @@ draw_qix(ModeInfo * mi)
 
 	qp->first = (qp->last + qp->npoints) % qp->nlines;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < qp->npoints; i++) {
 		qp->position[i].x += qp->delta[i].x;
 		qp->position[i].y += qp->delta[i].y;
@@ -215,7 +244,7 @@ draw_qix(ModeInfo * mi)
 				XDrawLine(display, MI_WINDOW(mi), gc,
 					  qp->lineq[qp->first + i].x, qp->lineq[qp->first + i].y,
 					  qp->lineq[qp->first + j].x, qp->lineq[qp->first + j].y);
-	} else {
+	} else if (!qp->kaleid) {
 		for (i = 1; i < qp->npoints + ((qp->npoints == 2) ? -1 : 0); i++)
 			XDrawLine(display, MI_WINDOW(mi), gc,
 				  qp->lineq[qp->first + i - 1].x, qp->lineq[qp->first + i - 1].y,
@@ -238,6 +267,56 @@ draw_qix(ModeInfo * mi)
 				XDrawLine(display, MI_WINDOW(mi), gc,
 					qp->position[i].x, qp->position[i].y,
 				       qp->position[j].x, qp->position[j].y);
+	} else if (qp->kaleid) {
+		for (i = 0; i < qp->npoints; i++) {
+			XSegment    segs[8];
+			XPoint      small[2];
+
+			j = (i + 1) % qp->npoints;
+			small[0].x = ABS(qp->position[i].x - qp->mid);
+			small[0].y = ABS(qp->position[i].y - qp->mid);
+			small[1].x = ABS(qp->position[j].x - qp->mid);
+			small[1].y = ABS(qp->position[j].y - qp->mid);
+			segs[0].x1 = qp->midx + small[0].x;
+			segs[0].y1 = qp->midy + small[0].y;
+			segs[0].x2 = qp->midx + small[1].x;
+			segs[0].y2 = qp->midy + small[1].y;
+			segs[1].x1 = qp->midx - small[0].x;
+			segs[1].y1 = qp->midy + small[0].y;
+			segs[1].x2 = qp->midx - small[1].x;
+			segs[1].y2 = qp->midy + small[1].y;
+			segs[2].x1 = qp->midx - small[0].x;
+			segs[2].y1 = qp->midy - small[0].y;
+			segs[2].x2 = qp->midx - small[1].x;
+			segs[2].y2 = qp->midy - small[1].y;
+			segs[3].x1 = qp->midx + small[0].x;
+			segs[3].y1 = qp->midy - small[0].y;
+			segs[3].x2 = qp->midx + small[1].x;
+			segs[3].y2 = qp->midy - small[1].y;
+			segs[4].x1 = qp->midx + small[0].y;
+			segs[4].y1 = qp->midy + small[0].x;
+			segs[4].x2 = qp->midx + small[1].y;
+			segs[4].y2 = qp->midy + small[1].x;
+			segs[5].x1 = qp->midx + small[0].y;
+			segs[5].y1 = qp->midy - small[0].x;
+			segs[5].x2 = qp->midx + small[1].y;
+			segs[5].y2 = qp->midy - small[1].x;
+			segs[6].x1 = qp->midx - small[0].y;
+			segs[6].y1 = qp->midy - small[0].x;
+			segs[6].x2 = qp->midx - small[1].y;
+			segs[6].y2 = qp->midy - small[1].x;
+			segs[7].x1 = qp->midx - small[0].y;
+			segs[7].y1 = qp->midy + small[0].x;
+			segs[7].x2 = qp->midx - small[1].y;
+			segs[7].y2 = qp->midy + small[1].x;
+			XDrawSegments(display, MI_WINDOW(mi), gc, segs, 8);
+			if (qp->npoints == 2)	/* do not repeat drawing the same line */
+				break;
+		}
+		if (++qp->linecount >= qp->nlines) {
+			qp->linecount = 0;
+			MI_CLEARWINDOW(mi);
+		}
 	} else {
 		for (i = 1; i < qp->npoints + ((qp->npoints == 2) ? -1 : 0); i++)
 			XDrawLine(display, MI_WINDOW(mi), gc,
@@ -247,13 +326,14 @@ draw_qix(ModeInfo * mi)
 			  qp->position[qp->npoints - 1].x, qp->position[qp->npoints - 1].y);
 	}
 
-	for (i = 0; i < qp->npoints; i++) {
-		qp->lineq[qp->last].x = qp->position[i].x;
-		qp->lineq[qp->last].y = qp->position[i].y;
-		qp->last++;
-		if (qp->last >= qp->nlines)
-			qp->last = 0;
-	}
+	if (!qp->kaleid)
+		for (i = 0; i < qp->npoints; i++) {
+			qp->lineq[qp->last].x = qp->position[i].x;
+			qp->lineq[qp->last].y = qp->position[i].y;
+			qp->last++;
+			if (qp->last >= qp->nlines)
+				qp->last = 0;
+		}
 	if (qp->redrawing) {
 		for (i = 0; i < REDRAWSTEP; i++) {
 			j = (qp->first - qp->redrawpos + qp->nlines - qp->npoints) % qp->nlines;
@@ -263,7 +343,7 @@ draw_qix(ModeInfo * mi)
 						XDrawLine(display, MI_WINDOW(mi), gc,
 							  qp->lineq[j + k].x, qp->lineq[j + k].y,
 							  qp->lineq[j + l].x, qp->lineq[j + l].y);
-			} else {
+			} else if (!qp->kaleid) {
 				for (k = 1; k < qp->npoints + ((qp->npoints == 2) ? -1 : 0); k++)
 					XDrawLine(display, MI_WINDOW(mi), gc,
 						  qp->lineq[j + k - 1].x, qp->lineq[j + k - 1].y,
