@@ -42,36 +42,46 @@ static const char sccsid[] = "@(#)random.c	4.07 97/11/24 xlockmore";
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
+#include "color.h"
+#include "util.h"
 #endif /* STANDALONE */
 
 #define DEF_DURATION	"60"	/* 0 == infinite duration */
 #define DEF_MODELIST	""
 #define DEF_SEQUENTIAL "False"
+#define DEF_FULLRANDOM "True"
 
 static int  duration;
 static char *modelist;
 static Bool sequential;
+extern Bool fullrandom;
 
 static XrmOptionDescRec opts[] =
 {
 	{"-duration", ".random.duration", XrmoptionSepArg, (caddr_t) NULL},
 	{"-modelist", ".random.modelist", XrmoptionSepArg, (caddr_t) NULL},
 	{"-sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-	{"+sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "off"}
+      {"+sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{"-sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
+      {"+sequential", ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{"-fullrandom", ".random.fullrandom", XrmoptionNoArg, (caddr_t) "on"},
+	{"+fullrandom", ".random.fullrandom", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
 	{(caddr_t *) & duration, "duration", "Duration", DEF_DURATION, t_Int},
     {(caddr_t *) & modelist, "modelist", "Modelist", DEF_MODELIST, t_String},
-{(caddr_t *) & sequential, "sequential", "Sequential", DEF_SEQUENTIAL, t_Bool}
+	{(caddr_t *) & sequential, "sequential", "Sequential", DEF_SEQUENTIAL, t_Bool},
+{(caddr_t *) & fullrandom, "fullrandom", "FullRandom", DEF_FULLRANDOM, t_Bool}
 };
 
 static OptionStruct desc[] =
 {
 	{"-duration num", "how long a mode runs before changing to another"},
 	{"-modelist string", "list of modes to randomly choose from"},
-	{"-/+sequential", "turn on/off picking of modes sequentially"}
+	{"-/+sequential", "turn on/off picking of modes sequentially"},
+	{"-/+fullrandom", "turn on/off full random choice of mode-options"}
 };
 
 ModeSpecOpt random_opts =
@@ -114,12 +124,18 @@ extern char *bitmap;
 #ifdef USE_GL
 static char gl_modes[][MAXMODECHARS] =
 {
-    "atlantis", "cage", "gears", "bubble3d",
+	"atlantis", "bubble3d", "cage", "gears",
 	"moebius", "morph3d", "pipes", "rubik",
-    "sproingies", "stairs", "superquadrics"
+	"sproingies", "stairs", "superquadrics"
+#if defined(USE_TEXT)
+	,"text3d"
+#endif
+#if defined( USE_UNSTABLE ) && (defined( USE_XPM ) || defined( USE_XPMINC ))
+	,"lament"
+#endif
 };
 
-#define NUMGL (sizeof (gl_modes) / sizeof (gl_modes[0]))
+#define NUMGL (int) (sizeof (gl_modes) / sizeof (gl_modes[0]))
 #else
 static char gl_modes[][MAXMODECHARS] =
 {""};
@@ -133,7 +149,7 @@ static char xpm_modes[][MAXMODECHARS] =
 	"bat", "cartoon", "image", "flag", "life", "life1d", "maze", "puzzle"
 };
 
-#define NUMXPM (sizeof (xpm_modes) / sizeof (xpm_modes[0]))
+#define NUMXPM (int) (sizeof (xpm_modes) / sizeof (xpm_modes[0]))
 #else
 /* They will not really be xpm_modes anymore... */
 static char xpm_modes[][MAXMODECHARS] =
@@ -141,16 +157,17 @@ static char xpm_modes[][MAXMODECHARS] =
 	"bat", "image", "flag", "life", "life1d", "maze", "puzzle"
 };
 
-#define NUMXPM (sizeof (xpm_modes) / sizeof (xpm_modes[0]))
+#define NUMXPM (int) (sizeof (xpm_modes) / sizeof (xpm_modes[0]))
 
 #endif
 
 static char write_modes[][MAXMODECHARS] =
 {
-	"mandelbrot", "swirl", "tube"	/* XPM modes are usually writable too ... */
+	"crystal", "mandelbrot", "starfish", "swirl", "tube"
+	/* XPM modes are usually writable too ... */
 };
 
-#define NUMWRITE (sizeof (write_modes) / sizeof (write_modes[0]))
+#define NUMWRITE (int) (sizeof (write_modes) / sizeof (write_modes[0]))
 
 static char nice_modes[][MAXMODECHARS] =
 {
@@ -176,21 +193,21 @@ static char nice_modes[][MAXMODECHARS] =
 	"world", "worm"
 };
 
-#define NUMNICE (sizeof (nice_modes) / sizeof (nice_modes[0]))
+#define NUMNICE (int) (sizeof (nice_modes) / sizeof (nice_modes[0]))
 
 static char use3d_modes[][MAXMODECHARS] =
 {
-	"bouboule", "pyro", "star", "worm"
+	"bouboule", "hyper", "pyro", "star", "worm"
 };
 
-#define NUMUSE3D (sizeof (use3d_modes) / sizeof (use3d_modes[0]))
+#define NUMUSE3D (int) (sizeof (use3d_modes) / sizeof (use3d_modes[0]))
 
 static char mouse_modes[][MAXMODECHARS] =
 {
 	"eyes", "julia", "swarm"
 };
 
-#define NUMMOUSE (sizeof (mouse_modes) / sizeof (mouse_modes[0]))
+#define NUMMOUSE (int) (sizeof (mouse_modes) / sizeof (mouse_modes[0]))
 
 static char automata_modes[][MAXMODECHARS] =
 {
@@ -198,7 +215,7 @@ static char automata_modes[][MAXMODECHARS] =
 	"voters", "wator", "wire"
 };
 
-#define NUMAUTOMATA (sizeof (automata_modes) / sizeof (automata_modes[0]))
+#define NUMAUTOMATA (int) (sizeof (automata_modes) / sizeof (automata_modes[0]))
 
 static char fractal_modes[][MAXMODECHARS] =
 {
@@ -207,7 +224,7 @@ static char fractal_modes[][MAXMODECHARS] =
 	"sierpinski", "strange", "thornbird", "triangle", "turtle", "vines"
 };
 
-#define NUMFRACTAL (sizeof (fractal_modes) / sizeof (fractal_modes[0]))
+#define NUMFRACTAL (int) (sizeof (fractal_modes) / sizeof (fractal_modes[0]))
 
 
 static char geometry_modes[][MAXMODECHARS] =
@@ -217,14 +234,14 @@ static char geometry_modes[][MAXMODECHARS] =
 	"shape", "sphere", "spiral", "spline"
 };
 
-#define NUMGEOMETRY (sizeof (geometry_modes) / sizeof (geometry_modes[0]))
+#define NUMGEOMETRY (int) (sizeof (geometry_modes) / sizeof (geometry_modes[0]))
 
 static char space_modes[][MAXMODECHARS] =
 {
 	"bouboule", "galaxy", "grav", "star", "world"
 };
 
-#define NUMSPACE (sizeof (space_modes) / sizeof (space_modes[0]))
+#define NUMSPACE (int) (sizeof (space_modes) / sizeof (space_modes[0]))
 
 typedef struct {
 	XGCValues   gcvs;
@@ -482,6 +499,7 @@ init_random(ModeInfo * mi)
 
 	if (currentmode < 0) {
 		parsemodelist(mi);
+		MI_SET_FLAG_STATE(mi, WI_FLAG_FULLRANDOM, fullrandom);
 
 		for (i = startscreen; i < MI_NUM_SCREENS(mi); i++) {
 			(void) XGetGCValues(MI_DISPLAY(mi), MI_GC(mi),
