@@ -155,9 +155,9 @@ init_roll(ModeInfo * mi)
 	rp = &rolls[MI_SCREEN(mi)];
 
 	ang = (double) NRAND(75) + 7.5;
-	rp->direction.x = ((2 * (LRAND() & 1)) - 1) * (int)
+	rp->direction.x = (short) ((2 * (LRAND() & 1)) - 1) * (int)
 		(SPEED * SINF(ang * M_PI / 180.0));
-	rp->direction.y = ((2 * (LRAND() & 1)) - 1) * (int)
+	rp->direction.y = (short) ((2 * (LRAND() & 1)) - 1) * (int)
 		(SPEED * COSF(ang * M_PI / 180.0));
 	rp->width = MI_WIDTH(mi);
 	rp->height = MI_HEIGHT(mi);
@@ -214,6 +214,8 @@ draw_roll(ModeInfo * mi)
 	rollstruct *rp = &rolls[MI_SCREEN(mi)];
 	int         i;
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < rp->maxpts; i++) {
 		rp->pts[i].t = rp->pts[i].t1;
 		rp->pts[i].u = rp->pts[i].u1;
