@@ -30,7 +30,7 @@ static const char sccsid[] = "@(#)shape.c	4.07 97/11/24 xlockmore";
  * 27-Feb-95: patch for VMS
  * 29-Sep-94: multidisplay bug fix <epstein_caleb@jpmorgan.com>
  * 15-Jul-94: xlock version David Bagley <bagleyd@bigfoot.com>
- * 1992:      xscreensaver version Jamie Zawinski <jwz@netscape.com>
+ * 1992:      xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
@@ -253,7 +253,10 @@ draw_shape(ModeInfo * mi)
 	int         shape, i;
 	XPoint      shade_offset;
 
-	shade_offset.x = shade_offset.y = 0;
+	MI_IS_DRAWN(mi) = True;
+
+	shade_offset.x = 0;
+	shade_offset.y = 0;
 	if (sp->stipple)
 		if (!sp->init_bits)
 			return;
@@ -268,8 +271,10 @@ draw_shape(ModeInfo * mi)
 	shape = NRAND(3);
 	if (sp->shade) {
 		i = MAX(ABS(sp->shade_offset.x), ABS(sp->shade_offset.y));
-		shade_offset.x = ((float) NRAND(i) + 2.0) / (1.0 + i) * sp->shade_offset.x;
-		shade_offset.y = ((float) NRAND(i) + 2.0) / (1.0 + i) * sp->shade_offset.y;
+		shade_offset.x = (short int) (((float) NRAND(i) + 2.0) /
+					      (1.0 + i) * sp->shade_offset.x);
+		shade_offset.y = (short int) (((float) NRAND(i) + 2.0) /
+					      (1.0 + i) * sp->shade_offset.y);
 		/* This is over-simplistic... it casts the same length shadow over
 		 * different depth objects.
 		 */
