@@ -22,7 +22,7 @@ static const char sccsid[] = "@(#)spiral.c	4.07 97/11/24 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
- * 10-May-97: jwz@netscape.com: turned into a standalone program.
+ * 10-May-97: jwz@jwz.org: turned into a standalone program.
  * 24-Jul-95: Fix to allow cycles not to have an arbitrary value by
  *            Peter Schmitzberger (schmitz@coma.sbg.ac.at).
  * 06-Mar-95: Finished cleaning up and final testing.
@@ -192,6 +192,8 @@ draw_spiral(ModeInfo * mi)
 	spiralstruct *sp = &spirals[MI_SCREEN(mi)];
 	int         i, j;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (sp->erase == 1) {
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		draw_dots(mi, sp->inc);
