@@ -35,7 +35,7 @@ static const char sccsid[] = "@(#)star.c	4.07 97/11/24 xlockmore";
  *            Get out your 3D glasses, Red on right and Blue on left.
  * 14-Apr-95: Jeremie PETIT <petit@aurora.unice.fr> added a "move" feature.
  * 2-Sep-93: xlock version David Bagley <bagleyd@bigfoot.com>
- * 1992:     xscreensaver version Jamie Zawinski <jwz@netscape.com>
+ * 1992:     xscreensaver version Jamie Zawinski <jwz@jwz.org>
  */
 
 /*-
@@ -594,7 +594,7 @@ compute_move(starstruct * sp, int axe)
 
 	if (!straight && !NRAND(DIRECTION_CHANGE_RATE)) {
 		/* We change direction */
-		change = LRAND() & 1;
+		change = (int) (LRAND() & 1);
 		if (change != 1) {
 			if (sp->direction[axe] == 0)
 				sp->direction[axe] = change - 1;	/* 0 becomes either 1 or -1 */
@@ -674,6 +674,8 @@ draw_star(ModeInfo * mi)
 {
 	starstruct *sp = &stars[MI_SCREEN(mi)];
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (sp->current_delta != sp->new_delta) {
 		if (sp->dchange_tick++ == 5) {
 			sp->dchange_tick = 0;
