@@ -138,7 +138,9 @@ init_swarm(ModeInfo * mi)
 		Pixmap      bit;
 		XColor      black;
 
-		black.red = black.green = black.blue = 0;
+		black.red = 0;
+		black.green = 0;
+		black.blue = 0;
 		black.flags = DoRed | DoGreen | DoBlue;
 		bit = XCreatePixmapFromBitmapData(display, window, "\000", 1, 1,
 						  MI_BLACK_PIXEL(mi),
@@ -195,6 +197,8 @@ draw_swarm(ModeInfo * mi)
 	Bool        track_p = MI_IS_MOUSE(mi);
 	int         cx, cy;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (track_p) {
 		Window      r, c;
 		int         rx, ry;
