@@ -57,7 +57,7 @@ static const char sccsid[] = "@(#)triangle.c	4.07 97/11/24 xlockmore";
  "*wireframe: False \n" \
  "*fullrandom: False \n"
 #define SMOOTH_COLORS
-			      /* #define UNIFORM_COLORS *//* To get blue water uncomment, but ... */
+							  /* #define UNIFORM_COLORS *//* To get blue water uncomment, but ... */
 #include "xlockmore.h"		/* in xscreensaver distribution */
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
@@ -139,10 +139,10 @@ draw_atriangle(ModeInfo * mi, XPoint * p, int y_0, int y_1, int y_2, double dinv
 		}
 
 		XSetForeground(display, gc, MI_PIXEL(mi, color % MI_NPIXELS(mi)));
-		if (tp->joke)
-			if ((Bool) (LRAND() & 1)) {
+		if (tp->joke) {
+			if ((Bool) (LRAND() & 1))
 				XDrawLines(display, window, gc, p, 4, CoordModeOrigin);
-			} else {
+			else
 				XFillPolygon(display, window, gc, p, 3, Convex, CoordModeOrigin);
 		} else if (tp->wireframe) {
 			XDrawLines(display, window, gc, p, 4, CoordModeOrigin);
@@ -300,6 +300,8 @@ draw_triangle(ModeInfo * mi)
 	trianglestruct *tp = &triangles[MI_SCREEN(mi)];
 	int         d, d2, i, j, delta;
 
+	MI_IS_DRAWN(mi) = True;
+
 	if (tp->busyLoop > 0) {
 		if (tp->busyLoop >= 100)
 			tp->busyLoop = -1;
@@ -340,7 +342,7 @@ draw_triangle(ModeInfo * mi)
 	}
 	if (tp->stage == tp->steps) {
 #ifdef STANDALONE
-    erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
+		erase_full_window(MI_DISPLAY(mi), MI_WINDOW(mi));
 #endif
 		init_triangle(mi);
 	}
