@@ -43,6 +43,8 @@ static const char sccsid[] = "@(#)tube.c 4.07 97/11/24 xlockmore";
 #include <X11/Xutil.h>
 #else /* !STANDALONE */
 #include "xlock.h"		/* from the xlockmore distribution */
+#include "vis.h"
+#include "color.h"
 #endif /* !STANDALONE */
 
 ModeSpecOpt tube_opts =
@@ -216,6 +218,8 @@ draw_tube(ModeInfo * mi)
 	unsigned int i, j;
 	int         k, lw = tp->linewidth / 2;
 
+	MI_IS_DRAWN(mi) = True;
+
 	/* advance drawing color */
 	tp->cur_color = (tp->cur_color + 1) % tp->ncolors;
 #ifndef STANDALONE
