@@ -41,10 +41,10 @@ static const char sccsid[] = "@(#)voters.c	4.07 97/11/24 xlockmore";
 #define UNIFORM_COLORS
 #define BRIGHT_COLORS
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "automata.h"
 
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
@@ -173,10 +173,10 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		}
 	} else if (vp->neighbors == 4 || vp->neighbors == 8) {
 		if (vp->pixelmode) {
-			if (bitmap == BITMAPS - 1 || (vp->xs == 1 && vp->ys == 1))
+			if (bitmap == BITMAPS - 1 || (vp->xs <= 2 || vp->ys <= 2))
 				XFillRectangle(display, window, gc,
 				vp->xb + vp->xs * col, vp->yb + vp->ys * row,
-					       vp->xs, vp->ys);
+				vp->xs - (vp->xs > 3), vp->ys - (vp->ys > 3));
 			else {
 				if (firstChange) {
 					XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
@@ -186,7 +186,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 					XSetForeground(display, gc, colour);
 				}
 				XFillArc(display, window, gc,
-					 vp->xb + vp->xs * col, vp->yb + vp->ys * row, vp->xs, vp->ys,
+					 vp->xb + vp->xs * col, vp->yb + vp->ys * row,
+					 vp->xs - 1, vp->ys - 1,
 					 0, 23040);
 			}
 		} else
@@ -727,6 +728,8 @@ draw_voters(ModeInfo * mi)
 	int         new_opinion, old_opinion;
 	cellstruct  info;
 
+	MI_IS_DRAWN(mi) = True;
+
 	vp->painted = True;
 	if (vp->busyLoop) {
 		if (vp->busyLoop >= 5000)
