@@ -41,10 +41,10 @@ static const char sccsid[] = "@(#)wator.c	4.07 97/11/24 xlockmore";
  "*ncolors: 200 \n" \
  "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "automata.h"
 
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
@@ -170,7 +170,8 @@ drawshape(ModeInfo * mi, int x, int y, int sizex, int sizey,
 		x - icon_width, y - icon_height / 2, icon_width, icon_height);
 	} else if (sizex < 3 || sizey < 3 || (sides == 4 && shape == 1)) {
 		XFillRectangle(display, window, gc,
-			       x - sizex / 2, y - sizey / 2, sizex, sizey);
+			x - sizex / 2, y - sizey / 2,
+			sizex - (sizey > 3), sizey - (sizey > 3));
 	} else if (sides == 4 && shape == 0) {
 	} else if (sides == 6 && shape == 1) {
 	} else if (sides == 6 && shape == 0) {
@@ -218,7 +219,7 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 			if (wp->xs <= 6 || wp->ys <= 2)
 				XFillRectangle(display, window, gc,
 				     wp->shape.hexagon[0].x - 3 * wp->xs / 4,
-					       wp->shape.hexagon[0].y + wp->ys / 4, wp->xs, wp->ys);
+				     wp->shape.hexagon[0].y + wp->ys / 4, wp->xs, wp->ys);
 			else
 				XFillArc(display, window, gc,
 				     wp->xb + wp->xs * ccol - 3 * wp->xs / 4,
@@ -228,10 +229,10 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 		}
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		if (wp->pixelmode) {
-			if (bitmap >= KINDBITMAPS || (wp->xs == 1 && wp->ys == 1) || !alive)
+			if (bitmap >= KINDBITMAPS || (wp->xs <= 2 || wp->ys <= 2) || !alive)
 				XFillRectangle(display, window, gc,
 				wp->xb + wp->xs * col, wp->yb + wp->ys * row,
-					       wp->xs, wp->ys);
+				wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
 			else {
 				XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 				XFillRectangle(display, window, gc,
@@ -239,7 +240,8 @@ drawcell(ModeInfo * mi, int col, int row, unsigned long color, int bitmap,
 					       wp->xs, wp->ys);
 				XSetForeground(display, gc, colour);
 				XFillArc(display, window, gc,
-					 wp->xb + wp->xs * col, wp->yb + wp->ys * row, wp->xs, wp->ys,
+					 wp->xb + wp->xs * col, wp->yb + wp->ys * row,
+					 wp->xs - 1, wp->ys - 1,
 					 0, 23040);
 			}
 		} else
@@ -802,6 +804,8 @@ draw_wator(ModeInfo * mi)
 	} acell[12];
 
 
+	MI_IS_DRAWN(mi) = True;
+
 	wp->painted = True;
 	/* Alternate updates, fish and sharks live out of phase with each other */
 	wp->kind = (wp->kind + 1) % KINDS;
@@ -831,8 +835,8 @@ draw_wator(ModeInfo * mi)
 						wp->currkind->info.direction = (5 - acell[i].dir) % ORIENTS +
 							((NRAND(REFLECTS)) ? 0 : ORIENTS) + wp->kind * KINDBITMAPS;
 					} else if (wp->neighbors == 8) {
-						wp->currkind->info.direction = (5 - (acell[i].dir / 2 +
-										     ((acell[i].dir % 2) ? LRAND() & 1 : 0))) % ORIENTS +
+						wp->currkind->info.direction = (char) (5 - (acell[i].dir / 2 +
+											    ((acell[i].dir % 2) ? LRAND() & 1 : 0))) % ORIENTS +
 							((NRAND(REFLECTS)) ? 0 : ORIENTS) + wp->kind * KINDBITMAPS;
 					} else
 						wp->currkind->info.direction = wp->kind * KINDBITMAPS;
@@ -887,8 +891,8 @@ draw_wator(ModeInfo * mi)
 						wp->currkind->info.direction = (5 - acell[i].dir) % ORIENTS +
 							((NRAND(REFLECTS)) ? 0 : ORIENTS) + wp->kind * KINDBITMAPS;
 					} else if (wp->neighbors == 8) {
-						wp->currkind->info.direction = (5 - (acell[i].dir / 2 +
-										     ((acell[i].dir % 2) ? LRAND() & 1 : 0))) % ORIENTS +
+						wp->currkind->info.direction = (char) (5 - (acell[i].dir / 2 +
+											    ((acell[i].dir % 2) ? LRAND() & 1 : 0))) % ORIENTS +
 							((NRAND(REFLECTS)) ? 0 : ORIENTS) + wp->kind * KINDBITMAPS;
 					} else
 						wp->currkind->info.direction = wp->kind * KINDBITMAPS;
