@@ -69,10 +69,10 @@ static const char sccsid[] = "@(#)wire.c	4.07 97/11/24 xlockmore";
  "*ncolors: 64 \n" \
  "*neighbors: 0 \n"
 #include "xlockmore.h"		/* in xscreensaver distribution */
-#include "automata.h"
 #else /* STANDALONE */
 #include "xlock.h"		/* in xlockmore distribution */
 #endif /* STANDALONE */
+#include "automata.h"
 
 /*-
  * neighbors of 0 randomizes it between 3, 4, 6, 8, 9, and 12.
@@ -353,7 +353,8 @@ fillcell(ModeInfo * mi, GC gc, int col, int row)
 			    wp->shape.hexagon, 6, Convex, CoordModePrevious);
 	} else if (wp->neighbors == 4 || wp->neighbors == 8) {
 		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-		wp->xb + wp->xs * col, wp->yb + wp->ys * row, wp->xs, wp->ys);
+		wp->xb + wp->xs * col, wp->yb + wp->ys * row,
+		wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
 	} else {		/* TRI */
 		int         orient = (col + row) % 2;	/* O left 1 right */
 
@@ -417,7 +418,8 @@ drawcell_notused(ModeInfo * mi, int col, int row, unsigned char state)
 		gc = wp->stippledGC;
 	}
 	XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-	       wp->xb + wp->xs * col, wp->yb + wp->ys * row, wp->xs, wp->ys);
+	       wp->xb + wp->xs * col, wp->yb + wp->ys * row,
+		wp->xs - (wp->xs > 3), wp->ys - (wp->ys > 3));
 }
 #endif
 
@@ -518,8 +520,8 @@ draw_state(ModeInfo * mi, int state)
 		while (current) {
 			rects[ncells].x = wp->xb + current->pt.x * wp->xs;
 			rects[ncells].y = wp->yb + current->pt.y * wp->ys;
-			rects[ncells].width = wp->xs;
-			rects[ncells].height = wp->ys;
+			rects[ncells].width = wp->xs - (wp->xs > 3);
+			rects[ncells].height = wp->ys - (wp->ys > 3);
 			current = current->next;
 			ncells++;
 		}
@@ -871,6 +873,8 @@ draw_wire(ModeInfo * mi)
 	int         offset, i, j;
 	unsigned char *z, *znew;
 
+	MI_IS_DRAWN(mi) = True;
+
 	/* wires do not grow so min max stuff does not change */
 	for (j = wp->minrow; j <= wp->maxrow; j++) {
 		for (i = wp->mincol; i <= wp->maxcol; i++) {
