@@ -167,7 +167,9 @@ worm_doit(ModeInfo * mi, int which, unsigned long color)
 			ws->dir2 = (ws->dir2 + 1) % SEGMENTS;
 		else
 			ws->dir2 = (ws->dir2 + SEGMENTS - 1) % SEGMENTS;
-		/* for the z-axis the wrap-around looks bad, so worms should just turn around. */
+		/* for the z-axis the wrap-around looks bad,
+		   * so worms should just turn around.
+		 */
 		z = (int) (ws->z + wp->circsize * sintab[ws->dir2]);
 		if (z < 0 || z >= wp->zsize)
 			z = (int) (ws->z - wp->circsize * sintab[ws->dir2]);
@@ -378,6 +380,8 @@ draw_worm(ModeInfo * mi)
 
 	(void) memset((char *) wp->size, 0, wp->nc * sizeof (int));
 
+	MI_IS_DRAWN(mi) = True;
+
 	for (i = 0; i < wp->nw; i++) {
 		if (MI_NPIXELS(mi) > 2) {
 			wcolor = (i + wp->chromo) % wp->nc;
