@@ -1,11 +1,9 @@
-typedef struct
-  {
-    int tag;
-    char *label;
-    void *data;
-    int init;
-  }
-TagList;
+typedef struct {
+	int         tag;
+	char       *label;
+	void       *data;
+	int         init;
+} TagList;
 
 #ifndef TRUE
 #define TRUE  1
@@ -23,4 +21,4 @@ TagList;
 #define TAG_INIT    1
 #define TAG_NOINIT  0
 
-int GetValues (TagList * tags);
+int         GetValues(TagList * tags);
