@@ -22,6 +22,8 @@ extern char *messagefontname;
 
 #else
 #include "xlock.h"
+#include "vis.h"
+#include "color.h"
 char       *message, *messagefile, *messagesfile, *program;
 char       *messagefontname;
 
@@ -70,12 +72,10 @@ randomFileFromList(char *directory,
 {
 	int         num;
 
-	if (numfiles > 0) {
-		num = NRAND(numfiles);
-		if (strlen(directory) + strlen(filelist[num]->d_name) + 1 < 256) {
-			(void) sprintf(file_local, "%s%s",
-				       directory, filelist[num]->d_name);
-		}
+	num = NRAND(numfiles);
+	if (strlen(directory) + strlen(filelist[num]->d_name) + 1 < 256) {
+		(void) sprintf(file_local, "%s%s",
+			       directory, filelist[num]->d_name);
 	}
 }
 
@@ -203,13 +203,20 @@ sel_image(struct dirent *name)
 			++numfrag;
 			filename_tmp = filename_tmp + ip;
 		}
+/* PURIFY says this leaks */
 		frags[numfrag] = (char *) malloc(strlen(filename_tmp) + 1);
 		(void) strcpy(frags[numfrag], filename_tmp);
 	}
 	for (i = 0; i <= numfrag; ++i) {
 		ip = index_dir(name_tmp, frags[i]);
-		if (ip == 0)
+		(void) free((void *) frags[i]);
+		if (ip == 0) {
+			int         j;
+
+			for (j = i + 1; j <= numfrag; ++j)
+				(void) free((void *) frags[j]);
 			return (0);
+		}
 		name_tmp = name_tmp + ip;
 	}
 
@@ -228,13 +235,21 @@ scan_dir(const char *directoryname, struct dirent ***namelist,
 	struct dirent *new_entry, **namelist_tmp;
 	int         size_tmp, num_list_tmp;
 
-	if ((dirp = opendir(directoryname)) == NULL)
+	if (debug)
+		(void) printf("scan_dir directoryname %s\n", directoryname);
+	if ((dirp = opendir(directoryname)) == NULL) {
+		if (debug)
+			(void) printf("scan_dir can not open directoryname %s\n", directoryname);
 		return (-1);
+	}
 	size_tmp = _MEMBL_;
 	namelist_tmp = (struct dirent **) malloc(size_tmp * sizeof (struct dirent *));
 
-	if (namelist_tmp == NULL)
+	if (namelist_tmp == NULL) {
+		if (debug)
+			(void) printf("scan_dir no memory\n");
 		return (-1);
+	}
 	num_list_tmp = 0;
 	while ((new_entry = readdir(dirp)) != NULL) {
 #ifndef VMS
@@ -248,8 +263,11 @@ scan_dir(const char *directoryname, struct dirent ***namelist,
 			namelist_tmp = (struct dirent **) realloc(
 									 (void *) namelist_tmp, size_tmp * sizeof (struct dirent *));
 
-			if (namelist_tmp == NULL)
+			if (namelist_tmp == NULL) {
+				if (debug)
+					(void) printf("scan_dir no memory\n");
 				return (-1);
+			}
 		}
 		namelist_tmp[num_list_tmp - 1] =
 			(struct dirent *) malloc(sizeof (struct dirent)
@@ -268,6 +286,8 @@ scan_dir(const char *directoryname, struct dirent ***namelist,
 		(void) qsort((void *) namelist_tmp, num_list_tmp,
 			     sizeof (struct dirent *), compare);
 
+	if (debug)
+		(void) printf("scan_dir number %d\n", num_list_tmp);
 	*namelist = namelist_tmp;
 	return (num_list_tmp);
 }
@@ -279,7 +299,7 @@ static void
 getRandomImageFile(char *randomfile, char *randomfile_local)
 {
 	extern char directory_r[DIRBUF];
-	struct dirent ***images_list;
+	struct dirent ***images_list = NULL;
 	extern struct dirent **image_list;
 	extern int  num_list;
 	extern char filename_r[MAXNAMLEN];
@@ -290,11 +310,30 @@ getRandomImageFile(char *randomfile, char *randomfile_local)
 			int         (*compare) (const void *, const void *));
 
 	get_dir(randomfile, directory_r, filename_r);
+	if (image_list != NULL) {
+		int         i;
+
+		for (i = 0; i < num_list; i++) {
+			if (image_list[i] != NULL)
+				(void) free((void *) image_list[i]);
+		}
+		(void) free((void *) image_list);
+		image_list = NULL;
+	}
 	images_list = (struct dirent ***) malloc(sizeof (struct dirent **));
 
 	num_list = scan_dir(directory_r, images_list, sel_image, NULL);
 	image_list = *images_list;
-	randomFileFromList(directory_r, image_list, num_list, randomfile_local);
+	if (images_list) {
+		(void) free((void *) images_list);
+		images_list = NULL;
+	}
+	if (num_list > 0) {
+		randomFileFromList(directory_r, image_list, num_list, randomfile_local);
+	} else if (num_list < 0) {
+		image_list = NULL;
+		num_list = 0;
+	}
 }
 
 #endif
@@ -368,8 +407,8 @@ getImage(ModeInfo * mi, XImage ** logo,
 #ifdef STANDALONE
 		bitmap_local = MI_BITMAP(mi);
 #else
-		bitmap_local = malloc(256);
-		(void) strncpy(bitmap_local, MI_BITMAP(mi), sizeof (bitmap_local));
+		bitmap_local = (char *) malloc(256);
+		(void) strncpy(bitmap_local, MI_BITMAP(mi), 256);
 #if HAVE_DIRENT_H
 		getRandomImageFile(MI_BITMAP(mi), bitmap_local);
 #endif
@@ -389,9 +428,10 @@ getImage(ModeInfo * mi, XImage ** logo,
 					(void) GetColor(mi, MI_FG_PIXEL(mi));
 				}
 			}
-		} else
+		} else {
 			(void) fprintf(stderr,
 			       "could not read file \"%s\"\n", bitmap_local);
+		}
 #if defined( USE_XPM ) || defined( USE_XPMINC )
 #ifndef USE_MONOXPM
 		if (MI_NPIXELS(mi) > 2)
@@ -473,7 +513,7 @@ destroyImage(XImage ** logo, int *graphics_format)
 		case IS_XPM:
 		case IS_XPMFILE:
 		case IS_RASTERFILE:
-			if (logo)
+			if (logo && *logo)
 				(void) XDestroyImage(*logo);
 			break;
 	}
@@ -499,9 +539,10 @@ pickPixmap(Display * display, Drawable drawable, char *name,
 			if (*graphics_format <= 0)
 				(void) fprintf(stderr,
 					    "\"%s\" not xbm format\n", name);
-		} else
+		} else {
 			(void) fprintf(stderr,
 				       "could not read file \"%s\"\n", name);
+		}
 	}
 	if (*graphics_format <= 0) {
 		*width = default_width;
@@ -530,7 +571,8 @@ getPixmap(ModeInfo * mi, Drawable drawable,
 #ifdef STANDALONE
 		bitmap_local = MI_BITMAP(mi);
 #else
-		bitmap_local = malloc(256);
+		bitmap_local = (char *) malloc(256);
+		(void) strncpy(bitmap_local, MI_BITMAP(mi), 256);
 #if HAVE_DIRENT_H
 		getRandomImageFile(MI_BITMAP(mi), bitmap_local);
 #endif
@@ -572,9 +614,13 @@ getWords(int screen, int screens)
 	FILE       *pp;
 	static char *buf = NULL, progerr[BUFSIZ], progrun[BUFSIZ];
 	register char *p;
-	extern int  pclose(FILE *);
 	int         i;
 
+#if !defined(__cplusplus) && !defined(c_plusplus)
+	extern int  pclose(FILE *);
+
+#endif
+
 	if (!buf) {
 		buf = (char *) calloc(screens * BUFSIZ, sizeof (char));
 
@@ -591,9 +637,9 @@ getWords(int screen, int screens)
 		getwordsfrom = FROM_FORMATTEDFILE;
 	} else {
 		getwordsfrom = FROM_PROGRAM;
-   
+
 		(void) sprintf(progrun, "( %s ) 2>&1",
-			       (!program || !*program) ? DEF_PROGRAM : program);
+			    (!program || !*program) ? DEF_PROGRAM : program);
 	}
 
 	switch (getwordsfrom) {
@@ -618,7 +664,7 @@ getWords(int screen, int screens)
 					(void) memset((char *) progerr, 0, sizeof (progerr));
 					(void) strcpy(progerr, "sh: ");
 					strcat_firstword(progerr, (!program || !*program) ?
-            DEF_PROGRAM : program);
+						      DEF_PROGRAM : program);
 					(void) strcat(progerr, ": not found\n");
 					if (!strcmp(&buf[screen * BUFSIZ], progerr))
 						switch (NRAND(12)) {
