@@ -38,13 +38,13 @@ LockStruct  LockProcs[] =
 {
 	{"ant", init_ant, draw_ant, release_ant,
 	 refresh_ant, init_ant, NULL, &ant_opts,
-	 1000, -3, 40000, -7, 64, 1.0, "",
+	 1000, -3, 40000, -12, 64, 1.0, "",
 	 "Shows Langton's and Turk's generalized ants", 0, NULL},
 #ifdef USE_GL
 	{"atlantis", init_atlantis, draw_atlantis, release_atlantis,
 	 refresh_atlantis, change_atlantis, NULL, &atlantis_opts,
- 	1000, 4, 100, 6000, 64, 1.0, "",
- 	"Shows moving sharks/whales/dolphin", 0, NULL},
+	 1000, 4, 100, 6000, 64, 1.0, "",
+	 "Shows moving sharks/whales/dolphin", 0, NULL},
 #endif
 	{"ball", init_ball, draw_ball, release_ball,
 	 refresh_ball, init_ball, NULL, &ball_opts,
@@ -74,7 +74,7 @@ LockStruct  LockProcs[] =
 	 refresh_bubble, init_bubble, NULL, &bubble_opts,
 	 100000, 25, 1, 100, 64, 0.6, "",
 	 "Shows popping bubbles", 0, NULL},
-#if defined( USE_GL ) && defined( USE_UNSTABLE )
+#ifdef USE_GL
 	{"bubble3d", init_bubble3d, draw_bubble3d, release_bubble3d,
 	 draw_bubble3d, change_bubble3d, NULL, &bubble3d_opts,
 	 1000, 1, 2, 1, 64, 1.0, "",
@@ -206,10 +206,20 @@ LockStruct  LockProcs[] =
 	 refresh_julia, init_julia, NULL, &julia_opts,
 	 10000, 1000, 20, 1, 64, 1.0, "",
 	 "Shows the Julia set", 0, NULL},
-  {"kaleid", init_kaleid, draw_kaleid, release_kaleid,
-   refresh_kaleid, init_kaleid, NULL, &kaleid_opts,
-   80000, 4, 40, -9, 64, 0.6, "",
-   "Shows a kaleidoscope", 0, NULL},
+	{"kaleid", init_kaleid, draw_kaleid, release_kaleid,
+	 refresh_kaleid, init_kaleid, NULL, &kaleid_opts,
+	 80000, 4, 40, -9, 64, 0.6, "",
+	 "Shows a kaleidoscope", 0, NULL},
+	{"kumppa", init_kumppa, draw_kumppa, release_kumppa,
+	 refresh_kumppa, init_kumppa, NULL, &kumppa_opts,
+	 10000, 1, 1000, 1, 64, 1.0, "",
+	 "Shows kumppa", 0, NULL},
+#if defined( USE_GL ) && (defined( USE_XPM ) || defined( USE_XPMINC )) && defined( USE_UNSTABLE )
+	{"lament", init_lament, draw_lament, release_lament,
+	 draw_lament, change_lament, NULL, &lament_opts,
+	 10000, 1, 1, 1, 64, 1.0, "",
+	 "Shows Lemarchand's Box", 0, NULL},
+#endif
 	{"laser", init_laser, draw_laser, release_laser,
 	 refresh_laser, init_laser, NULL, &laser_opts,
 	 20000, -10, 200, 1, 64, 1.0, "",
@@ -363,6 +373,10 @@ LockStruct  LockProcs[] =
 	 refresh_star, init_star, NULL, &star_opts,
 	 75000, 100, 1, 100, 64, 0.3, "",
 	 "Shows a star field with a twist", 0, NULL},
+	{"starfish", init_starfish, draw_starfish, release_starfish,
+	 refresh_starfish, init_starfish, NULL, &starfish_opts,
+	 2000, 1, 1000, 1, 64, 1.0, "",
+	 "Shows starfish", 0, NULL},
 	{"strange", init_strange, draw_strange, release_strange,
 	 init_strange, init_strange, NULL, &strange_opts,
 	 1000, 1, 1, 1, 64, 1.0, "",
@@ -381,6 +395,12 @@ LockStruct  LockProcs[] =
 	 refresh_swirl, init_swirl, NULL, &swirl_opts,
 	 5000, 5, 1, 1, 64, 1.0, "",
 	 "Shows animated swirling patterns", 0, NULL},
+#if defined( USE_GL ) && defined( USE_TEXT )
+	{"text3d", init_text3d, draw_text3d, release_text3d,
+	 refresh_text3d, change_text3d, NULL, &text3d_opts,
+	 100000, 1, 1, 1, 64, 1.0, "",
+	 "Shows 3D texts", 0, NULL},
+#endif
 	{"thornbird", init_thornbird, draw_thornbird, release_thornbird,
 	 refresh_thornbird, NULL, NULL, &thornbird_opts,
 	 1000, 800, 16, 1, 64, 1.0, "",
