@@ -7,7 +7,7 @@
  * mode.h - mode management for xlock, the X Window System lockscreen.
  *
  * Copyright (c) 1991 by Patrick J. Naughton.
- * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -42,7 +42,7 @@
 /* xscreensaver compatibility layer for xlockmore modules. */
 
 /*-
- * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -54,7 +54,7 @@
  *
  * The definitions in this file make it possible to compile an xlockmore
  * module into a standalone program, and thus use it with xscreensaver.
- * By Jamie Zawinski <jwz@netscape.com> on 10-May-97; based on the ideas
+ * By Jamie Zawinski <jwz@jwz.org> on 10-May-97; based on the ideas
  * in the older xlock.h by Charles Hannum <mycroft@ai.mit.edu>.  (I had
  * to redo it, since xlockmore has diverged so far from xlock...)
  */
@@ -100,6 +100,7 @@
 #define MI_IS_USE3D(MI)	((MI)->threed)
 #define MI_COUNT(MI)	((MI)->count)
 #define MI_NCOLORS(MI)    ((MI)->ncolors)
+#define MI_IS_DRAWN(MI)((MI)->is_drawn)
 
 
 #define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
@@ -131,10 +132,10 @@ typedef struct ModeInfo {
 	long        pause;
 	Bool        fullrandom;
 	Bool        verbose;
-	long        count;
-	long        cycles;
-	long        size;
-	long        ncolors;
+	int         count;
+	int         cycles;
+	int         size;
+	int         ncolors;
 	Bool        threed;
 	long        threed_left_color;
 	long        threed_right_color;
@@ -144,6 +145,7 @@ typedef struct ModeInfo {
 	Bool        wireframe_p;
 	Bool        mouse;
 	char       *bitmap;
+	Bool        is_drawn;
 } ModeInfo;
 
 typedef enum {
@@ -215,10 +217,10 @@ typedef struct LockStruct_s {
 
 #define LS_FLAG_INITED		1
 
-												 /* #define ORIGINAL_XPM_PATCH *//* Not recommended */
 typedef struct {
 	Pixmap      pixmap;
 #ifdef ORIGINAL_XPM_PATCH
+	/* Not recommended */
 	Pixmap      bitmap;
 #else
 	int         width, height, graphics_format;
@@ -272,6 +274,8 @@ typedef struct {
 	int         height;	/* height of current window */
 	unsigned int flags;	/* xlock window flags */
 	float       delta3d;
+	Bool        is_drawn;	/*Indicates that enough is drawn for special *
+				 *  erase                                    */
 } WindowInfo;
 
 #define WI_FLAG_INFO_INITTED	0x001	/* private state flag */
@@ -292,10 +296,10 @@ typedef struct {
 typedef struct {
 	long        pause;	/* output, set by mode */
 	long        delay;	/* inputs, current settings */
-	long        count;
-	long        cycles;
-	long        ncolors;
-	long        size;
+	int         count;
+	int         cycles;
+	int         size;
+	int         ncolors;
 	float       saturation;
 	char       *bitmap;
 } RunInfo;
@@ -335,6 +339,7 @@ typedef struct ModeInfo_s {
 #define MI_HEIGHT(mi)	((mi)->windowinfo.height)
 #define MI_DELTA3D(mi)	((mi)->windowinfo.delta3d)
 #define MI_FLAGS(mi)	((mi)->windowinfo.flags)
+#define MI_IS_DRAWN(mi)	((mi)->windowinfo.is_drawn)
 #define MI_SET_FLAG_STATE(mi,f,bool) ((mi)->windowinfo.flags = \
 					(bool) ? (mi)->windowinfo.flags | f \
 					: (mi)->windowinfo.flags & ~(f))
@@ -375,7 +380,7 @@ typedef struct ModeInfo_s {
 #define MI_LEFT_COLOR(mi)	((mi)->screeninfo->left_pixel)
 
 #define MI_DELAY(mi)		((mi)->runinfo.delay)
-#define MI_COUNT(mi)	((mi)->runinfo.count)
+#define MI_COUNT(mi)		((mi)->runinfo.count)
 #define MI_CYCLES(mi)		((mi)->runinfo.cycles)
 #define MI_SIZE(mi)		((mi)->runinfo.size)
 #define MI_NCOLORS(mi)		((mi)->runinfo.ncolors)
@@ -403,6 +408,10 @@ typedef struct ModeInfo_s {
  * If it does happen it is probably not as noticable to worry about.
  */
 #endif
+
+extern void
+            erase_full_window(ModeInfo * mi, GC erase_gc, unsigned long pixel);
+
 #if 0
 #define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
 { \
@@ -419,9 +428,7 @@ typedef struct ModeInfo_s {
 #else
 #define MI_CLEARWINDOWCOLORMAP(mi, gc, pixel) \
 { \
- XSetForeground(MI_DISPLAY(mi), gc, pixel); \
- XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc, \
-   0, 0, (unsigned int) MI_WIDTH(mi), (unsigned int) MI_HEIGHT(mi)); \
+ erase_full_window( mi , gc , pixel ); \
 }
 #endif
 #define MI_CLEARWINDOWCOLOR(mi, pixel) \
@@ -507,7 +514,7 @@ extern ModeHook release_bubble;
 extern ModeHook refresh_bubble;
 extern ModeSpecOpt bubble_opts;
 
-#if defined( USE_GL ) && defined( USE_UNSTABLE )
+#ifdef USE_GL
 extern ModeHook init_bubble3d;
 extern ModeHook draw_bubble3d;
 extern ModeHook release_bubble3d;
@@ -717,6 +724,21 @@ extern ModeHook release_kaleid;
 extern ModeHook refresh_kaleid;
 extern ModeSpecOpt kaleid_opts;
 
+extern ModeHook init_kumppa;
+extern ModeHook draw_kumppa;
+extern ModeHook release_kumppa;
+extern ModeHook refresh_kumppa;
+extern ModeSpecOpt kumppa_opts;
+
+#if defined( USE_GL ) && (defined( USE_XPM ) || defined( USE_XPMINC )) && defined( USE_UNSTABLE )
+extern ModeHook init_lament;
+extern ModeHook draw_lament;
+extern ModeHook release_lament;
+extern ModeHook change_lament;
+extern ModeSpecOpt lament_opts;
+
+#endif
+
 extern ModeHook init_laser;
 extern ModeHook draw_laser;
 extern ModeHook release_laser;
@@ -954,6 +976,12 @@ extern ModeHook release_star;
 extern ModeHook refresh_star;
 extern ModeSpecOpt star_opts;
 
+extern ModeHook init_starfish;
+extern ModeHook draw_starfish;
+extern ModeHook release_starfish;
+extern ModeHook refresh_starfish;
+extern ModeSpecOpt starfish_opts;
+
 extern ModeHook init_strange;
 extern ModeHook draw_strange;
 extern ModeHook release_strange;
@@ -980,6 +1008,16 @@ extern ModeHook release_swirl;
 extern ModeHook refresh_swirl;
 extern ModeSpecOpt swirl_opts;
 
+#if defined( USE_GL ) && defined( USE_TEXT )
+extern ModeHook init_text3d;
+extern ModeHook draw_text3d;
+extern ModeHook release_text3d;
+extern ModeHook refresh_text3d;
+extern ModeHook change_text3d;
+extern ModeSpecOpt text3d_opts;
+
+#endif
+
 extern ModeHook init_thornbird;
 extern ModeHook draw_thornbird;
 extern ModeHook release_thornbird;
