@@ -32,6 +32,7 @@ static const char sccsid[] = "@(#)passwd.c	4.02 97/04/01 xlockmore";
  */
 
 #include "xlock.h"
+#include "iostuff.h"
 
 #ifdef VMS
 #include <str$routines.h>
@@ -338,12 +339,18 @@ static int  krb_check_password(struct passwd *, char *);
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
+#ifdef SunCplusplus
+#include <crypt.h>
+#else
+#if 0
 #if 1
 extern char *crypt(char *, char *);
 
 #else
 extern char *crypt(const char *, const char *);
 
+#endif
+#endif
 #endif
 #endif
 
@@ -359,7 +366,7 @@ my_passwd_entry(void)
 
 #endif
 
-	uid = getuid();
+	uid = (int) getuid();
 #ifndef SUNOS_ADJUNCT_PASSWD
 	{
 		char       *user = NULL;
@@ -377,6 +384,8 @@ my_passwd_entry(void)
 	if (!pw)
 #endif
 		pw = getpwuid(uid);
+	if (!pw)
+		return (pw);
 #ifdef HAVE_SHADOW
 	if ((spw = getspnam(pw->pw_name)) != NULL) {
 		char       *tmp;	/* swap */
@@ -530,7 +539,7 @@ gpasskey(char *pass)
 {
 	static char saltchars[CPASSCHARS + 1] =
 	"abcdefghijklmnopwrstuvwxyzABCDEFGHIJKLMNOPWRSTUVWXYZ1234567890./";
-	char        pw[9], salt[2], *pw2;
+	char        pw[9], salt[3], *pw2;
 
 #if 0
 	char       *getpass(const char *);
@@ -546,6 +555,7 @@ gpasskey(char *pass)
 	/* grab a random printable character that is not a colon */
 	salt[0] = saltchars[LRAND() & (CPASSCHARS - 1)];
 	salt[1] = saltchars[LRAND() & (CPASSCHARS - 1)];
+	salt[2] = '\0';
 	(void) strncpy(pass, (char *) crypt(pw, salt), CPASSLENGTH);
 }
 
@@ -1136,6 +1146,11 @@ checkPasswd(char *buffer)
 	if (!done) {
 		done = (allowroot &&
 			!strcmp((char *) crypt(buffer, rootpass), rootpass));
+		if (allowroot && !*rootpass && !*buffer)
+			/*
+			 * root has no password, don't let him in...
+			 */
+			done = False;
 #if ( HAVE_SYSLOG_H && defined( USE_SYSLOG ))
 		if (done)
 			syslog(SYSLOG_NOTICE, "%s: %s unlocked screen", ProgramName, ROOT);
