@@ -1,5 +1,5 @@
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)resource.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)resource.c	4.08 98/08/04 xlockmore";
 
 #endif
 
@@ -66,7 +66,8 @@ static const char sccsid[] = "@(#)resource.c	4.07 97/11/24 xlockmore";
  */
 
 #include "xlock.h"
-#include "mode.h"
+#include "vis.h"
+#include "iostuff.h"
 #include "version.h"
 #if VMS
 #if ( __VMS_VER < 70000000 )
@@ -83,13 +84,6 @@ static const char sccsid[] = "@(#)resource.c	4.07 97/11/24 xlockmore";
 #define offsetof(s,m) ((char*)(&((s *)0)->m)-(char*)0)
 #endif
 
-#if defined( USE_AUTO_LOGOUT ) || defined( USE_BUTTON_LOGOUT )
-extern int  fullLock();
-
-#endif
-
-extern char *getenv(const char *);
-
 #ifdef USE_MODULES
 #ifndef DEF_MODULEPATH
 #define DEF_MODULEPATH "/usr/lib/X11/xlock_modules"
@@ -129,7 +123,7 @@ typedef struct descriptor_t dsc;
 static int  descr();
 
 #else
-#define DEF_FILESEARCHPATH "/usr/lib/X11/%T/%N%S"
+#define DEF_FILESEARCHPATH "/usr/lib/X11/%T/%N%C%S:/usr/lib/X11/%T/%N%S"
 #endif
 #endif
 #ifndef DEF_MODE
@@ -146,6 +140,7 @@ static int  descr();
 #define DEF_NCOLORS	"64"	/* maximum number of colors */
 #define DEF_SATURATION	"1.0"	/* color ramp saturation 0->1 */
 #define DEF_NICE	"10"	/* xlock process nicelevel */
+#define DEF_ERASEDELAY	"400"	/* Speed for screen erase modes */
 #define DEF_LOCKDELAY	"0"	/* secs until lock */
 #define DEF_TIMEOUT	"30"	/* secs until password entry times out */
 #ifndef DEF_FONT
@@ -161,16 +156,32 @@ static int  descr();
 #endif
 #define DEF_BG		"White"
 #define DEF_FG		"Black"
+#ifdef FR
+#define DEF_NAME	"Nom: "
+#define DEF_PASS	"Mot de passe: "
+#define DEF_VALID	"Validation ..."
+#define DEF_INVALID	"Mot de passe Invalide."
+#define DEF_INFO	"Entrez le mot de passe ou choisissez l'icone pour verrouiller."
+#else
+#ifdef NL
+#define DEF_NAME  "Naam: "
+#define DEF_PASS  "Wachtwoord: "
+#define DEF_VALID "Aan het checken ..."
+#define DEF_INVALID "Ongeldig wachtwoord."
+#define DEF_INFO  "Geef wachtwoord om te ontgrendelen ; selecteer het icoon om te vergendelen."
+#else
 #define DEF_NAME	"Name: "
 #define DEF_PASS	"Password: "
+#define DEF_VALID	"Validating login..."
+#define DEF_INVALID	"Invalid login."
+#define DEF_INFO	"Enter password to unlock; select icon to lock."
+#endif
+#endif
 #ifdef SAFEWORD
 #define DEF_DPASS "Dynamic password: "
 #define DEF_FPASS "Fixed Password: "
 #define DEF_CHALL "Challenge: "
 #endif
-#define DEF_INFO	"Enter password to unlock; select icon to lock."
-#define DEF_VALID	"Validating login..."
-#define DEF_INVALID	"Invalid login."
 #define DEF_GEOMETRY	""
 #define DEF_ICONGEOMETRY	""
 #ifdef FX
@@ -248,6 +259,16 @@ static int  descr();
 #endif
 #endif
 
+#ifdef FR
+#define DEF_BTN_LABEL	"Logout"
+#define DEF_BTN_HELP	"Cliquer ici pour etre deloger"
+#define DEF_FAIL	"Auto-logout a echoue"
+#else
+#ifdef NL
+#define DEF_BTN_LABEL "Loguit"
+#define DEF_BTN_HELP  "klik hier om uit te loggen"
+#define DEF_FAIL  "Auto-loguit mislukt"
+#else
 #define DEF_BTN_LABEL	"Logout"	/* string that appears in logout button */
 
 /* this string appears immediately below logout button */
@@ -257,10 +278,11 @@ static int  descr();
    logged out */
 #define DEF_FAIL	"Auto-logout failed"
 
+#endif
+#endif
 #endif
 
 extern char *ProgramName;
-extern Display *dsp;
 
 /* For modes with text, marquee & nose */
 extern char *program;
@@ -286,9 +308,9 @@ static char *parentname;
 extern Bool parentSet;
 
 #if HAVE_DIRENT_H
-static struct dirent ***images_list;
-int         num_list;
-struct dirent **image_list;
+static struct dirent ***images_list = NULL;
+int         num_list = 0;
+struct dirent **image_list = NULL;
 char        filename_r[MAXNAMLEN];
 char        directory_r[DIRBUF];
 
@@ -297,8 +319,14 @@ char        directory_r[DIRBUF];
 static XrmOptionDescRec genTable[] =
 {
 	{"-mode", ".mode", XrmoptionSepArg, (caddr_t) NULL},
+	{"-erasemode", ".erasemode", XrmoptionSepArg, (caddr_t) NULL},
+	{"-erasedelay", ".erasedelay", XrmoptionSepArg, (caddr_t) NULL},
 	{"-nolock", ".nolock", XrmoptionNoArg, (caddr_t) "on"},
 	{"+nolock", ".nolock", XrmoptionNoArg, (caddr_t) "off"},
+#ifdef USE_VTLOCK
+	{"-vtlock", ".vtlock", XrmoptionNoArg, (caddr_t) "on"},
+	{"+vtlock", ".vtlock", XrmoptionNoArg, (caddr_t) "off"},
+#endif
 	{"-inwindow", ".inwindow", XrmoptionNoArg, (caddr_t) "on"},
 	{"+inwindow", ".inwindow", XrmoptionNoArg, (caddr_t) "off"},
 	{"-inroot", ".inroot", XrmoptionNoArg, (caddr_t) "on"},
@@ -319,8 +347,6 @@ static XrmOptionDescRec genTable[] =
 	{"+enablesaver", ".enablesaver", XrmoptionNoArg, (caddr_t) "off"},
 	{"-resetsaver", ".resetsaver", XrmoptionNoArg, (caddr_t) "on"},
 	{"+resetsaver", ".resetsaver", XrmoptionNoArg, (caddr_t) "off"},
-	{"-fullrandom", ".fullrandom", XrmoptionNoArg, (caddr_t) "on"},
-	{"+fullrandom", ".fullrandom", XrmoptionNoArg, (caddr_t) "off"},
 	{"-grabmouse", ".grabmouse", XrmoptionNoArg, (caddr_t) "on"},
 	{"+grabmouse", ".grabmouse", XrmoptionNoArg, (caddr_t) "off"},
 	{"-grabserver", ".grabserver", XrmoptionNoArg, (caddr_t) "on"},
@@ -413,9 +439,9 @@ static XrmOptionDescRec genTable[] =
 	{"-mailIcon", ".mailIcon", XrmoptionSepArg, (caddr_t) ""},
 	{"-nomailIcon", ".nomailIcon", XrmoptionSepArg, (caddr_t) ""},
 #ifdef USE_DPMS
-        {"-dpmsstandby", ".dpmsstandby", XrmoptionSepArg, (caddr_t) NULL},
-        {"-dpmssuspend", ".dpmssuspend", XrmoptionSepArg, (caddr_t) NULL},
-        {"-dpmsoff", ".dpmsoff", XrmoptionSepArg, (caddr_t) NULL},
+	{"-dpmsstandby", ".dpmsstandby", XrmoptionSepArg, (caddr_t) NULL},
+	{"-dpmssuspend", ".dpmssuspend", XrmoptionSepArg, (caddr_t) NULL},
+	{"-dpmsoff", ".dpmsoff", XrmoptionSepArg, (caddr_t) NULL},
 #endif
 };
 
@@ -436,9 +462,19 @@ static XrmOptionDescRec modeTable[] =
 
 #define modeEntries (sizeof modeTable / sizeof modeTable[0])
 
+/*-
+   Chicken/egg problem here.
+   Customization strings will only work with
+#define CUSTOMIZATION
+   I prefer not to use it because "xlock -display whatever:0" does not work.
+   If I get any complaints about this I will change it the default.
+ */
+
 static XrmOptionDescRec cmdlineTable[] =
 {
+#ifndef CUSTOMIZATION
 	{"-display", ".display", XrmoptionSepArg, (caddr_t) NULL},
+#endif
 	{"-visual", ".visual", XrmoptionSepArg, (caddr_t) NULL},
 	{"-parent", ".parent", XrmoptionSepArg, (caddr_t) NULL},
 	{"-nolock", ".nolock", XrmoptionNoArg, (caddr_t) "on"},
@@ -458,11 +494,16 @@ static XrmOptionDescRec cmdlineTable[] =
 
 #define cmdlineEntries (sizeof cmdlineTable / sizeof cmdlineTable[0])
 
-static XrmOptionDescRec nameTable[] =
+static XrmOptionDescRec earlyCmdlineTable[] =
 {
 	{"-name", ".name", XrmoptionSepArg, (caddr_t) NULL},
+#ifdef CUSTOMIZATION
+	{"-display", ".display", XrmoptionSepArg, (caddr_t) NULL},
+#endif
 };
 
+#define earlyCmdlineEntries (sizeof earlyCmdlineTable / sizeof earlyCmdlineTable[0])
+
 #ifdef USE_MODULES
 static XrmOptionDescRec modulepathTable[] =
 {
@@ -496,12 +537,17 @@ static OptionStruct opDesc[] =
 #else
 	{"-bitmap filename", "bitmap file (sometimes ras too)"},
 #endif
+	{"-erasemode erase-modename", "Erase mode to use"},
+	{"-erasedelay num", "Erase delay for clear screen modes"},
 	{"-/+nolock", "turn on/off no password required"},
 	{"-/+inwindow", "turn on/off making xlock run in a window"},
 	{"-/+inroot", "turn on/off making xlock run in the root window"},
 	{"-/+remote", "turn on/off remote host access"},
 	{"-/+mono", "turn on/off monochrome override"},
 	{"-/+allowaccess", "turn on/off allow new clients to connect"},
+#ifdef USE_VTLOCK
+	{"-/+vtlock", "turn on/off vt switching"},
+#endif
 #ifndef ALWAYS_ALLOW_ROOT
 	{"-/+allowroot", "turn on/off allow root password to unlock"},
 #else
@@ -514,7 +560,6 @@ static OptionStruct opDesc[] =
 	{"-/+grabmouse", "turn on/off grabbing of mouse and keyboard"},
 	{"-/+grabserver", "turn on/off grabbing of server"},
 	{"-/+install", "whether to use private colormap if needed (yes/no)"},
-	{"-/+fullrandom", "turn on/off full random choice of mode-options"},
 	{"-/+mousemotion", "turn on/off sensitivity to mouse"},
 	{"-/+sound", "whether to use sound if configured for it (yes/no)"},
 	{"-/+timeelapsed", "turn on/off clock"},
@@ -590,8 +635,8 @@ static OptionStruct opDesc[] =
 	{"-mailIcon string", "Icon to display when there is mail"},
 	{"-nomailIcon string", "Icon to display when there is no mail"},
 #ifdef USE_DPMS
-	{"-dpmsstandby seconds", "seconds to wait before engaging DPMS standby"},
-	{"-dpmssuspend seconds", "seconds to wait before engaging DPMS suspend"},
+    {"-dpmsstandby seconds", "seconds to wait before engaging DPMS standby"},
+    {"-dpmssuspend seconds", "seconds to wait before engaging DPMS suspend"},
 	{"-dpmsoff seconds", "seconds to wait before engaging DPMS off"},
 #endif
 };
@@ -613,6 +658,9 @@ char       *modulepath;
 
 #endif
 
+static char *erasemodename;
+int         erasemode;
+int         erasedelay;
 Bool        nolock;
 Bool        inwindow;
 Bool        inroot;
@@ -631,7 +679,7 @@ Bool        debug;
 Bool        echokeys;
 Bool        enablesaver;
 Bool        resetsaver;
-Bool        fullrandom;
+Bool        fullrandom = False;
 Bool        grabmouse;
 Bool        grabserver;
 Bool        install;
@@ -656,6 +704,7 @@ char       *planfontname;
 int         dpmsstandby;
 int         dpmssuspend;
 int         dpmsoff;
+
 #endif
 
 #ifdef USE_MB
@@ -730,8 +779,15 @@ char       *mailCmd;
 char       *mailIcon;
 char       *nomailIcon;
 
+#ifdef USE_VTLOCK
+Bool        vtlock;
+
+#endif
+
 static argtype genvars[] =
 {
+	{(caddr_t *) & erasemodename, "erasemode", "EraseMode", "", t_String},
+	{(caddr_t *) & erasedelay, "erasedelay", "EraseDelay", DEF_ERASEDELAY, t_Int},
     {(caddr_t *) & allowaccess, "allowaccess", "AllowAccess", "off", t_Bool},
 #ifndef ALWAYS_ALLOW_ROOT
 	{(caddr_t *) & allowroot, "allowroot", "AllowRoot", "off", t_Bool},
@@ -740,7 +796,6 @@ static argtype genvars[] =
 	{(caddr_t *) & echokeys, "echokeys", "EchoKeys", "off", t_Bool},
     {(caddr_t *) & enablesaver, "enablesaver", "EnableSaver", "off", t_Bool},
 	{(caddr_t *) & resetsaver, "resetsaver", "ResetSaver", "on", t_Bool},
-	{(caddr_t *) & fullrandom, "fullrandom", "FullRandom", "on", t_Bool},
 	{(caddr_t *) & grabmouse, "grabmouse", "GrabMouse", "on", t_Bool},
 	{(caddr_t *) & grabserver, "grabserver", "GrabServer", "off", t_Bool},
 	{(caddr_t *) & install, "install", "Install", "on", t_Bool},
@@ -751,7 +806,6 @@ static argtype genvars[] =
 	{(caddr_t *) & usefirst, "usefirst", "UseFirst", "on", t_Bool},
 	{(caddr_t *) & verbose, "verbose", "Verbose", "off", t_Bool},
 	{(caddr_t *) & visualname, "visual", "Visual", "", t_String},
-
 	{(caddr_t *) & nicelevel, "nice", "Nice", DEF_NICE, t_Int},
    {(caddr_t *) & lockdelay, "lockdelay", "LockDelay", DEF_LOCKDELAY, t_Int},
 	{(caddr_t *) & timeout, "timeout", "Timeout", DEF_TIMEOUT, t_Int},
@@ -827,6 +881,9 @@ static argtype genvars[] =
 	{(caddr_t *) & mailCmd, "mailCmd", "MailCmd", DEF_MAILAPP, t_String},
      {(caddr_t *) & mailIcon, "mailIcon", "MailIcon", DEF_MAILAPP, t_String},
 {(caddr_t *) & nomailIcon, "nomailIcon", "NomailIcon", DEF_MAILAPP, t_String},
+#ifdef USE_VTLOCK
+	{(caddr_t *) & vtlock, "vtlock", "VTLock", "on", t_Bool},
+#endif
 #if 0
     /* These resources require special handling.  They must be examined
      * before the display is opened.  They are evaluated by individual
@@ -973,13 +1030,13 @@ checkSpecialArgs(int argc, char **argv)
 			Version();
 #ifdef CHECK_OLD_ARGS
 		{
-			char       *depreciated_args[] =
+			static char *depreciated_args[] =
 			{"-v", "-imagefile", "-mfont"};
-			char       *current_args[] =
+			static char *current_args[] =
 			{"-verbose", "-bitmap", "-messagefont"};
 			int         j;
 
-			for (j = 0; j < (sizeof (current_args)) / sizeof (*(current_args)); j++)
+			for (j = 0; j < (int) ((sizeof current_args) / sizeof (*current_args)); j++)
 				if (!strncmp(argv[i], depreciated_args[j], strlen(argv[i]))) {
 					(void) printf("%s depreciated, use %s\n",
 					depreciated_args[j], current_args[j]);
@@ -1077,8 +1134,8 @@ GetResource(XrmDatabase database, char *parentname, char *parentclassname,
 		case t_String:
 			{
 /*-
- * PURIFY 4.0.1 on Solaris 2 and on SunOS4 reports a 1 byte memory leak on
- * the following line. */
+ * PURIFY 4.2 on Solaris 2 and on SunOS4 reports a memory leak on the following
+ * line. It leaks as many bytes as there are characters in the string + 1. */
 				char       *s = (char *) malloc(len + 1);
 
 				if (s == (char *) NULL) {
@@ -1110,9 +1167,9 @@ GetResource(XrmDatabase database, char *parentname, char *parentclassname,
 	}
 }
 
-
 static      XrmDatabase
-parsefilepath(char *xfilesearchpath, char *TypeName, char *ClassName)
+parsefilepath(char *xfilesearchpath, char *TypeName, char *ClassName,
+	      char *CustomName)
 {
 	XrmDatabase database = NULL;
 	char       *appdefaults;
@@ -1135,6 +1192,9 @@ parsefilepath(char *xfilesearchpath, char *TypeName, char *ClassName)
 				case 'N':
 					i += strlen(ClassName);
 					break;
+				case 'C':
+					i += strlen(CustomName);
+					break;
 				default:
 					break;
 			}
@@ -1177,6 +1237,11 @@ parsefilepath(char *xfilesearchpath, char *TypeName, char *ClassName)
 					src++;
 					dst += strlen(ClassName);
 					break;
+				case 'C':
+					(void) strcat(dst, CustomName);
+					src++;
+					dst += strlen(CustomName);
+					break;
 				case 'S':
 					src++;
 					break;
@@ -1292,23 +1357,13 @@ descr(char *name)
 #endif
 
 static void
-open_display(void)
+openDisplay(Display ** displayp)
 {
 	char       *buf;
-	struct hostent *host;
 
-#if defined(__cplusplus) || defined(c_plusplus)		/* !__bsdi__ */
-#if HAVE_GETHOSTNAME
-	extern int  gethostname(char *, size_t);
-	extern struct hostent *gethostbyname(const char *);
-
-#else
-#define gethostname(name,namelen) sysinfo(SI_HOSTNAME,name,namelen)
-#endif
-#endif
-
-
-	if (!(dsp = XOpenDisplay((displayname) ? displayname : ""))) {
+/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
+ * the following line. */
+	if (!(*displayp = XOpenDisplay((displayname) ? displayname : ""))) {
 		buf = (char *) malloc(strlen(ProgramName) +
 			     ((displayname) ? strlen(displayname) : 0) + 80);
 		(void) sprintf(buf,
@@ -1317,7 +1372,32 @@ open_display(void)
 		error(buf);
 		(void) free((void *) buf);	/* Should never get here */
 	}
-	displayname = DisplayString(dsp);
+	displayname = DisplayString(*displayp);
+}
+
+static void
+checkDisplay(void)
+{
+	char       *buf;
+	struct hostent *host;
+
+#if defined(__cplusplus) || defined(c_plusplus)		/* !__bsdi__ */
+/* #include <netdb.h> */
+#if HAVE_GETHOSTNAME
+#ifdef SunCplusplus
+	extern struct hostent *gethostbyname(const char *);
+
+#else
+#if 0
+	extern int  gethostname(char *, size_t);
+	extern struct hostent *gethostbyname(const char *);
+
+#endif
+#endif
+#else
+#define gethostname(name,namelen) sysinfo(SI_HOSTNAME,name,namelen)
+#endif
+#endif
 
 	/*
 	 * only restrict access to other displays if we are locking and if the
@@ -1443,68 +1523,60 @@ printvar(char *classname, argtype var)
 }
 
 void
-getResources(int argc, char **argv)
+getServerResources(Display * display, char *homeenv, char **custom,
+		   XrmDatabase * RDB, XrmDatabase * serverDB)
 {
-	XrmDatabase RDB = NULL;
-
-#ifdef USE_MODULES
-	XrmDatabase modulepathDB = NULL;
-
-#endif
-	XrmDatabase nameDB = NULL;
-	XrmDatabase modeDB = NULL;
-	XrmDatabase cmdlineDB = NULL;
-	XrmDatabase generalDB = NULL;
-	XrmDatabase homeDB = NULL;
-	XrmDatabase applicationDB = NULL;
-	XrmDatabase serverDB = NULL;
-	XrmDatabase userDB = NULL;
-	char       *userfile = NULL;
-	char       *homeenv;
-	char       *userpath;
-	char       *env;
 	char       *serverString;
-	int         i, j;
-	int         max_length;
-	extern Display *dsp;
 
-	XrmInitialize();
-
-#ifndef USE_MODULES
-	/*
-	 * Moved back because its annoying if you need -remote and
-	 * you do not know it.
-	 */
-	checkSpecialArgs(argc, argv);
+	serverString = XResourceManagerString(display);
+	if (serverString) {
+/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
+   * line.  PURIFY 4.0.1 on SunOS4 reports this also when using X11R5, but not
+   * with OpenWindow 3.0 (X11R4 based). */
+		*serverDB = XrmGetStringDatabase(serverString);
+#ifndef CUSTOMIZATION
+/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
+   * line.  PURIFY 4.0.1 on SunOS4 does not report this error. */
+		(void) XrmMergeDatabases(*serverDB, RDB);
 #endif
+	} else {
+		char       *buf = (char *) malloc(strlen(homeenv) + 12);
 
-	/* Application Class is fixed */
-	classname = DEF_CLASSNAME;
-	/*
-	 * Application Name may be modified by -name arg from command
-	 * line so you can have different resource files for different
-	 * configurations/machines etc...
-	 */
-#ifdef VMS
-	/*Strip off directory and .exe; parts */
-	ProgramName = stripname(ProgramName);
+		(void) sprintf(buf, "%s/.Xdefaults", homeenv);
+#ifdef CUSTOMIZATION
+		*serverDB = XrmGetFileDatabase(buf);
+#else
+		(void) XrmMergeDatabases(XrmGetFileDatabase(buf), RDB);
 #endif
-	XrmParseCommand(&nameDB, nameTable, 1, "xlock",
-			&argc, argv);
-	GetResource(nameDB, "xlock", classname, "name", "Name", t_String,
-		    ProgramName, &ProgramName);
+		(void) free((void *) buf);
+	}
+#ifdef CUSTOMIZATION
+	if (*serverDB)
+		GetResource(*serverDB, ProgramName, classname, "customization",
+			    "Customization", t_String, "", custom);
+	else
+		*custom = "";
+#endif
+}
 
-
-	homeenv = getenv("HOME");
-	if (!homeenv)
-		homeenv = "";
+void
+getAppResources(char *homeenv, char **custom,
+	   XrmDatabase * RDB, XrmDatabase * serverDB, int *argc, char **argv)
+{
+	char       *env;
+	char       *userpath;
+	char       *userfile = NULL;
+	XrmDatabase cmdlineDB = NULL;
+	XrmDatabase userDB = NULL;
+	XrmDatabase applicationDB = NULL;
+	extern char *getenv(const char *);
 
 	env = getenv("XFILESEARCHPATH");
 	applicationDB = parsefilepath(env ? env : DEF_FILESEARCHPATH,
-				      "app-defaults", classname);
+				      "app-defaults", classname, *custom);
 
 	XrmParseCommand(&cmdlineDB, cmdlineTable, cmdlineEntries, ProgramName,
-			&argc, argv);
+			argc, argv);
 
 	userpath = getenv("XUSERFILESEARCHPATH");
 	if (!userpath) {
@@ -1530,35 +1602,41 @@ getResources(int argc, char **argv)
 		}
 		userpath = userfile;
 	}
-	userDB = parsefilepath(userpath, "app-defaults", classname);
+	userDB = parsefilepath(userpath, "app-defaults", classname, *custom);
 
 	if (userfile)
 		(void) free((void *) userfile);
 
-	(void) XrmMergeDatabases(applicationDB, &RDB);
-	(void) XrmMergeDatabases(userDB, &RDB);
+	(void) XrmMergeDatabases(applicationDB, RDB);
+	(void) XrmMergeDatabases(userDB, RDB);
 /* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
    * line.  PURIFY 4.0.1 on SunOS4 does not report this error. */
-	(void) XrmMergeDatabases(cmdlineDB, &RDB);
-
-	GetResource(RDB, ProgramName, classname, "display", "Display", t_String,
+	(void) XrmMergeDatabases(cmdlineDB, RDB);
+#ifdef CUSTOMIZATION
+	if (*serverDB)
+/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
+   * line.  PURIFY 4.0.1 on SunOS4 does not report this error. */
+		(void) XrmMergeDatabases(*serverDB, RDB);
+#else
+	GetResource(*RDB, ProgramName, classname, "display", "Display", t_String,
 		    "", &displayname);
-	GetResource(RDB, ProgramName, classname, "parent", "Parent", t_String,
+#endif
+	GetResource(*RDB, ProgramName, classname, "parent", "Parent", t_String,
 		    "", &parentname);
 	if (parentname && *parentname) {
 		if (sscanf(parentname, "%ld", &parent))
 			parentSet = True;
 	}
-	GetResource(RDB, ProgramName, classname, "nolock", "NoLock", t_Bool,
+	GetResource(*RDB, ProgramName, classname, "nolock", "NoLock", t_Bool,
 		    "off", (caddr_t *) & nolock);
-	GetResource(RDB, ProgramName, classname, "inwindow", "InWindow", t_Bool,
+	GetResource(*RDB, ProgramName, classname, "inwindow", "InWindow", t_Bool,
 		    "off", (caddr_t *) & inwindow);
-	GetResource(RDB, ProgramName, classname, "inroot", "InRoot", t_Bool,
+	GetResource(*RDB, ProgramName, classname, "inroot", "InRoot", t_Bool,
 		    "off", (caddr_t *) & inroot);
-	GetResource(RDB, ProgramName, classname, "remote", "Remote", t_Bool,
+	GetResource(*RDB, ProgramName, classname, "remote", "Remote", t_Bool,
 		    "off", (caddr_t *) & remote);
 #ifdef USE_DTSAVER
-	GetResource(RDB, ProgramName, classname, "dtsaver", "DtSaver", t_Bool,
+	GetResource(*RDB, ProgramName, classname, "dtsaver", "DtSaver", t_Bool,
 		    "off", (caddr_t *) & dtsaver);
 	if (dtsaver) {
 		inroot = False;
@@ -1566,25 +1644,77 @@ getResources(int argc, char **argv)
 		nolock = True;
 	}
 #endif
+}
 
-	open_display();
-	serverString = XResourceManagerString(dsp);
-	if (serverString) {
-/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
-   * line.  PURIFY 4.0.1 on SunOS4 reports this also when using X11R5, but not
-   * with OpenWindow 3.0 (X11R4 based). */
-		serverDB = XrmGetStringDatabase(serverString);
-/* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
-   * line.  PURIFY 4.0.1 on SunOS4 does not report this error. */
-		(void) XrmMergeDatabases(serverDB, &RDB);
-	} else {
-		char       *buf = (char *) malloc(strlen(homeenv) + 12);
+void
+getResources(Display ** displayp, int argc, char **argv)
+{
+	XrmDatabase RDB = NULL;
 
-		(void) sprintf(buf, "%s/.Xdefaults", homeenv);
-		homeDB = XrmGetFileDatabase(buf);
-		(void) XrmMergeDatabases(homeDB, &RDB);
-		(void) free((void *) buf);
-	}
+#ifdef USE_MODULES
+	XrmDatabase modulepathDB = NULL;
+
+#endif
+	XrmDatabase serverDB = NULL;
+	XrmDatabase earlyCmdlineDB = NULL;
+	XrmDatabase modeDB = NULL;
+	XrmDatabase generalDB = NULL;
+	char       *custom = NULL;
+	char       *homeenv = NULL;
+	int         i, j;
+	int         max_length;
+	extern char *getenv(const char *);
+
+#if defined( USE_AUTO_LOGOUT ) || defined( USE_BUTTON_LOGOUT )
+	extern int  fullLock();
+
+#endif
+
+	XrmInitialize();
+
+#ifndef USE_MODULES
+	/*
+	 * Moved back because its annoying if you need -remote and
+	 * you do not know it.
+	 */
+	checkSpecialArgs(argc, argv);
+#endif
+
+	/* Application Class is fixed */
+	classname = DEF_CLASSNAME;
+	/*
+	 * Application Name may be modified by -name arg from command
+	 * line so you can have different resource files for different
+	 * configurations/machines etc...
+	 */
+#ifdef VMS
+	/*Strip off directory and .exe; parts */
+	ProgramName = stripname(ProgramName);
+#endif
+	XrmParseCommand(&earlyCmdlineDB, earlyCmdlineTable,
+			earlyCmdlineEntries, "xlock", &argc, argv);
+	GetResource(earlyCmdlineDB, "xlock", classname, "name", "Name",
+		    t_String, ProgramName, &ProgramName);
+#ifdef CUSTOMIZATION
+	GetResource(earlyCmdlineDB, ProgramName, classname, "display",
+		    "Display", t_String, "", &displayname);
+#endif
+	homeenv = getenv("HOME");
+	if (!homeenv)
+		homeenv = "";
+
+#ifdef CUSTOMIZATION
+	openDisplay(displayp);
+	getServerResources(*displayp, homeenv, &custom, &RDB, &serverDB);
+	getAppResources(homeenv, &custom, &RDB, &serverDB, &argc, argv);
+	checkDisplay();
+#else
+	custom = "";
+	getAppResources(homeenv, &custom, &RDB, &serverDB, &argc, argv);
+	openDisplay(displayp);
+	checkDisplay();
+	getServerResources(*displayp, homeenv, &custom, &RDB, &serverDB);
+#endif
 
 #ifdef USE_MODULES
 	/*
@@ -1607,7 +1737,6 @@ getResources(int argc, char **argv)
 	 */
 	checkSpecialArgs(argc, argv);
 #endif
-
 	XrmParseCommand(&generalDB, genTable, genEntries, ProgramName, &argc, argv);
 /* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
    * line.  PURIFY 4.0.1 on SunOS4 does not report this error. */
@@ -1781,6 +1910,19 @@ getResources(int argc, char **argv)
 			(void) fprintf(stderr, "Using visual class %s\n",
 				       nameOfVisualClass(VisualClassWanted));
 	}
+	if (!erasemodename || !*erasemodename || !strcmp(erasemodename,
+							 "default")) {
+		erasemode = -1;
+		if (verbose)
+			(void) fprintf(stderr, "Using random erase mode\n");
+	} else {
+		extern int  erasemodefromname(char *name);
+
+		erasemode = erasemodefromname(erasemodename);
+		if (verbose)
+			(void) fprintf(stderr, "Using erase mode %s\n",
+				       erasemodename);
+	}
 #if HAVE_DIRENT_H
 	/* Evaluate bitmap */
 	if (bitmap && strcmp(bitmap, DEF_BITMAP)) {
@@ -1791,14 +1933,31 @@ getResources(int argc, char **argv)
 			int         (*compare) (const void *, const void *));
 
 		get_dir(bitmap, directory_r, filename_r);
+		if (image_list != NULL) {
+			int         i;
+
+			for (i = 0; i < num_list; i++) {
+				if  (image_list[i])
+					(void) free((void *) image_list[i]);
+			}
+			(void) free((void *) image_list);
+			image_list = NULL;
+		}
 		images_list = (struct dirent ***) malloc(sizeof (struct dirent **));
 
 		num_list = scan_dir(directory_r, images_list, sel_image, NULL);
 		image_list = *images_list;
+		if (images_list) {
+			(void) free((void *) images_list);
+			images_list = NULL;
+		}
 		if (debug)
 			for (i = 0; i < num_list; i++)
 				(void) printf("File number %d: %s\n", i, image_list[i]->d_name);
-
+		if (num_list < 0) {
+			image_list = NULL;
+			num_list = 0;
+		}
 	} else {
 		num_list = 0;
 	}
