@@ -27,7 +27,7 @@
 #ifndef _SPLINE_H_
 #define _SPLINE_H_
 
-typedef struct _spline {
+typedef struct {
 	/* input */
 	unsigned int n_controls;
 	double     *control_x;
@@ -39,7 +39,7 @@ typedef struct _spline {
 	unsigned int allocated_points;
 } spline;
 
-spline *    make_spline(unsigned int size);
+spline     *make_spline(unsigned int size);
 void        compute_spline(spline * s);
 void        compute_closed_spline(spline * s);
 void        just_fill_spline(spline * s);
