@@ -77,9 +77,9 @@ VirtualRootWindowOfScreen(Screen * screen)
 		root = RootWindowOfScreen(screen);
 
 		/* go look for a virtual root */
-#ifndef XSCREENSAVER 
+#if 0
 /*-
- * Without this it makes the screen all white when xautolock kicks in.
+ * I forget why I put this here....
  * With this it screws up the mouse focus with xscreensaver.
  */
 		if (inroot)
