@@ -7,7 +7,7 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
  * xlock.c - X11 client to lock a display and show a screen saver.
  *
  * Copyright (c) 1988-91 by Patrick J. Naughton.
- * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -24,6 +24,10 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
  * Revision History:
  *
  * Changes maintained by David Bagley <bagleyd@bigfoot.com>
+ * 01-Jul-98: Eric Lassauge <lassauge@sagem.fr> &
+ *              Remi Cohen-Scali <remi.cohenscali@pobox.com>
+ *            Added support for locking VT switching (-/+vtlock)
+ *            Added code is enclosed in USE_VTLOCK
  * 01-May-97: Matthew Rench <mdrench@mtu.edu>
  *            Added DPMS options.
  * 02-Dec-97: Strong user authentication, utilizing the SafeWord API.
@@ -65,12 +69,12 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
  *            Took out "bounce" since it was too buggy (maybe I will put
  *            it back later).
  * 21-Mar-94: patch to to trap Shift-Ctrl-Reset courtesy of Jamie Zawinski
- *            <jwz@netscape.com>, patched the patch (my mistake) for AIXV3
+ *            <jwz@jwz.org>, patched the patch (my mistake) for AIXV3
  *            and HP from <R.K.Lloyd@csc.liv.ac.uk>.
  * 01-Dec-93: added patch for AIXV3 from Tom McConnell
  *            <tmcconne@sedona.intel.com> also added a patch for HP-UX 8.0.
  * 29-Jul-93: "hyper", "helix", "rock", and "blot" (also tips on "maze") I
- *            got courtesy of Jamie Zawinski <jwz@netscape.com>;
+ *            got courtesy of Jamie Zawinski <jwz@jwz.org>;
  *            at the time I could not get his stuff to work for the hpux 8.0,
  *            so I scrapped it but threw his stuff in xlock.
  *            "maze" and "sphere" I got courtesy of Sun Microsystems.
@@ -168,10 +172,9 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
 
 #ifdef STANDALONE
 
-
 /*-
  * xscreensaver compatibility layer for xlockmore modules.
- * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -183,7 +186,7 @@ static const char sccsid[] = "@(#)xlock.c	4.11 98/05/24 xlockmore";
  *
  * This file, along with xlockmore.h, make it possible to compile an xlockmore
  * module into a standalone program, and thus use it with xscreensaver.
- * By Jamie Zawinski <jwz@netscape.com> on 10-May-97; based on the ideas
+ * By Jamie Zawinski <jwz@jwz.org> on 10-May-97; based on the ideas
  * in the older xlock.h by Charles Hannum <mycroft@ai.mit.edu>.  (I had
  * to redo it, since xlockmore has diverged so far from xlock...)
  */
@@ -530,6 +533,7 @@ xlockmore_screenhack(Display * dpy, Window window,
 	mi.verbose = get_boolean_resource("verbose", "Boolean");
 
 	mi.root_p = (window == RootWindowOfScreen(mi.xgwa.screen));
+	mi.is_drawn = False;
 
 
 	if (mi.pause < 0)
@@ -568,6 +572,9 @@ xlockmore_screenhack(Display * dpy, Window window,
 
 #else /* STANDALONE */
 #include "xlock.h"
+#include "color.h"
+#include "util.h"
+#include "iostuff.h"
 #include <sys/stat.h>
 #include <signal.h>
 #include <errno.h>
@@ -852,11 +859,19 @@ static XpmImage *nomail_xpmimg = NULL;
 #define MAIL_BITS    mailfull_bits
 #endif
 
-int         signalUSR1 = 0;
-int         signalUSR2 = 0;
+#ifdef USE_VTLOCK
+	/* EL - RCS : for VT switching locking */
+extern int  vtlock;		/* Have to VT lock switching */
+extern int  vtlocked;		/* VT switching is locked */
+
+extern void dovtlock(void);	/* Actual do it */
+extern void dounvtlock(void);	/* & undo it functions */
+
+#endif
+
+static int  signalUSR1 = 0;
+static int  signalUSR2 = 0;
 char        old_default_mode[20] = "";
-void        SigUsr1(int sig);
-void        SigUsr2(int sig);
 
 #define AllPointerEventMask \
 	(ButtonPressMask | ButtonReleaseMask | \
@@ -1025,12 +1040,12 @@ GrabKeyboardAndMouse(Display * display, Window window)
 			(void) free((void *) buf);	/* Should never get here */
 		}
 	}
-	status = XGrabPointer(display, window, True, AllPointerEventMask,
+	status = XGrabPointer(display, window, True, (unsigned int) AllPointerEventMask,
 			      GrabModeAsync, GrabModeAsync, None, mycursor,
 			      CurrentTime);
 	if (status != GrabSuccess) {
 		(void) sleep(1);
-		status = XGrabPointer(display, window, True, AllPointerEventMask,
+		status = XGrabPointer(display, window, True, (unsigned int) AllPointerEventMask,
 				GrabModeAsync, GrabModeAsync, None, mycursor,
 				      CurrentTime);
 
@@ -1050,7 +1065,7 @@ static void
 ChangeGrabbedCursor(Display * display, Window window, Cursor cursor)
 {
 	if (!debug && grabmouse && !inwindow && !inroot)
-		(void) XGrabPointer(display, window, True, AllPointerEventMask,
+		(void) XGrabPointer(display, window, True, (unsigned int) AllPointerEventMask,
 		    GrabModeAsync, GrabModeAsync, None, cursor, CurrentTime);
 }
 
@@ -1166,10 +1181,11 @@ mode_info(Display * display, int scrn, Window window, int iconic)
 		MI_SET_FLAG_STATE(mi, WI_FLAG_USE3D, use3d &&
 			    !(mono || CellsOfScreen(MI_SCREENPTR(mi)) <= 2));
 		MI_SET_FLAG_STATE(mi, WI_FLAG_VERBOSE, verbose);
-		MI_SET_FLAG_STATE(mi, WI_FLAG_FULLRANDOM, fullrandom);
+		MI_SET_FLAG_STATE(mi, WI_FLAG_FULLRANDOM, False);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_WIREFRAME, wireframe);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_MOUSE, mouse);
 		MI_SET_FLAG_STATE(mi, WI_FLAG_INFO_INITTED, True);
+		MI_IS_DRAWN(mi) = False;
 	}
 	if (MI_WINDOW(mi) != window) {
 		MI_WINDOW(mi) = window;
@@ -1240,6 +1256,11 @@ finish(Display * display, Bool closeDisplay)
 		(void) XCloseDisplay(display);
 #endif
 	(void) nice(0);
+#ifdef USE_VTLOCK
+	/* EL - RCS : Unlock VT switching */
+	if (vtlock && vtlocked)
+		dounvtlock();
+#endif
 }
 
 static int
@@ -1343,30 +1364,44 @@ statusUpdate(int isnew, int scr)
 	if (timeelapsed) {
 		if (len < 60)
 			(void) sprintf(buf,
-#ifdef NL
-				       "%d minute%s op slot.                                        \n",
-				       len, len == 1 ? "" : "n");
-#else
 #ifdef DE
 				       "Seit %d Minute%s gesperrt.                                  \n",
-				       len, len == 1 ? "" : "n");
+				       len, len <= 1 ? "" : "n"
+#else
+#ifdef FR
+				       "%d minute%s coule%s depuis verrouillage.                      \n",
+				len, len <= 1 ? "" : "s", len <= 1 ? "" : "s"
+#else
+#ifdef NL
+				       "%d minute%s op slot.                                        \n",
+				       len, len <= 1 ? "" : "n"
 #else
 				       "%d minute%s elapsed since locked.                           \n",
-				       len, len == 1 ? "" : "s");
+				       len, len <= 1 ? "" : "s"
 #endif
 #endif
+#endif
+				);
 		else
 			(void) sprintf(buf,
-#ifdef NL
-				       "%d:%02d uur op slot.                                           \n",
-#else
 #ifdef DE
 				       "Seit %d:%02d Stunden gesperrt.                                 \n",
+				       len / 60, len % 60
+#else
+#ifdef FR
+				       "%d:%02d heures coule%s depuis verouillage.                        \n",
+			       len / 60, len % 60, (len / 60) <= 1 ? "" : "s"
+#else
+#ifdef NL
+				       "%d:%02d uur op slot.                                           \n",
+				       len / 60, len % 60
 #else
 				       "%d:%02d hours elapsed since locked.                            \n",
+				       len / 60, len % 60
 #endif
 #endif
-				       len / 60, len % 60);
+#endif
+				);
 		putText(dsp, Scr[scr].window, Scr[scr].textgc, buf, False, left, &x, &y);
 	}
 #ifdef USE_BUTTON_LOGOUT
@@ -1376,41 +1411,55 @@ statusUpdate(int isnew, int scr)
 
 			if (tmp < 60)
 				(void) sprintf(buf,
-#ifdef NL
-					       "Over %d minute%s verschijnt de " logout " knop.                 \n",
-					       tmp, (tmp == 1) ? "" : "n");
-#else
 #ifdef DE
 					       "In %d Minute%s erscheint der Auslogger.                       \n",
-					       tmp, (tmp == 1) ? "" : "n");
+					       tmp, (tmp <= 1) ? "" : "n"
+#else
+#ifdef FR
+					       "%d minute%s jusqu' apparition du bouton lougout.             \n",
+					       tmp, (tmp <= 1) ? "" : "s"
+#else
+#ifdef NL
+					       "Over %d minute%s verschijnt de logout knop.                   \n",
+					       tmp, (tmp <= 1) ? "" : "n"
 #else
 					       "%d minute%s until the public logout button appears.           \n",
-					       tmp, (tmp == 1) ? "" : "s");
+					       tmp, (tmp <= 1) ? "" : "s"
 #endif
 #endif
+#endif
+					);
 			else
 				(void) sprintf(buf,
-#ifdef NL
-					       "Over %d:%02d uur verschijnt de " logout " knop.               \n",
-#else
 #ifdef DE
 					       "In %d:%02d Stunden erscheint der Auslogger.                 \n",
+#else
+#ifdef FR
+					       "%d:%02d heures jusqu' apparition du bouton lougout         \n",
+#else
+#ifdef NL
+					       "Over %d:%02d uur verschijnt de logout knop.                 \n",
 #else
 					       "%d:%02d hours until the public logout button appears.       \n",
 #endif
+#endif
 #endif
 					       tmp / 60, tmp % 60);
 			putText(dsp, Scr[scr].window, Scr[scr].textgc, buf, False, left, &x, &y);
 		} else {
 			putText(dsp, Scr[scr].window, Scr[scr].textgc,
-#ifdef NL
-				"Schop me eruit                                               \n",
-#else
 #ifdef DE
 				"Werft mich raus                                              \n",
+#else
+#ifdef FR
+				"Jettes moi                                                   \n",
+#else
+#ifdef NL
+				"Schop me eruit                                               \n",
 #else
 				"Kick me out                                                  \n",
 #endif
+#endif
 #endif
 				False, left, &x, &y);
 			if (!made_button || (isnew && tried_logout)) {
@@ -1452,11 +1501,23 @@ statusUpdate(int isnew, int scr)
 		int         tmp = logoutAuto - len;
 
 		if (tmp < 60)
-			(void) sprintf(buf, "%d minute%s until auto-logout.    \n",
-				       tmp, (tmp == 1) ? "" : "s");
+			(void) sprintf(buf,
+#ifdef FR
+				  "%d minute%s jusqu' l'auto-logout.    \n",
+#else
+				       "%d minute%s until auto-logout.    \n",
+#endif
+				       tmp, (tmp <= 1) ? "" : "s");
 		else
-			(void) sprintf(buf, "%d:%02d hours until auto-logout.  \n",
-				       tmp / 60, tmp % 60);
+			(void) sprintf(buf,
+#ifdef FR
+				  "%d:%02d heure%s jusqu' auto-logout.  \n",
+			       tmp / 60, tmp % 60, (tmp / 60) <= 1 ? "" : "s"
+#else
+				       "%d:%02d hours until auto-logout.  \n",
+				       tmp / 60, tmp % 60
+#endif
+				);
 		putText(dsp, Scr[scr].window, Scr[scr].textgc, buf, False, left, &x, &y);
 	}
 #endif /* USE_AUTO_LOGOUT */
@@ -1515,8 +1576,7 @@ runMainLoop(int maxtime, int iconscreen)
 {
 	static int  lastdelay = -1, lastmaxtime = -1;
 	int         fd = ConnectionNumber(dsp), r;
-	struct timeval sleep_time, first, repeat;
-	struct timeval elapsed, tmp;
+	struct timeval sleep_time, first, repeat, elapsed, tmp;
 	fd_set      reads;
 	unsigned long started;
 
@@ -1527,8 +1587,10 @@ runMainLoop(int maxtime, int iconscreen)
 	GETTIMEOFDAY(&loopStart);
 #endif
 
-	first.tv_sec = first.tv_usec = 0;
-	elapsed.tv_sec = elapsed.tv_usec = 0;
+	first.tv_sec = 0;
+	first.tv_usec = 0;
+	elapsed.tv_sec = 0;
+	elapsed.tv_usec = 0;
 	repeat.tv_sec = delay / 1000000;
 	repeat.tv_usec = delay % 1000000;
 
@@ -1868,7 +1930,7 @@ modeDescription(ModeInfo * mi)
 	x = left = Scr[screen].iconpos.x;
 	y = Scr[screen].iconpos.y - font->ascent + font->descent + 2;
 
-	/*XSetForeground(dsp, Scr[screen].gc, Scr[screen].bg_pixel); */
+	XSetForeground(dsp, Scr[screen].gc, Scr[screen].bg_pixel);
 	XFillRectangle(dsp, Scr[screen].window, Scr[screen].gc,
 		       x, y - font->ascent,
 		       xgwa.width - x, font->ascent + font->descent + 2);
@@ -1919,9 +1981,7 @@ getPassword(void)
 	ChangeGrabbedCursor(dsp, Scr[screen].window,
 			    XCreateFontCursor(dsp, XC_left_ptr));
 
-	XSetForeground(dsp, Scr[screen].gc, Scr[screen].bg_pixel);
-	XFillRectangle(dsp, Scr[screen].window, Scr[screen].gc,
-		       0, 0, xgwa.width, xgwa.height);
+	MI_CLEARWINDOWCOLOR(mi, Scr[screen].bg_pixel);
 	XMapWindow(dsp, Scr[screen].icon);
 	XRaiseWindow(dsp, Scr[screen].icon);
 
@@ -2083,7 +2143,6 @@ getPassword(void)
 			       x, y, mbi->width, mbi->height);
 #endif
 	}
-
 	done = False;
 	while (!done) {
 #ifdef USE_SOUND
@@ -2379,6 +2438,11 @@ sigcatch(int signum)
 static void
 lockDisplay(Display * display, Bool do_display)
 {
+#ifdef USE_VTLOCK
+	/* EL - RCS : lock VT switching */
+	if (vtlock && !vtlocked)
+		dovtlock();
+#endif
 #if defined( HAVE_SYSLOG_H ) && defined( USE_SYSLOG )
 	syslogStart();
 #endif
@@ -2403,9 +2467,11 @@ lockDisplay(Display * display, Bool do_display)
 		int         oldsigmask;
 
 #ifndef VMS
+#if !defined(__cplusplus) && !defined(c_plusplus)
 		extern int  sigblock(int);
 		extern int  sigsetmask(int);
 
+#endif
 		oldsigmask = sigblock(
 #ifndef DEBUG
 					     sigmask(SIGHUP) |
@@ -2576,6 +2642,34 @@ createFontSet(Display * display, char *name)
 }
 #endif
 
+static void SigUsr2(int sig);
+
+static void
+SigUsr1(int sig)
+{
+#ifdef DEBUG
+	(void) printf("Signal %d received\n", sig);
+#endif
+	signalUSR1 = 1;
+	signalUSR2 = 0;
+
+	(void) signal(SIGUSR1, SigUsr1);
+	(void) signal(SIGUSR2, SigUsr2);
+}
+
+static void
+SigUsr2(int sig)
+{
+#ifdef DEBUG
+	(void) printf("Signal %d received\n", sig);
+#endif
+	signalUSR1 = 0;
+	signalUSR2 = 1;
+
+	(void) signal(SIGUSR1, SigUsr1);
+	(void) signal(SIGUSR2, SigUsr2);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -2665,7 +2759,7 @@ main(int argc, char **argv)
 	SRAND((long) ProgramPID);
 #endif
 
-	getResources(argc, argv);
+	getResources(&dsp, argc, argv);
 
 #ifdef HAVE_SETEUID
 	/* become root to get the password */
@@ -2709,9 +2803,20 @@ main(int argc, char **argv)
 #endif
 #endif
 #else
-	(void) setgid(rgid);
+	/* In order to lock VT switch we must issue an ioctl on console */
+	/* (VT_LOCKSWITCH). This ioctl MUST be issued by root. */
+	/* We need later to be able to do another seteuid(0), so let's */
+	/* disable the overwrite of saved uid/gid */
+
+#ifdef USE_VTLOCK
+	if (!vtlock)
 #endif
-	(void) setuid(ruid);
+		(void) setgid(rgid);
+#endif
+#ifdef USE_VTLOCK
+	if (!vtlock)
+#endif
+		(void) setuid(ruid);
 
 #if 0
 	/* synchronize -- so I'm aware of errors immediately */
@@ -2845,7 +2950,7 @@ main(int argc, char **argv)
 			Scr[this_screen].window = saver_wins[this_win];
 		}
 		/* Reduce to the screens that have windows.  Avoid problems and */
-    /* assume that if one fails there is only one good window. */
+		/* assume that if one fails there is only one good window. */
 		for (this_screen = startscreen; this_screen < screens; this_screen++) {
 			if (Scr[this_screen].window == None) {
 				startscreen = DefaultScreen(dsp);
@@ -2898,11 +3003,11 @@ main(int argc, char **argv)
  * As far as I can tell, this problem exists only if your using MesaGL.
  */
 #if (defined( USE_GL ) && (!defined( MESA ) || defined( REALGLX ))) || !defined( COMPLIANT_COLORMAP )
-    Scr[screen].colormap = cmap = xswa.colormap =
-      XCreateColormap(dsp, Scr[screen].root, Scr[screen].visual, AllocNone);
+		Scr[screen].colormap = cmap = xswa.colormap =
+			XCreateColormap(dsp, Scr[screen].root, Scr[screen].visual, AllocNone);
 #else
-    cmap = DefaultColormapOfScreen(scr);
-    Scr[screen].colormap = None;
+		cmap = DefaultColormapOfScreen(scr);
+		Scr[screen].colormap = None;
 #endif
 
 		xswa.override_redirect = True;
@@ -3041,7 +3146,6 @@ main(int argc, char **argv)
 			       XA_WM_HINTS, XA_WM_HINTS, 32, PropModeReplace,
 					(unsigned char *) &xwmh, sizeof (xwmh) / sizeof (int));
 		}
-
 		if (debug) {
 			Scr[screen].iconpos.x = (DisplayWidth(dsp, screen) - 100 -
 						 MAX(512, XTextWidth(font, text_info, strlen(text_info)))) / 2;
@@ -3092,7 +3196,7 @@ main(int argc, char **argv)
 		else {
 			Scr[screen].icon = XCreateWindow(dsp, Scr[screen].window,
 				Scr[screen].iconpos.x, Scr[screen].iconpos.y,
-				    iconwidth, iconheight, 1, CopyFromParent,
+			      iconwidth, iconheight, 1, (int) CopyFromParent,
 						 InputOutput, CopyFromParent,
 							 CIMASK, &xswa);
 #ifdef USE_BUTTON_LOGOUT
@@ -3104,7 +3208,7 @@ main(int argc, char **argv)
 				w = XTextWidth(font, buf, strlen(buf));
 				h = font->ascent + font->descent + 2;
 				Scr[screen].button = XCreateWindow(dsp, Scr[screen].window,
-					       0, 0, w, h, 1, CopyFromParent,
+					 0, 0, w, h, 1, (int) CopyFromParent,
 						 InputOutput, CopyFromParent,
 							      CIMASK, &xswa);
 			}
@@ -3231,7 +3335,7 @@ main(int argc, char **argv)
 #else
 			(void) sigsetmask(old_sigmask);
 #endif
-			system(startCmd);
+			(void) system(startCmd);
 			exit(0);
 		}
 	}
@@ -3269,7 +3373,7 @@ main(int argc, char **argv)
 			perror(ProgramName);
 			cmd_pid = 0;
 		} else if (!cmd_pid) {
-			system(endCmd);
+			(void) system(endCmd);
 			exit(0);
 		}
 	}
@@ -3280,30 +3384,4 @@ main(int argc, char **argv)
 #endif
 }
 
-void
-SigUsr1(int sig)
-{
-#ifdef DEBUG
-	(void) printf("Signal %d received\n", sig);
-#endif
-	signalUSR1 = 1;
-	signalUSR2 = 0;
-
-	(void) signal(SIGUSR1, SigUsr1);
-	(void) signal(SIGUSR2, SigUsr2);
-}
-
-void
-SigUsr2(int sig)
-{
-#ifdef DEBUG
-	(void) printf("Signal %d received\n", sig);
-#endif
-	signalUSR1 = 0;
-	signalUSR2 = 1;
-
-	(void) signal(SIGUSR1, SigUsr1);
-	(void) signal(SIGUSR2, SigUsr2);
-}
-
 #endif /* STANDALONE */
