@@ -7,7 +7,7 @@
  * xlock.h - external interfaces for new modes and SYSV OS defines.
  *
  * Copyright (c) 1991 by Patrick J. Naughton.
- * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver code, Copyright (c) 1997 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -49,7 +49,7 @@
 /* xscreensaver compatibility layer for xlockmore modules. */
 
 /*-
- * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@netscape.com>
+ * xscreensaver, Copyright (c) 1997, 1998 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -61,7 +61,7 @@
  *
  * The definitions in this file make it possible to compile an xlockmore
  * module into a standalone program, and thus use it with xscreensaver.
- * By Jamie Zawinski <jwz@netscape.com> on 10-May-97; based on the ideas
+ * By Jamie Zawinski <jwz@jwz.org> on 10-May-97; based on the ideas
  * in the older xlock.h by Charles Hannum <mycroft@ai.mit.edu>.  (I had
  * to redo it, since xlockmore has diverged so far from xlock...)
  */
@@ -134,7 +134,20 @@ XrmOptionDescRec options[100];
 #endif
 #else /* HAVE_CONFIG_H */
 
+/* I use this for testing SunCplusplus
+   I still get this in the link:
+   Undefined                       first referenced
+   symbol                             in file
+   gethostbyname(const char*)               ../xlock/resource.o
+   kill(long, int)                         ../xlock/logout.o
+   signal(int, void (*)(int))                   ../xlock/logout.o
+
+   #define SUN_OGL_NO_VERTEX_MACROS 1
+   #define SunCplusplus
+ */
+
 /* THIS MAY SOON BE DEFUNCT, SHOULD WORK NOW THOUGH FOR IMAKE */
+#define HAVE_GLBINDTEXTURE 1
 #define inline
 #ifdef AIXV3
 #define HAVE_SYS_SELECT_H 1
@@ -398,20 +411,15 @@ typedef struct {
 
 /* this must follow definition of ModeSpecOpt */
 #include "mode.h"
-#include "vis.h"
-#include "color.h"
-#include "util.h"
-#include "iostuff.h"
-#include "automata.h"
 
-#define CHECK_OLD_ARGS /* check depreciated args */
+#define CHECK_OLD_ARGS		/* check depreciated args */
 
 #ifdef OPENGL_MESA_INCLUDES
 /* Allow OPEN GL using MESA includes */
 #undef MESA
 #endif
 
-extern void getResources(int argc, char **argv);
+extern void getResources(Display ** displayp, int argc, char **argv);
 extern void finish(Display * display, Bool closeDisplay);
 extern void error(char *buf);
 
